@@ -10,8 +10,8 @@
 * in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
-#include <stdio.h>
-#include <iostream.h>
+#include <iostream>
+using namespace std;
 
 #define DATA_BEGIN   ((char) 2)
 #define DATA_END     ((char) 5)
@@ -23,7 +23,7 @@ main () {
   cout << DATA_BEGIN << "verbatim:";
   cout << "Terminate your input by ';'";
   cout << DATA_END;
-  fflush (stdout);
+  cout.flush ();
 
   while (true) {
     char buffer[100];
@@ -40,7 +40,7 @@ main () {
       else cout << "#f";
       cout << DATA_END;
     }
-    fflush (stdout);
+    cout.flush ();
   }
   return 0;
 }
