@@ -15,25 +15,27 @@
 ;; Mathematical constants are displayed upright in TeXmacs
 ;; Admit variants <mathD*>, <mathd*>, etc.
 
+("<mathcatalan>"   "#43")   ; Catalan constant
 ("<mathD>"	   "#44")   ; Derivation operator
 ("<mathd>"	   "#64")   ; differential (for d x inside integrals)
 ("<mathe>"	   "#65")   ; exp(1)
 ("<mathi>"	   "#69")   ; imaginary unit
 ("<mathj>"	   "#6A")   ; variant of imaginary unit
-("<mathpi>"	   "#03C0") ;
+("<mathGamma>"	   "#0393") ; Gamma function
+("<mathLaplace>"   "#0394") ; Laplace operator
+("<mathpi>"	   "#03C0") ; pi constant
 ("<matheuler>"	   "#03B3") ; Euler constant
-("<mathcatalan>"   "#69")   ; Catalan constant
+("<mathlambda>"	   "#03BB") ; lambda calculus "quantifier"
 
 ;; Alternate symbol names. They use the same glyph and are converted to the
 ;; same unicode character as another symbol.
 
-("<cdummy>"	"#22C5") ; see <cdot>
 ("<dag>"	"#2020") ; see <dagger>
 ("<ddag>"	"#2021") ; see <ddagger>
 ("<Im>"		"#2111") ; see <frak-I>
 ("<Re>"		"#211C") ; see <frak-R>
 ("<agemO>"	"#2127") ; see <Mho>
-("<to>"		"#2192") ; see <rigtharrow>
+("<to>"		"#2192") ; see <rightarrow>
 ("<notin>"	"#2209") ; see <nin>
 ("<notni>"	"#220C") ; see <nni>
 ("<asterisk>"	"#2217") ; see <ast>
@@ -48,6 +50,8 @@
 ("<wasyunlhd>"	"#22B4") ; see <trianglelefteq>
 ("<unrhd>"	"#22B5") ; see <trianglerighteq>
 ("<wasyunrhd>"	"#22B5") ; see <trianglerighteq>
+("<cdummy>"	"#22C5") ; see <cdot>
+("<exterior>"	"#2227") ; see <wedge>
 ("<box>"	"#25A1") ; see <square>
 ("<Box>"	"#25A1") ; see <square>
 ("<wasy-38>"	"#2641") ; see <earth>
@@ -109,6 +113,11 @@
 ;; LEFT, RIGHT, MID and BIG primitive. If they are explicitly
 ;; present, they are exported as a regular-sized character.	
 
+("<lvert>"		"|")
+("<rvert>"		"|")
+("<lVert>"		"#2016")
+("<rVert>"		"#2016")
+
 ("<large-less-0>"	"<")
 ("<large-gtr-0>"	">")
 ("<large-(>"		"(")
@@ -132,9 +141,17 @@
 ("<large-{-0>"		"{")
 ("<large-}-0>"		"}")
 ("<large-|>"		"|")
+("<large-lvert>"	"|")
+("<large-rvert>"	"|")
 ("<large-||>"		"#2016")
+("<large-lVert>"	"#2016")
+("<large-rVert>"	"#2016")
 ("<large-|-0>"		"|")
+("<large-lvert-0>"	"|")
+("<large-rvert-0>"	"|")
 ("<large-||-0>"		"#2016")
+("<large-lVert-0>"	"#2016")
+("<large-rVert-0>"	"#2016")
 ("<large-llbracket>"	"#27E6")
 ("<large-rrbracket>"	"#27E7")
 ("<large-llbracket-0>"	"#27E6")
