@@ -756,6 +756,7 @@
 ("new row" "nov dek")
 ("new table" "nov tabulka")
 ("next line" "dal dek")
+("no" "ne")
 ("no changes need to be saved" "dn zmny pro uloen")
 ("no dictionary for" "chyb slovnk")
 ("no first indentation" "neodsazovat prvn")
@@ -1298,6 +1299,7 @@
 ("writing data converters" "tvorba konvertor dat")
 ("writing your own style files" "tvorba vaich vlastnch soubor styl")
 ("yellow" "lut")
+("yes" "ano")
 ("you can also obtain" "me tak zskat")
 ("your document is back in its original state" "v dokument je opt v pvodn stavu")
 ("your first interface" "vae prvn rozhran")
