@@ -999,6 +999,7 @@
 ("next match" "suivant")
 ("next" "suivant")
 ("nickname" "surnom")
+("no" "non")
 ("no changes need to be saved" "il n'y a pas de changements  sauvegarder")
 ("no dictionary for" "pas de dictionnaire pour")
 ("no first indentation" "pas de premire indentation")
@@ -1717,6 +1718,7 @@
 ("writing your own style files" "crire vos propres feuilles de style")
 ("written with TeXmacs" "conu avec TeXmacs")
 ("yellow" "jaune")
+("yes" "oui")
 ("you can also obtain" "vous pouvez galement obtenir")
 ("your document is back in its original state" "votre document est revenu dans son tat original")
 ("your first interface" "votre premire interface")
