@@ -684,7 +684,7 @@
 ("left margin" "linker Abstand")
 ("left padding" "Padding links")
 ("left prime" "linker Strich")
-("left ragged" "linksbndig")
+("left aligned" "linksbndig")
 ("left slanted" "nach links geneigt")
 ("left subscript" "Index links unten")
 ("left superscript" "Index rechts oben")
@@ -1066,7 +1066,7 @@
 ("right border" "sichtbarer rechter Rand")
 ("right margin" "rechter Abstand")
 ("right padding" "Padding rechts")
-("right ragged" "rechtsbndig")
+("right aligned" "rechtsbndig")
 ("right subscript" "Index rechts unten")
 ("right superscript" "Index rechts oben")
 ("right surrounding" "rechtes Umfeld")
