@@ -757,6 +757,7 @@
 ("new row" "nuova riga")
 ("new table" "nuova tabella")
 ("next line" "prossima linea")
+("no" "no")
 ("no changes need to be saved" "non ci sono cambiamenti da salvare")
 ("no dictionary for" "non c' un dizionario per")
 ("no first indentation" "nessuna prima indentazione")
@@ -1299,6 +1300,7 @@
 ("writing data converters" "scrivere convertitori di formato")
 ("writing your own style files" "scrivere il proprio file di stile")
 ("yellow" "giallo")
+("yes" "si")
 ("you can also obtain" "puoi anche ottenere")
 ("your document is back in its original state" "il documento  stato riportato allo stato originale")
 ("your first interface" "la tua prima interfaccia")
