@@ -1,4 +1,4 @@
-<TeXmacs|1.0.7.6>
+<TeXmacs|1.0.7.9>
 
 <style|<tuple|source|std>>
 
@@ -24,15 +24,25 @@
 
   \;
 
-  <assign|render-key|<macro|x|<active*|<move|<small|<with|font-family|tt|<with|ornament-color|#e0e0e0|ornament-sunny-color|#f0f0f0|ornament-shadow-color|#c0c0c0|ornament-hpadding|2ln|ornament-vpadding|2ln|ornament-border|2ln|<ornament|<vcorrect|<arg|x>>>>>>||0.075ex>>>>
+  <assign|render-key|<macro|key|<active*|<move|<small|<with|font-family|tt|<with|ornament-color|#e0e0e0|ornament-sunny-color|#f0f0f0|ornament-shadow-color|#c0c0c0|ornament-hpadding|2ln|ornament-vpadding|2ln|ornament-border|2ln|<ornament|<vcorrect|<arg|key>>>>>>||0.075ex>>>>
 
-  <assign|key|<macro|x|<extern|tmdoc-key|<arg|x>>>>
+  <assign|render-keys|<macro|keys|<extern|tmdoc-render-keys|<arg|keys>>>>
 
-  <assign|key*|<macro|x|<extern|tmdoc-key*|<arg|x>>>>
+  <assign|key|<macro|shortcut|<extern|tmdoc-key|<arg|shortcut>>>>
 
-  <assign|shortcut|<macro|cmd|<extern|tmdoc-shortcut|<arg|cmd>>>>
+  <assign|key*|<macro|shortcut|<extern|tmdoc-key*|<arg|shortcut>>>>
 
-  <assign|prefix|<macro|x|<extern|tmdoc-key|<arg|x>>>>
+  <assign|shortcut|<macro|command|<extern|tmdoc-shortcut|<arg|command>>>>
+
+  <assign|prefix|<macro|keys|<extern|tmdoc-key|<arg|keys>>>>
+
+  <drd-props|key|arity|1|string|0>
+
+  <drd-props|key*|arity|1|string|0>
+
+  <drd-props|shortcut|arity|1|string|0>
+
+  <drd-props|prefix|arity|1|string|0>
 
   \;
 </body>
