@@ -1,4 +1,4 @@
-<TeXmacs|1.0.7.15>
+<TeXmacs|1.0.7.17>
 
 <style|source>
 
@@ -70,17 +70,45 @@
     </src-comment>
   </active*>
 
-  <assign|render-footnote|<macro|nr|body|<style-with|src-compact|none|<\float|footnote|>
-    <smaller|<with|par-mode|justify|par-left|0cm|par-right|0cm|<style-with|src-compact|none|<surround|<locus|<id|<hard-id|<arg|body>>>|<link|hyperlink|<id|<hard-id|<arg|body>>>|<url|<merge|#footnr-|<arg|nr>>>>|<arg|nr>><footnote-sep>|<set-binding|<merge|footnote-|<arg|nr>>|<value|the-label>|body><right-flush>|<style-with|src-compact|none|<arg|body>>>>>>
+  <assign|render-footnote*|<macro|sym|nr|body|<style-with|src-compact|none|<\float|footnote|>
+    <smaller|<with|par-mode|justify|par-left|0cm|par-right|0cm|<style-with|src-compact|none|<surround|<locus|<id|<hard-id|<arg|body>>>|<link|hyperlink|<id|<hard-id|<arg|body>>>|<url|<merge|#footnr-|<arg|nr>>>>|<arg|sym>><footnote-sep>|<set-binding|<merge|footnote-|<arg|nr>>|<value|the-label>|body><right-flush>|<style-with|src-compact|none|<arg|body>>>>>>
   </float>>>>
 
+	<assign|render-footnote|<macro|nr|body|<style-with|src-compact|none|<render-footnote*|<arg|nr>|<arg|nr>|<arg|body>>>>>
+
   <assign|footnote|<macro|body|<style-with|src-compact|none|<next-footnote><render-footnote|<the-footnote>|<arg|body>><space|0spc><label|<merge|footnr-|<the-footnote>>><rsup|<reference|<merge|footnote-|<the-footnote>>>>>>>
 
-  \;
+  <\active*>
+    <\src-comment>
+      Customized notes.
+    </src-comment>
+  </active*>
+
+  <assign|custom-note-text|<\macro|sym|id|body>
+    <\style-with|src-compact|none>
+		<style-with|src-compact|none|||<\surround|<locus|<id|<merge|dest-abbr-|<arg|id>>>|<link|footnote-source|<id|<merge|dest-abbr-|<arg|id>>>|<id|<merge|source-|<arg|id>>>>|<arg|sym>><footnote-sep>|<right-flush>>
+        <\with|locus-color|preserve|visited-color|preserve>
+          <\locus|<id|<merge|dest-|<arg|id>>>>
+            <style-with|src-compact|none|<arg|body>>
+          </locus>
+        </with>
+      </surround>>
+    </style-with>
+  </macro>>
+
+  <assign|custom-footnote-text|<macro|sym|id|body|<style-with|src-compact|none|<\float|footnote|>
+    <smaller|<\with|par-mode|justify|par-left|0cm|par-right|0cm>
+      <\custom-note-text|<arg|sym>|<arg|id>>
+        <arg|body>
+      </custom-note-text>
+    </with>>
+  </float>>>>
+
+  <assign|custom-note-ref|<macro|sym|sep|id|body|<style-with|src-compact|none|<with|locus-color|preserve|visited-color|preserve|<locus|<id|<merge|source-|<arg|id>>>|<arg|body>>><rsup|<locus|<id|<merge|source-abbr-|<arg|id>>>|<link|footnote-text|<id|<merge|source-abbr-|<arg|id>>>|<id|<merge|dest-|<arg|id>>>>|<arg|sep><arg|sym>>>>>>
 </body>
 
 <\initial>
   <\collection>
     <associate|preamble|true>
   </collection>
-</initial>
\ No newline at end of file
+</initial>
