@@ -1,4 +1,4 @@
-<TeXmacs|1.0.5.12>
+<TeXmacs|1.0.6.2>
 
 <style|source>
 
@@ -15,11 +15,11 @@
     <src-copyright|1998--2004|Marie-Franoise Roy and Joris van der Hoeven>
 
     <\src-license>
-      This <TeXmacs> style package falls under the <hlink|GNU general public
-      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
-      WHATSOEVER. If you do not have a copy of the license, then write to the
-      Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-      02111-1307, USA.
+      This software falls under the <hlink|GNU general public
+      license, version 3 or later|$TEXMACS_PATH/LICENSE>.
+      It comes WITHOUT ANY WARRANTY WHATSOEVER.
+      You should have received a copy of the license which the software.
+      If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
     </src-license>
   </src-title>>
 
@@ -392,7 +392,7 @@
   </surround>>>>
 
   <assign|detailed-algorithm|<\macro|x|y>
-    <style-with|src-compact|none|<\surround|<with|par-first|-3fn|<style-with|src-compact|none|<yes-indent><action|<resize|<specific|screen|<active*|<with|mode|math|\<bullet\>>>>|||r]1.5fn|>|(mouse-fold)|<arg|x>>>>|<right-flush>>
+    <style-with|src-compact|none|<\surround|<with|par-first|-3fn|<style-with|src-compact|none|<yes-indent><action|<resize|<specific|screen|<active*|<with|mode|math|\<bullet\>>>>|||r]1.5fn|>|(mouse-fold)|<arg|x>|<arg|y>>>>|<right-flush>>
       <\with|padded-normal|<value|fold-padded-normal>|item|<value|fold-item>>
         <arg|y>
       </with>
