@@ -1,4 +1,4 @@
-<TeXmacs|1.0.7.14>
+<TeXmacs|1.0.7.16>
 
 <style|<tuple|source|std>>
 
@@ -40,6 +40,10 @@
 
   <assign|tex-text-width|<macro|<if|<equal|<value|par-columns>|1>|25.5cc|17.5cm>>>
 
+  <assign|tex-line-width|<value|tex-text-width>>
+
+  <assign|tex-column-width|<value|tex-text-width>>
+
   \;
 
   <assign|tex-voffset|<macro|0cm>>
