@@ -238,10 +238,10 @@
      ,(bib-new-list-spc
        `(,(bib-new-block (bib-format-author x))
 	 ,(bib-new-block (bib-format-field-Locase x "title"))
-	 ,(bib-new-block
-	   (bib-new-sentence
-	    `(,(bib-format-field x "howpublished")
-	      ,(bib-format-field x "address")
+	 ,(bib-new-case-preserved-block
+	   (bib-new-case-preserved-sentence
+	    `(,(bib-format-field-preserve-case x "howpublished")
+	      ,(bib-upcase-first (bib-format-field x "address"))
 	      ,(bib-format-date x))))
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
@@ -385,9 +385,9 @@
      ,(bib-new-list-spc
        `(,(bib-new-block (bib-format-author x))
 	 ,(bib-new-block (bib-format-field-Locase x "title"))
-	 ,(bib-new-block
-	   (bib-new-sentence
-	    `(,(bib-format-field x "howpublished")
+	 ,(bib-new-case-preserved-block
+	   (bib-new-case-preserved-sentence
+	    `(,(bib-format-field-preserve-case x "howpublished")
 	      ,(bib-format-date x))))
 	 ,(bib-new-block (bib-format-field x "note"))))))
 
