@@ -27,13 +27,13 @@
   ,(string->symbol " ") ,(string->symbol ";") 
   ,(string->symbol ",") ,(string->symbol ":") 
   - / [ ] ! * ,(string->symbol "|") i j ss SS oe OE ae AE
-  AA DH L NG O S TH aa dh dj l ng o th pounds colon
+  AA DH L NG O S TH aa dh dj l ng o th pounds colon and lq rq
   quad qquad enspace thinspace par smallskip medskip bigskip
   noindent newline linebreak nobreak nolinebreak strut
   pagebreak nopagebreak newpage newdoublepage clearpage cleardoublepage
   newblock bgroup egroup protect cr hfil hfill hfilll appendix limits nolimits
   dots maketitle tableofcontents TeX LaTeX onecolumn twocolumn
-  begingroup endgroup printindex today
+  begingroup endgroup printindex today bmod toprule midrule bottomrule
 
   ;; AMS commands
   qed dotsc dotsb dotsm dotsi dotso
@@ -43,18 +43,24 @@
   notin vert Vert addots
   implies iff gets
   ;; wikipedia
-  infin rang)
+  infin rang
+
+  ;; Algorithms
+  AND BlankLine Ensure ENSURE FALSE GLOBALS NOT OR PRINT Require REQUIRE RETURN
+  State STATE TO KwTo TRUE XOR Else ENDBODY EndFor ENDFOR EndFunction EndIf
+  ENDIF ENDINPUTS EndLoop ENDLOOP ENDOUTPUTS EndProcedure ENDWHILE EndWhile
+  Loop)
 
 (logic-group latex-command-1%
-  usepackage part part* chapter chapter*
+  part part* chapter chapter*
   section section* subsection subsection* subsubsection subsubsection*
   paragraph paragraph* subparagraph subparagraph* nextbib
   footnote overline underline <sub> <sup> not left right
   big Big bigg Bigg bigl Bigl biggl Biggl
   bigm Bigm biggm Biggm bigr Bigr biggr Biggr
   bar hat tilde widehat widetilde vec bm
-  grave acute check breve abovering mathring
-  dot ddot dddot ddddot mod pod pmod bmod
+  grave acute check breve invbreve abovering mathring
+  dot ddot dddot ddddot mod pod pmod
   label ref pageref index hspace hspace* vspace vspace*
   mbox hbox textnormal text not substack
   ,(string->symbol "'") ,(string->symbol "`") ,(string->symbol "\"")
@@ -67,9 +73,11 @@
   newcounter stepcounter refstepcounter value
   citet citep citet* citep* citealt citealp citealt* citealp*
   citetext citeauthor citeauthor* citeyear onlinecite
-  epsfig url penalty centerline fbox framebox 
+  epsfig url penalty centerline fbox framebox cline cmidrule
   enlargethispage
-  newlength newdimen newskip)
+  newlength newdimen newskip
+  Comment COMMENT For ForAll If Input KwData KwResult KwRet lnl nllabel
+  lElse uElse Output Repeat Until UNTIL While)
 
 (logic-group latex-command-1% ;; . needs a special treatment
   ,(string->symbol "."))
@@ -78,10 +86,11 @@
   binom tbinom dbinom cfrac tfrac equal href
   sideset stackrel citeauthoryear
   setcounter addtocounter setlength addtolength
-  scalebox)
+  scalebox
+  Call Function Procedure SetKw SetKwData SetKwFunction SetKwInOut)
 
 (logic-group latex-command-3%
-  ifthenelse resizebox @setfontsize)
+  ifthenelse resizebox @setfontsize eIf multicolumn)
 
 (logic-group latex-command-4%
   mathchoice)
@@ -108,21 +117,24 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (logic-group latex-command-0*%
-  item ,(string->symbol "\\"))
+  item ,(string->symbol "\\")
+  BODY ELSE INPUTS LOOP OUTPUTS REPEAT)
 
 (logic-group latex-command-1*%
-  documentclass documentstyle sqrt bibitem cite
+  usepackage documentclass documentstyle sqrt bibitem cite caption  
   includegraphics includegraphics*
   subjclass declaretheorem footnotetext
   xleftarrow xrightarrow xleftrightarrow xminus
   xLeftarrow xRightarrow xLeftrightarrow xequal
-  xmapsto xmapsfrom)
+  xmapsto xmapsfrom
+  Begin ELSIF FORALL FOR IF WHILE tcp tcp* tcc tcc*)
 
 (logic-group latex-command-2*%
-  def newcommand renewcommand newtheorem newtheorem* frac parbox)
+  def newcommand renewcommand newtheorem newtheorem* frac parbox 
+  ElseIf uElseIf lElseIf ForEach lForEach lForAll lFor)
 
 (logic-group latex-command-3*%
-  category newenvironment renewenvironment)
+  category newenvironment renewenvironment multirow)
 
 (logic-rules
   ((latex-command-0% 'x) (latex-command-0*% 'x))
@@ -146,7 +158,8 @@
   begin-picture)
 
 (logic-group latex-environment-0*%
-  begin-figure begin-table)
+  begin-figure begin-table begin-figure* begin-table*
+  begin-algorithmic begin-algorithm begin-algorithm2e)
 
 (logic-group latex-environment-1%
   begin-tabbing begin-thebibliography begin-multicols)
@@ -154,6 +167,9 @@
 (logic-group latex-environment-1*%
   begin-array begin-tabular)
 
+(logic-group latex-environment-2*%
+  begin-tabular* begin-tabularx)
+
 (logic-rules
   ((latex-environment% 'x) (latex-environment-0% 'x))
   ((latex-arity% 'x 0) (latex-environment-0% 'x))
@@ -166,7 +182,9 @@
   ((latex-environment-0% 'x) (latex-environment-0*% 'x))
   ((latex-optional-arg% 'x) (latex-environment-0*% 'x))
   ((latex-environment-1% 'x) (latex-environment-1*% 'x))
-  ((latex-optional-arg% 'x) (latex-environment-1*% 'x)))
+  ((latex-optional-arg% 'x) (latex-environment-1*% 'x))
+  ((latex-environment-2% 'x) (latex-environment-2*% 'x))
+  ((latex-optional-arg% 'x) (latex-environment-2*% 'x)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Modifiers
@@ -370,7 +388,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (logic-group latex-ignore-0%
-  allowbreak notag xspace break sloppy makeatother makeatletter
+  allowbreak notag xspace break sloppy makeatother makeatletter relax
   ignorespacesafterend ignorespaces balancecolumns)
 
 (logic-group latex-ignore-0*%
