@@ -68,6 +68,7 @@
   (mapmulti "{\\mbox{\\rotatebox[origin=c]{180}{$\\multimap$}}}")
   (mathcatalan "C")
   (mathd "\\mathrm{d}")
+  (mathD "\\mathrm{D}")
   (mathe "\\mathrm{e}")
   (matheuler "\\gamma")
   (mathlambda "\\lambda")
@@ -96,6 +97,7 @@
   (point ".")
   (cdummy "\\cdot")
   (comma "{,}")
+  (copyright "\\copyright")
   (bignone "")
   (nobracket "")
   (nospace "")
@@ -154,6 +156,7 @@
 (logic-table latex-texmacs-0%
   (tmunsc "\\_")
   (emdash "---")
+  (tmhrule "\\noindent\\rule[0.3\\baselineskip]{\\textwidth}{0.4pt}")
   (tmat "\\symbol{\"40}")
   (tmbsl "\\ensuremath{\\backslash}")
   (tmdummy "$\\mbox{}$")
