@@ -69,17 +69,17 @@
 	(set! tmtex-image-root-string "image")))
   (set! tmtex-appendices? #f)
   (set! tmtex-replace-style?
-	(== (assoc-ref opts "texmacs->latex:replace-style") "on"))
+    (== (assoc-ref opts "texmacs->latex:replace-style") "on"))
   (set! tmtex-indirect-bib?
-	(== (assoc-ref opts "texmacs->latex:indirect-bib") "on"))
+    (== (assoc-ref opts "texmacs->latex:indirect-bib") "on"))
   (set! tmtex-use-macros?
-	(== (assoc-ref opts "texmacs->latex:use-macros") "on"))
+    (== (assoc-ref opts "texmacs->latex:use-macros") "on"))
   (set! tmtex-use-unicode?
-	(== (assoc-ref opts "texmacs->latex:encoding") "utf-8"))
+    (== (assoc-ref opts "texmacs->latex:encoding") "utf-8"))
   (set! tmtex-use-catcodes? 
-        (== (assoc-ref opts "texmacs->latex:encoding") "cork"))
+    (== (assoc-ref opts "texmacs->latex:encoding") "cork"))
   (set! tmtex-use-ascii? 
-        (== (assoc-ref opts "texmacs->latex:encoding") "ascii")))
+    (== (assoc-ref opts "texmacs->latex:encoding") "ascii")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Data
@@ -377,7 +377,7 @@
 
 (define (tmtex-transform-style x)
   (cond ((in? x '("article" "book" "letter")) x)
-	((in? x '("generic" "exam")) "letter")
+	((in? x '("generic" "exam")) "article")
 	((== x "seminar") "slides")
 	((in? x '("tmarticle" "tmdoc" "mmxdoc")) "article")
 	((in? x '("tmbook" "tmmanual")) "book")
@@ -514,6 +514,7 @@
 (define (tmtex-new-line l) (tex-apply '!newline))
 (define (tmtex-next-line l) (list '!nextline))
 (define (tmtex-no-break l) '(!group (nobreak)))
+(define (tmtex-emdash l) "---")
 
 (define (tmtex-decode-length len)
   ;; FIXME: should be completed
@@ -523,6 +524,8 @@
 	  ((string-ends? s "par") (string-replace s "par" "\\columnwidth"))
 	  (else s))))
 
+(define (tmtex-hrule l) (list 'tmhrule))
+
 (define (tmtex-hspace l)
   (let ((s (if (= (length l) 1) (car l) (cadr l))))
     (cond ((== s "1fn") (list 'quad))
@@ -829,6 +832,7 @@
 	  ((== acc "<bar>") (list (if wide 'overline 'bar) arg))
 	  ((== acc "<vect>") (list (if wide 'overrightarrow 'vec) arg))
 	  ((== acc "<breve>") (list 'breve arg))
+	  ((== acc "<invbreve>") (list 'invbreve arg))
 	  ((== acc "<check>") (list 'check arg))
 	  ((== acc "<acute>") (list 'acute arg))
 	  ((== acc "<grave>") (list 'grave arg))
@@ -1167,7 +1171,7 @@
 (tm-define (tmtex-select-data expr tag)
   (:synopsis "Get data matching @tag in @expr with nice separators")
   (let* ((data (select expr (list tag)))
-	 (sep (if (== tag 'author-address) '(!nextline) "; "))
+	 (sep (if (== tag 'author-affiliation) '(!nextline) "; "))
 	 (fun (lambda (x)
 		(cond ((func? x 'document)
 		       (list (tex-concat* (tmtex-compressed sep (cdr x)))))
@@ -1180,15 +1184,16 @@
   (if (null? l) l
       (list (list tag (tex-concat* l)))))
 
-(define (tmtex-make-author tag)
-  (let* ((name (tmtex-select-data tag 'author-name))
-	 (address (tmtex-select-data tag 'author-address))
-	 (note (tmtex-select-data tag 'author-note))
+(define (tmtex-make-author data)
+  (let* ((tag (select data '(:%2)))
+         (name (tmtex-select-data tag 'author-name))
+	 (address (tmtex-select-data tag 'author-affiliation))
+	 (misc (tmtex-select-data tag 'author-note))
 	 (email (tmtex-select-data tag 'author-email))
 	 (homepage (tmtex-select-data tag 'author-homepage))
 	 (email* (tmtex-data-apply 'email email))
 	 (homepage* (tmtex-data-apply 'homepage homepage))
-	 (note* (tmtex-data-assemble "; " (list note email* homepage*)))
+	 (note* (tmtex-data-assemble "; " (list misc email* homepage*)))
 	 (name* (append name (tmtex-data-apply 'thanks note*))))
     (tex-concat* (tmtex-data-assemble '(!nextline)
 				      (list name* address)))))
@@ -1196,29 +1201,33 @@
 (tm-define (tmtex-doc-data s l)
   (let* ((tag (cons s l))
 	 (title (tmtex-select-data tag 'doc-title))
-	 (authors (map tmtex-make-author (select tag '(doc-author-data))))
+	 (authors (map tmtex-make-author (select tag '(doc-author))))
 	 (date (tmtex-select-data tag 'doc-date))
 	 (note (tmtex-select-data tag 'doc-note))
-	 (keywords (tmtex-select-data tag 'doc-keywords))
-	 (AMS-class (tmtex-select-data tag 'doc-AMS-class))
-	 (keywords* (tmtex-data-apply 'keywords keywords))
-	 (AMS-class* (tmtex-data-apply 'AMSclass AMS-class))
-	 (note* (tmtex-data-assemble "; " (list note keywords* AMS-class*)))
-	 (title* (append title (tmtex-data-apply 'thanks note*)))
-	 (author* (tmtex-data-assemble '(and) (map list authors))))
-    (tex-concat `((title ,(tex-concat title*))
-		  (author ,(tex-concat author*))
+	 (title* (append title (tmtex-data-apply 'thanks note)))
+	 (author* (tmtex-data-assemble " \\and " (map list authors))))
+    (tex-concat `((title ,(tex-concat title*)) "\n"
+		  (author ,(tex-concat author*)) "\n"
 		  (maketitle)))))
 
 (define (tmtex-doc-data-wrapper s l)
   (tmtex-doc-data s l))
 
 (tm-define (tmtex-abstract s l)
-  (tmtex-std-env s l))
+  (tmtex-std-env "abstract" l))
 
 (define (tmtex-abstract-wrapper s l)
   (tmtex-abstract s l))
 
+(define (tmtex-select-args-by-func n l)
+  (filter (lambda (x) (func? x n)) l))
+
+(define (tmtex-abstract-data s l)
+  (let* ((msc (tmtex-select-args-by-func 'abstract-msc l))
+         (keywords (tmtex-select-args-by-func 'abstract-keywords l))
+         (abstract (tmtex-select-args-by-func 'abstract l)))
+  (tex-concat `(,@abstract "\n" ,@keywords "\n" ,@msc))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; TeXmacs style primitives
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1419,9 +1428,9 @@
 
 (define (tmtex-bibitem* s l)
   (cond ((= (length l) 1)
-	 `(bibitem ,(tmtex (car l))))
+	 `(bibitem ,(car l)))
 	((= (length l) 2)
-	 `(bibitem (!option ,(tmtex (car l))) ,(tmtex (cadr l))))
+	 `(bibitem (!option ,(tmtex (car l))) ,(cadr l)))
 	(else "")))
 
 (define (tmtex-figure s l)
@@ -1501,7 +1510,7 @@
 
 (define (tmtex-cite-list l)
   (cond ((null? l) "")
-	((nstring? (car l)) (tmtex-cite-list (cdr l)))
+	;((nstring? (car l)) (tmtex-cite-list (cdr l)))
 	((null? (cdr l)) (car l))
 	(else (string-append (car l) "," (tmtex-cite-list (cdr l))))))
 
@@ -1624,6 +1633,7 @@
   (concat tmtex-concat)
   (rigid tmtex-rigid)
   (hidden tmtex-noop)
+  (hrule tmtex-hrule)
   (hspace tmtex-hspace)
   (vspace* tmtex-noop)
   (vspace tmtex-vspace)
@@ -1641,6 +1651,7 @@
   (line-break tmtex-line-break)
   (new-line tmtex-new-line)
   (next-line tmtex-next-line)
+  (emdash tmtex-emdash)
   (no-break tmtex-no-break)
   (no-indent tmtex-no-first-indentation)
   (yes-indent tmtex-noop)
@@ -1754,11 +1765,12 @@
   (hide-part (,tmtex-hide-part -1))
   (show-part (,tmtex-show-part -1))
   (doc-data (,tmtex-doc-data-wrapper -1))
-  ((:or doc-title doc-author-data doc-date doc-note
-	doc-keywords doc-AMS-class) (,tmtex-default -1))
-  ((:or author-name author-address author-note
+  ((:or doc-title doc-author author-data doc-date doc-note
+	abstract-keywords abstract-msc) (,tmtex-default -1))
+  ((:or author-name author-affiliation author-note
 	author-email author-homepage) (,tmtex-default -1))
   (abstract (,tmtex-abstract-wrapper 1))
+  (abstract-data (,tmtex-abstract-data -1))
   (appendix (,tmtex-appendix 1))
   ((:or theorem proposition lemma corollary proof axiom definition
 	notation conjecture remark note example exercise problem warning
@@ -1922,8 +1934,8 @@
   (cond ((not sty) (set! sty (list "generic")))
 	((string? sty) (set! sty (list sty)))
 	((func? sty 'tuple) (set! sty (cdr sty)))
-	((null? sty) (set! sty '("letter"))))
-  (if (== (car sty) "generic") (set! sty (cons "letter" (cdr sty))))
+	((null? sty) (set! sty '("article"))))
+  (if (== (car sty) "generic") (set! sty (cons "article" (cdr sty))))
   sty)
 
 (tm-define (texmacs->latex x opts)
@@ -1931,10 +1943,10 @@
   (if (tmfile? x)
       (let* ((body (tmfile-extract x 'body))
 	     (style (tmtex-get-style (tmfile-extract x 'style)))
-	     (main-style (or (tmtex-transform-style (car style)) "letter"))
+	     (main-style (or (tmtex-transform-style (car style)) "article"))
 	     (lan (tmfile-init x "language"))
 	     (init (tmfile-extract x 'initial))
-	     (doc (list '!file body style lan init (get-texmacs-path))))
+	     (doc (list '!file body style lan init (url->string (get-texmacs-path)))))
 	(latex-set-style main-style)
 	(latex-set-packages '())
 	(set! tmtex-style (car style))
