@@ -89,19 +89,28 @@
 
 (define (eval-string-with-catch s)
   (catch #t
-	 (lambda () (eval (string->object s)))
-	 (lambda (key msg . args)
-	   key)))
+         (lambda () (eval (string->object s)))
+         (lambda (key msg . err-msg)
+           (let* ((msg (car err-msg))
+                  (args (cadr err-msg))
+                  (err-msg 
+                    (if (list? args) (eval (apply format #f msg args)) msg)))
+             (stree->tree `(errput ,err-msg))))))
+
+(define (error-tree? t)
+  (and (tree? t) (tree-is? t 'errput)))
 
 (tm-define (scheme-eval t)
   (let* ((s (texmacs->code t))
 	 (r (eval-string-with-catch s)))
-    (cond ((and (tree? r) (session-scheme-trees?))
+    (cond ((and (tree? r) (error-tree? r) (session-scheme-trees?))
+           (tree-copy r))
+          ((and (tree? r) (session-scheme-trees?))
            (tree 'text (tree-copy r)))
-	  ((session-scheme-math?)
-	   (with m (cas->stree r)
-	     (if (tm? m) (tree 'math (tm->tree m)) (var-object->string r))))
-	  (else (var-object->string r)))))
+          ((session-scheme-math?)
+           (with m (cas->stree r)
+                 (if (tm? m) (tree 'math (tm->tree m)) (var-object->string r))))
+          (else (var-object->string r)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Low-level evaluation management
@@ -490,6 +499,11 @@
         ((and (tree-cursor-at? t 1 :end) forwards?) (noop))
         (else (remove-text forwards?))))
 
+(tm-define (kbd-remove t forwards?)
+  (:require (and (field-input-context? t) (selection-active-any?)))
+  (clipboard-cut "nowhere")
+  (clipboard-clear "nowhere"))
+
 (tm-define (kbd-variant t forwards?)
   (:require (and (field-context? t) (session-supports-completions?)))
   (let* ((lan (get-env "prog-language"))
