@@ -14,74 +14,89 @@
 (texmacs-module (fonts fonts-adobe))
 
 (set-font-rules
-  '(((avant-garde rm medium right $s $d) (adobe rpagk $s $d 0))
-    ((avant-garde rm medium slanted $s $d) (adobe rpagko $s $d 0))
-    ((avant-garde rm medium italic $s $d) (adobe rpagko $s $d 0))
-    ((avant-garde rm bold right $s $d) (adobe rpagd $s $d 0))
-    ((avant-garde rm bold slanted $s $d) (adobe rpagdo $s $d 0))
-    ((avant-garde rm bold italic $s $d) (adobe rpagdo $s $d 0))
+  '(((avant-garde rm medium right $s $d) (ec avant-garde-rm $s $d))
+    ((avant-garde rm medium slanted $s $d) (ec avant-garde-ti $s $d))
+    ((avant-garde rm medium italic $s $d) (ec avant-garde-ti $s $d))
+    ((avant-garde rm bold right $s $d) (ec avant-garde-bx $s $d))
+    ((avant-garde rm bold slanted $s $d) (ec avant-garde-bi $s $d))
+    ((avant-garde rm bold italic $s $d) (ec avant-garde-bi $s $d))
+    ((avant-garde ss $series $shape $s $d) (avant-garde rm $series $shape $s $d))
+    ((avant-garde tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
-    ((bookman rm medium right $s $d) (adobe rpbkl $s $d 0))
-    ((bookman rm medium slanted $s $d) (adobe rpbkli $s $d 0))
-    ((bookman rm medium italic $s $d) (adobe rpbkli $s $d 0))
-    ((bookman rm bold right $s $d) (adobe rpbkd $s $d 0))
-    ((bookman rm bold slanted $s $d) (adobe rpbkdi $s $d 0))
-    ((bookman rm bold italic $s $d) (adobe rpbkdi $s $d 0))
+    ((bookman rm medium right $s $d) (ec bookman-rm $s $d))
+    ((bookman rm medium slanted $s $d) (ec bookman-ti $s $d))
+    ((bookman rm medium italic $s $d) (ec bookman-ti $s $d))
+    ((bookman rm bold right $s $d) (ec bookman-bx $s $d))
+    ((bookman rm bold slanted $s $d) (ec bookman-bx $s $d))
+    ((bookman rm bold italic $s $d) (ec bookman-bi $s $d))
     ((bookman ss $series $shape $s $d) (avant-garde rm $series $shape $s $d))
     ((bookman tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
-    ((courier rm medium right $s $d) (adobe rpcrr $s $d 0))
-    ((courier rm medium slanted $s $d) (adobe rpcrro $s $d 0))
-    ((courier rm medium italic $s $d) (adobe rpcrro $s $d 0))
-    ((courier rm bold right $s $d) (adobe rpcrb $s $d 0))
-    ((courier rm bold slanted $s $d) (adobe rpcrbo $s $d 0))
-    ((courier rm bold italic $s $d) (adobe rpcrbo $s $d 0))
+    ((courier rm medium right $s $d) (ec courier-rm $s $d))
+    ((courier rm medium slanted $s $d) (ec courier-ti $s $d))
+    ((courier rm medium italic $s $d) (ec courier-ti $s $d))
+    ((courier rm bold right $s $d) (ec courier-bx $s $d))
+    ((courier rm bold slanted $s $d) (ec courier-bx $s $d))
+    ((courier rm bold italic $s $d) (ec courier-bi $s $d))
+    ((courier ss $series $shape $s $d) (helvetica rm $series $shape $s $d))
+    ((courier tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
-    ((helvetica rm medium right $s $d) (adobe rphvr $s $d 0))
-    ((helvetica rm medium slanted $s $d) (adobe rphvro $s $d 0))
-    ((helvetica rm medium italic $s $d) (adobe rphvro $s $d 0))
-    ((helvetica rm medium condensed $s $d) (adobe rphvrrn $s $d 0))
-    ((helvetica rm medium slanted-condensed $s $d) (adobe rphvron $s $d 0))
-    ((helvetica rm medium italic-condensed $s $d) (adobe rphvron $s $d 0))
-    ((helvetica rm bold right $s $d) (adobe rphvb $s $d 0))
-    ((helvetica rm bold slanted $s $d) (adobe rphvbo $s $d 0))
-    ((helvetica rm bold italic $s $d) (adobe rphvbo $s $d 0))
-    ((helvetica rm bold condensed $s $d) (adobe rphvbrn $s $d 0))
-    ((helvetica rm bold slanted-condensed $s $d) (adobe rphvbon $s $d 0))
-    ((helvetica rm bold italic-condensed $s $d) (adobe rphvbon $s $d 0))
+    ((helvetica rm medium right $s $d) (ec helvetica-rm $s $d))
+    ((helvetica rm medium slanted $s $d) (ec helvetica-ti $s $d))
+    ((helvetica rm medium italic $s $d) (ec helvetica-ti $s $d))
+    ((helvetica rm bold right $s $d) (ec helvetica-bx $s $d))
+    ((helvetica rm bold slanted $s $d) (ec helvetica-bx $s $d))
+    ((helvetica rm bold italic $s $d) (ec helvetica-bi $s $d))
+    ((helvetica ss $series $shape $s $d) (helvetica rm $series $shape $s $d))
     ((helvetica tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
-    ((new-century-schoolbook rm medium right $s $d) (adobe rpncr $s $d 0))
-    ((new-century-schoolbook rm medium slanted $s $d) (adobe rpncri $s $d 0))
-    ((new-century-schoolbook rm medium italic $s $d) (adobe rpncri $s $d 0))
-    ((new-century-schoolbook rm bold right $s $d) (adobe rpncb $s $d 0))
-    ((new-century-schoolbook rm bold slanted $s $d) (adobe rpncbi $s $d 0))
-    ((new-century-schoolbook rm bold italic $s $d) (adobe rpncbi $s $d 0))
+    ((new-century-schoolbook rm medium right $s $d) (ec nc-schoolbook-rm $s $d))
+    ((new-century-schoolbook rm medium slanted $s $d) (ec nc-schoolbook-ti $s $d))
+    ((new-century-schoolbook rm medium italic $s $d) (ec nc-schoolbook-ti $s $d))
+    ((new-century-schoolbook rm bold right $s $d) (ec nc-schoolbook-bx $s $d))
+    ((new-century-schoolbook rm bold slanted $s $d) (ec nc-schoolbook-bx $s $d))
+    ((new-century-schoolbook rm bold italic $s $d) (ec nc-schoolbook-bi $s $d))
+    ((new-century-schoolbook ss $series $shape $s $d) (helvetica rm $series $shape $s $d))
+    ((new-century-schoolbook tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
-    ((palatino rm medium right $s $d) (adobe rpplr $s $d 0))
-    ((palatino rm medium slanted $s $d) (adobe rpplro $s $d 0))
-    ((palatino rm medium italic $s $d) (adobe rpplri $s $d 0))
-    ((palatino rm medium italic-right $s $d) (adobe rpplru $s $d 0))
-    ((palatino rm medium condensed $s $d) (adobe rpplrrn $s $d 0))
-    ((palatino rm medium wide $s $d) (adobe rpplrre $s $d 0))
-    ((palatino rm bold right $s $d) (adobe rpplb $s $d 0))
-    ((palatino rm bold slanted $s $d) (adobe rpplbi $s $d 0))
-    ((palatino rm bold italic $s $d) (adobe rpplbi $s $d 0))
-    ((palatino rm bold italic-right $s $d) (adobe rpplbu $s $d 0))
+    ((palatino rm medium right $s $d) (ec palatino-rm $s $d))
+    ((palatino rm medium slanted $s $d) (ec palatino-sl $s $d))
+    ((palatino rm medium italic $s $d) (ec palatino-ti $s $d))
+    ((palatino rm medium small-caps $s $d) (ec palatino-cc $s $d))
+    ((palatino rm bold right $s $d) (ec palatino-bx $s $d))
+    ((palatino rm bold slanted $s $d) (ec palatino-bl $s $d))
+    ((palatino rm bold italic $s $d) (ec palatino-bi $s $d))
+    ((palatino rm bold small-caps $s $d) (ec palatino-xc $s $d))
     ((palatino ss $series $shape $s $d) (helvetica rm $series $shape $s $d))
     ((palatino tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
-    ((times rm medium right $s $d) (adobe rptmr $s $d 0))
-    ((times rm medium slanted $s $d) (adobe rptmro $s $d 0))
-    ((times rm medium italic $s $d) (adobe rptmri $s $d 0))
-    ((times rm medium condensed $s $d) (adobe rptmrrn $s $d 0))
-    ((times rm medium wide $s $d) (adobe rptmrre $s $d 0))
-    ((times rm bold right $s $d) (adobe rptmb $s $d 0))
-    ((times rm bold slanted $s $d) (adobe rptmbo $s $d 0))
-    ((times rm bold italic $s $d) (adobe rptmbi $s $d 0))
+    ((times rm medium right $s $d) (ec times-rm $s $d))
+    ((times rm medium slanted $s $d) (ec times-sl $s $d))
+    ((times rm medium italic $s $d) (ec times-ti $s $d))
+    ((times rm medium small-caps $s $d) (ec times-cc $s $d))
+    ((times rm bold right $s $d) (ec times-bx $s $d))
+    ((times rm bold slanted $s $d) (ec times-bl $s $d))
+    ((times rm bold italic $s $d) (ec times-bi $s $d))
+    ((times rm bold small-caps $s $d) (ec times-xc $s $d))
     ((times ss $series $shape $s $d) (helvetica rm $series $shape $s $d))
     ((times tt $series $shape $s $d) (courier rm $series $shape $s $d))
 
+    ;; old style
+    ((helvetica rm medium condensed $s $d) (adobe rphvrrn $s $d 0))
+    ((helvetica rm medium slanted-condensed $s $d) (adobe rphvron $s $d 0))
+    ((helvetica rm medium italic-condensed $s $d) (adobe rphvron $s $d 0))
+    ((helvetica rm bold condensed $s $d) (adobe rphvbrn $s $d 0))
+    ((helvetica rm bold slanted-condensed $s $d) (adobe rphvbon $s $d 0))
+    ((helvetica rm bold italic-condensed $s $d) (adobe rphvbon $s $d 0))
+
+    ((palatino rm medium italic-right $s $d) (adobe rpplru $s $d 0))
+    ((palatino rm medium condensed $s $d) (adobe rpplrrn $s $d 0))
+    ((palatino rm medium wide $s $d) (adobe rpplrre $s $d 0))
+    ((palatino rm bold italic-right $s $d) (adobe rpplbu $s $d 0))
+
+    ((times rm medium condensed $s $d) (adobe rptmrrn $s $d 0))
+    ((times rm medium wide $s $d) (adobe rptmrre $s $d 0))
+
     ((chancery rm $a $b $s $d) (adobe rpzcmi $s $d 0))
     ((chancellary rm $a $b $s $d) (adobe rpzcmi $s $d 0))
     ((dingbat rm $a $b $s $d) (adobe rpzdr $s $d 0))))
@@ -116,6 +131,8 @@
 	      (tex-rubber rubber-stmary stmary $s $d)
 	      (tex-rubber rubber-wasy wasy $s $d)
 	      (tex-dummy-rubber (tex-rubber rubber-cmex $cmex $s $d)))
+      ;;(ec times-rm $s $d)
+      ;;(ec times-rm $s $d)))
       (adobe rptmr $s $d 0)
       (adobe rptmr $s $d 0)))
 
@@ -147,5 +164,7 @@
 	      (tex-rubber rubber-stmary stmaryb $s $d)
 	      (tex-rubber rubber-wasy wasyb $s $d)
 	      (tex-dummy-rubber (tex-rubber rubber-cmex $cmex $s $d)))
+      ;;(ec times-bx $s $d)
+      ;;(ec times-bx $s $d)))))
       (adobe rptmb $s $d 0)
       (adobe rptmb $s $d 0)))))
