@@ -12,9 +12,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (generic generic-edit)
-  (:use (utils library tree)
-	(utils library cursor)
-	(utils edit variants)))
+  (:use (utils library tree) (utils library cursor) (utils edit variants)
+        (bibtex bib-complete)))
 
 (tm-define (generic-context? t) #t) ;; overridden in, e.g., graphics mode
 
@@ -115,13 +114,21 @@
   (:require (tree-is-buffer? t))
   (if (and (not (complete-try?)) forwards?)
       (with sh (kbd-system-rewrite (kbd-find-inv-binding '(make-htab "5mm")))
-	(set-message `(concat "Use " ,sh " in order to insert a tab")
-		     "tab"))))
+        (set-message `(concat "Use " ,sh " in order to insert a tab")
+                     "tab"))))
 
 (tm-define (kbd-variant t forwards?)
   (:require (and (tree-in? t '(label reference pageref)) (cursor-inside? t)))
   (if (complete-try?) (noop)))
 
+(tm-define (kbd-variant t forwards?)
+  (:require (and (tree-in? t '(cite nocite cite-detail)) (cursor-inside? t)))
+  (with u (current-bib-file)
+    (with ttxt (tree-ref t (cADr (cursor-path)))
+      (if (or (url-none? u) (not ttxt))
+          (set-message "No completions" "You must add a bibliography file")
+          (custom-complete (tm->tree (citekey-completions u ttxt)))))))
+
 (tm-define (kbd-return)
   (kbd-enter (focus-tree) #f))
 (tm-define (kbd-shift-return)
@@ -149,7 +156,7 @@
 (tm-define (simple-context? t)
   (or (leaf? t)
       (and (tree-in? t (simple-tags))
-	   (simple-context? (tree-down t)))))
+           (simple-context? (tree-down t)))))
 
 (tm-define (document-context? t)
   (tree-is? t 'document))
@@ -463,13 +470,13 @@
   (apply tree-go-to l)
   (if (tree-is? (cursor-tree) 'tree)
       (with last (cAr l)
-	(if (nin? last '(:start :end)) (set! last :start))
-	(tree-go-to (cursor-tree) 0 last))))
+        (if (nin? last '(:start :end)) (set! last :start))
+        (tree-go-to (cursor-tree) 0 last))))
 
 (tm-define (structured-horizontal t* forwards?)
   (:require (tree-is? t* 'tree))
   (let* ((t (branch-active t*))
-	 (i (tree-down-index t)))
+         (i (tree-down-index t)))
     (cond ((and (not forwards?) (> i 1))
            (branch-go-to t (- i 1) :end))
           ((and forwards? (!= i 0) (< i (- (tree-arity t) 1)))
@@ -478,7 +485,7 @@
 (tm-define (structured-vertical t* downwards?)
   (:require (tree-is? t* 'tree))
   (let* ((t (branch-active t*))
-	 (i (tree-down-index t)))
+         (i (tree-down-index t)))
     (cond ((and (not downwards?) (!= i 0))
            (tree-go-to t 0 :end))
           ((and downwards? (== (tree-down-index t*) 0))
@@ -487,7 +494,7 @@
 (tm-define (structured-extremal t* forwards?)
   (:require (tree-is? t* 'tree))
   (let* ((t (branch-active t*))
-	 (i (tree-down-index t)))
+         (i (tree-down-index t)))
     (cond ((not forwards?)
            (branch-go-to t 1 :start))
           (forwards?
@@ -507,9 +514,39 @@
   (selection-set-end)
   (clipboard-cut "primary"))
 
+(tm-define (yank-paragraph)
+  (selection-set-start)
+  (go-end-paragraph)
+  (selection-set-end)
+  (clipboard-copy "primary"))
+
 (tm-define (select-all)
   (tree-select (buffer-tree)))
 
+(tm-define (go-to-line n . opt-from)
+  (if (nnull? opt-from) (cursor-history-add (car opt-from)))
+  (with-innermost t 'document
+    (tree-go-to t n 0)))
+
+(tm-define (go-to-column c . opt-from)
+  (if (nnull? opt-from) (cursor-history-add (car opt-from)))
+  (with-innermost t 'document
+    (with p (tree-cursor-path t)
+      (tree-go-to t (cADr p) c))))
+
+(tm-define (select-word w t col)
+  (:synopsis "Selects word @w in tree @t, more or less around column @col.")
+  (let* ((st (tree->string t))
+         (pos (- col (string-length w)))
+         (beg (string-contains st w (max 0 pos))))
+    (if beg
+        (with p (tree->path t)
+          (go-to (rcons p beg))
+          (selection-set-start)
+          (go-to (rcons p (+ beg (string-length w))))
+          (selection-set-end)))
+    beg))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Inserting various kinds of content
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -555,12 +592,12 @@
 
 (define (thumbnail-suffixes)
   (list->url (map url-wildcard
-		  '("*.gif" "*.jpg" "*.jpeg" "*.JPG" "*.JPEG"))))
+                  '("*.gif" "*.jpg" "*.jpeg" "*.JPG" "*.JPEG"))))
 
 (define (fill-row l nr)
   (cond ((= nr 0) '())
-	((nnull? l) (cons (car l) (fill-row (cdr l) (- nr 1))))
-	(else (cons "" (fill-row l (- nr 1))))))
+        ((nnull? l) (cons (car l) (fill-row (cdr l) (- nr 1))))
+        (else (cons "" (fill-row l (- nr 1))))))
 
 (define (make-rows l nr)
   (if (> (length l) nr)
@@ -571,20 +608,20 @@
   (define (mapper x)
     `(image ,(url->delta-unix x) "0.22par" "" "" ""))
   (let* ((l1 (map mapper l))
-	 (l2 (make-rows l1 4))
-	 (l3 (map (lambda (r) `(row ,@(map (lambda (c) `(cell ,c)) r))) l2)))
+         (l2 (make-rows l1 4))
+         (l3 (map (lambda (r) `(row ,@(map (lambda (c) `(cell ,c)) r))) l2)))
     (insert `(tabular* (tformat (twith "table-width" "1par")
-				(twith "table-hyphen" "yes")
-				(table ,@l3))))))
+                                (twith "table-hyphen" "yes")
+                                (table ,@l3))))))
 
 (tm-define (make-thumbnails)
   (:interactive #t)
   (user-url "Picture directory" "directory" 
    (lambda (dir) 
      (let* ((find (url-append dir (thumbnail-suffixes)))
-	          (files (url->list (url-expand (url-complete find "r"))))
-	          (base (buffer-master))
-	          (rel-files (map (lambda (x) (url-delta base x)) files)))
+                  (files (url->list (url-expand (url-complete find "r"))))
+                  (base (buffer-master))
+                  (rel-files (map (lambda (x) (url-delta base x)) files)))
            (if (nnull? rel-files) (make-thumbnails-sub rel-files))))))
    
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -595,13 +632,13 @@
   (:synopsis "Make an insertion of type @s.")
   (with pos (if (== s "float") "tbh" "")
     (insert-go-to (list 'float s pos (list 'document ""))
-		  (list 2 0 0))))
+                  (list 2 0 0))))
 
 (tm-define (insertion-positioning what flag)
   (:synopsis "Allow/disallow the position @what for innermost float.")
   (with-innermost t 'float
     (let ((op (if flag string-union string-minus))
-	  (st (tree-ref t 1)))
+          (st (tree-ref t 1)))
       (tree-set! st (op (tree->string st) what)))))
 
 (define (test-insertion-positioning? what)
@@ -631,8 +668,8 @@
 (tm-define (make-animation u)
   (interactive
       (lambda (w h len rep)
-	(if (== rep "no") (set! rep "false"))
-	(insert `(video ,(url->delta-unix u) ,w ,h ,len ,rep)))
+        (if (== rep "no") (set! rep "false"))
+        (insert `(video ,(url->delta-unix u) ,w ,h ,len ,rep)))
     "Width" "Height" "Length" "Repeat?"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -651,8 +688,8 @@
   (:mode search-mode?)
   (with cmd (key-press-command (string-append "search " key))
     (cond (cmd (cmd))
-	  ((key-press-search key) (noop))
-	  (else (key-press key)))))
+          ((key-press-search key) (noop))
+          (else (key-press key)))))
 
 (tm-define (search-next)
   (key-press-search "next"))
@@ -664,28 +701,28 @@
   (:mode replace-mode?)
   (with cmd (key-press-command (string-append "replace " key))
     (cond (cmd (cmd))
-	  ((key-press-replace key) (noop))
-	  (else (key-press key)))))
+          ((key-press-replace key) (noop))
+          (else (key-press key)))))
 
 (tm-define (keyboard-press key time)
   (:mode spell-mode?)
   (with cmd (key-press-command (string-append "spell " key))
     (cond (cmd (cmd))
-	  ((key-press-spell key) (noop))
-	  (else (key-press key)))))
+          ((key-press-spell key) (noop))
+          (else (key-press key)))))
 
 (tm-define (keyboard-press key time)
   (:mode complete-mode?)
   (with cmd (key-press-command (string-append "complete " key))
     (cond (cmd (cmd))
-	  ((key-press-complete key) (noop))
-	  (else (key-press key)))))
+          ((key-press-complete key) (noop))
+          (else (key-press key)))))
 
 (tm-define (keyboard-press key time)
   (:mode remote-control-mode?)
   ;;(display* "Press " key "\n")
   (if (ahash-ref remote-control-remap key)
       (begin
-	;;(display* "Remap " (ahash-ref remote-control-remap key) "\n")
-	(key-press (ahash-ref remote-control-remap key)))
+        ;;(display* "Remap " (ahash-ref remote-control-remap key) "\n")
+        (key-press (ahash-ref remote-control-remap key)))
       (key-press key)))
