@@ -136,8 +136,9 @@
       (glue #f #f 3 0)
       (mini #t (group (eval s))))
     (when active?
-      (input (when answer (tree-set (focus-tree) i answer)) fm
-	     (list in) w))))
+      (mini #t
+        (input (when answer (tree-set (focus-tree) i answer)) fm
+  	     (list in) w)))))
 
 (tm-menu (string-input-menu t i)
   (let* ((name (tree-child-long-name* t i))
