@@ -27,6 +27,7 @@
 	  (choosing #f)
 	  (sticky-point #f)
 	  (dragging-create? #f)
+	  (dragging-busy? #f)
 	  (leftclick-waiting #f)
 	  (current-point-no #f)
 	  (current-edge-sel? #f)
@@ -91,6 +92,7 @@
     (state-set! st 'choosing choosing)
     (state-set! st 'sticky-point sticky-point)
     (state-set! st 'dragging-create? dragging-create?)
+    (state-set! st 'dragging-busy? dragging-busy?)
     (state-set! st 'leftclick-waiting leftclick-waiting)
     (state-set! st 'current-obj current-obj)
     (state-set! st 'current-point-no current-point-no)
@@ -117,6 +119,7 @@
   (set! choosing (state-ref st 'choosing))
   (set! sticky-point (state-ref st 'sticky-point))
   (set! dragging-create? (state-ref st 'dragging-create?))
+  (set! dragging-busy? (state-ref st 'dragging-busy?))
   (set! leftclick-waiting (state-ref st 'leftclick-waiting))
   (set! current-obj (state-ref st 'current-obj))
   (set! current-point-no (state-ref st 'current-point-no))
@@ -186,6 +189,7 @@
   (set! choosing #f)
   (set! sticky-point #f)
   (set! dragging-create? #f)
+  (set! dragging-busy? #f)
   (set! leftclick-waiting #f)
   (set! current-obj #f)
   (set! current-point-no #f)
@@ -453,6 +457,7 @@
 	  (set! choosing #f)
 	  (set! sticky-point #f)
 	  (set! dragging-create? #f)
+	  (set! dragging-busy? #f)
 	  (set! current-point-no #f)
 	  (set! graphics-undo-enabled #t)
 	  (set! remove-undo-mark? #f)
