@@ -14,6 +14,15 @@
 (texmacs-module (kernel gui kbd-handlers)
   (:use (kernel texmacs tm-define)))
 
+(tm-define ShiftMask     256)
+(tm-define LockMask      512)
+(tm-define ControlMask  1024)
+(tm-define Mod1Mask     2048)
+(tm-define Mod2Mask     4096)
+(tm-define Mod3Mask     8192)
+(tm-define Mod4Mask    16384)
+(tm-define Mod5Mask    32768)
+
 (tm-define (keyboard-press key time)
   (key-press key))
 
@@ -21,4 +30,5 @@
   (noop))
 
 (tm-define (mouse-event key x y mods time)
-  (mouse-any key x y mods time))
+  ;;(display* "mouse-event " key ", " x ", " y ", " mods ", " time "\n")
+  (mouse-any key x y mods (+ time 0.0)))
