@@ -21,16 +21,19 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define-regexp-grammar
-  (:menu-label (:or
+  (:translatable? (:or
     :string?
     (concat :*)
-    (color :%5)
     (verbatim :%1)
     (text :tuple? :string?)
+    (replace :string? :translatable?)))
+  (:menu-label (:or
+    :translatable?
+    (color :%5)
     (icon :string?)
     (extend :menu-label :*)
     (style :integer? :menu-label)
-    (balloon :menu-label :string?)))
+    (balloon :menu-label :translatable?)))
   (:menu-wide-label (:or
     :menu-label
     (check :menu-wide-label :string? :%1)
@@ -38,18 +41,19 @@
   (:menu-item (:or
     ---
     |
-    (group :string?)
-    (text :string?)
+    (group :%1)
+    (text :%1)
     (glue :boolean? :boolean? :integer? :integer?)
     (color :%1 :boolean? :boolean? :integer? :integer?)
     (:menu-wide-label :%1)
     (symbol :string? :*)
-    (texmacs-output :%1)
-    (texmacs-input :%3)
+    (texmacs-output :%2)
+    (texmacs-input :%4)
     (input :%1 :string? :%1 :string?)
     (enum :%3 :string?)
     (choice :%3)
     (choices :%3)
+    (filtered-choice :%4)
     (toggle :%2)
     (horizontal :menu-item-list)
     (vertical :menu-item-list)
@@ -59,6 +63,8 @@
     (aligned-item :%2)
     (tabs :menu-item-list)
     (tab :menu-item-list)
+    (icon-tabs :menu-item-list)
+    (icon-tab :menu-item-list)
     (minibar :menu-item-list)
     (extend :menu-item :menu-item-list)
     (style :integer? :menu-item-list)
@@ -97,9 +103,9 @@
 
 (define-macro (make-menu-command cmd)
   `(delay-command (lambda ()
-		    (menu-before-action)
-		    ,cmd
-		    (menu-after-action))))
+                    (menu-before-action)
+                    ,cmd
+                    (menu-after-action))))
 
 (define (menu-protect cmd)
   (lambda x
@@ -111,8 +117,8 @@
 
 (define (kbd-system shortcut menu-flag?)
   (cond ((nstring? shortcut) "")
-	((and (qt-gui?) menu-flag?) shortcut)
-	(else (translate (kbd-system-rewrite shortcut)))))
+        ((and (qt-gui?) menu-flag?) shortcut)
+        (else (translate (kbd-system-rewrite shortcut)))))
 
 (define (kbd-find-shortcut what menu-flag?)
   (with r (kbd-find-inv-binding what)
@@ -124,6 +130,7 @@
       (set! r (string-replace r "accent:umlaut" "\""))
       (set! r (string-replace r "accent:abovedot" "."))
       (set! r (string-replace r "accent:breve" "U"))
+      (set! r (string-replace r "accent:invbreve" "A"))
       (set! r (string-replace r "accent:check" "C")))
     ;;(when (!= r "")
     ;;  (display* what " -> " r " -> " (kbd-system r menu-flag?) "\n"))
@@ -134,7 +141,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (translatable? s)
-  (or (string? s) (func? s 'concat) (func? s 'verbatim)))
+  (or (string? s) (func? s 'concat) (func? s 'verbatim) (func? s 'replace)))
 
 (define (active? style)
   (== (logand style widget-style-inert) 0))
@@ -157,25 +164,25 @@
   ;;   <label> :: (icon <string>)
   ;;     Pixmap menu label, the <string> is the name of the pixmap.
   (let ((tt? (and (nnull? opt) (car opt)))
-	(col (color (if (greyed? style) "dark grey" "black"))))
-    (cond ((translatable? p)		; "text"
-	   (widget-text (translate p) style col #t))
-  	  ((tuple? p 'balloon 2)        ; (balloon <label> "balloon text")
-  	   (make-menu-label (cadr p) style tt?))
-  	  ((tuple? p 'extend)		; (extend <label> . ws)
+        (col (color (if (greyed? style) "dark grey" "black"))))
+    (cond ((translatable? p)            ; "text"
+           (widget-text (translate p) style col #t))
+          ((tuple? p 'balloon 2)        ; (balloon <label> "balloon text")
+           (make-menu-label (cadr p) style tt?))
+          ((tuple? p 'extend)           ; (extend <label> . ws)
            (with l (make-menu-items (cddr p) style tt?)
              (widget-extend (make-menu-label (cadr p) style tt?) l)))
-  	  ((tuple? p 'style 2)		; (style st <label>)
+          ((tuple? p 'style 2)          ; (style st <label>)
            (let* ((x (cadr p))
                   (new-style (if (> x 0) (logior style x)
                                  (logand style (lognot (- x))))))
              (make-menu-label (caddr p) new-style tt?)))
-  	  ((tuple? p 'text 2)		; (text <font desc> "text")
-	   (widget-box (cadr p) (caddr p) col #t #t))
-  	  ((tuple? p 'icon 1)		; (icon "name.xpm")
-  	   (widget-xpm (cadr p)))
-  	  ((tuple? p 'color 5)		; (color col hext? vext? minw minh)
-  	   (widget-color (second p) (third p) (fourth p)
+          ((tuple? p 'text 2)           ; (text <font desc> "text")
+           (widget-box (cadr p) (caddr p) col #t #t))
+          ((tuple? p 'icon 1)           ; (icon "name.xpm")
+           (widget-xpm (cadr p)))
+          ((tuple? p 'color 5)          ; (color col hext? vext? minw minh)
+           (widget-color (second p) (third p) (fourth p)
                          (* (fifth p) 256) (* (sixth p) 256))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -200,28 +207,29 @@
 
 (define (make-menu-group s style)
   "Make @(group :string?) menu item."
-  (widget-menu-group s style))
+  (widget-menu-group (translate s) style))
 
 (define (make-menu-text s style)
   "Make @(text :string?) menu item."
   ;;(widget-text s style (color "black") #t)
-  (widget-text s style (color "black") #f))
+  (widget-text (translate s) style (color "black") #f))
 
 (define (make-texmacs-output p style)
-  "Make @(texmacs-output :%1) item."
-  (with (tag t) p
-    (widget-texmacs-output (t))))
+  "Make @(texmacs-output :%2) item."
+  (with (tag t tmstyle) p
+    (widget-texmacs-output (t) (tmstyle))))
 
 (define (make-texmacs-input p style)
-  "Make @(texmacs-input :%3) item."
-  (with (tag t cmd cont?) p
-    (widget-texmacs-input (t) (object->command (menu-protect cmd)) cont?)))
+  "Make @(texmacs-input :%4) item."
+  (with (tag t tmstyle cmd cont?) p
+    (widget-texmacs-input (t) (tmstyle) (object->command (menu-protect cmd))
+                          cont?)))
 
 (define (make-menu-input p style)
   "Make @(input :%1 :string? :%1 :string?) menu item."
   (with (tag cmd type props width) p
     (widget-input (object->command (menu-protect cmd)) type (props)
-		  (logior style widget-style-mini) width)))
+                  style width)))
 
 (define (make-enum p style)
   "Make @(enum :%3 :string?) item."
@@ -239,6 +247,12 @@
   (with (tag cmd vals mc) p
     (widget-choices (object->command (menu-protect cmd)) (vals) (mc))))
 
+(define (make-filtered-choice p style)
+  "Make @(filtered-choice :%4) item."
+  (with (tag cmd vals val filterstr) p
+    (widget-filtered-choice (object->command (menu-protect cmd)) (vals) (val)
+                            (filterstr))))
+
 (define (make-toggle p style)
   "Make @(toggle :%2) item."
   (with (tag cmd on) p
@@ -250,65 +264,65 @@
 
 (define (make-menu-entry-button style bar? check label short command)
   (let* ((l (make-menu-label label style))
-	 (pressed? (and bar? (!= check "")))
-	 (new-style (logior style (if pressed? widget-style-pressed 0))))
+         (pressed? (and bar? (!= check "")))
+         (new-style (logior style (if pressed? widget-style-pressed 0))))
     (if bar?
-	(widget-menu-button l command "" "" new-style)
-	(widget-menu-button l command check short style))))
+        (widget-menu-button l command "" "" new-style)
+        (widget-menu-button l command check short style))))
 
 (define-public (promise-source action)
   "Helper routines for menu-widget and kbd-define"
   (and (procedure? action)
        (with source (procedure-source action)
-	 (and (== (car source) 'lambda)
-	      (== (cadr source) '())
-	      (null? (cdddr source))
-	      (caddr source)))))
+         (and (== (car source) 'lambda)
+              (== (cadr source) '())
+              (null? (cdddr source))
+              (caddr source)))))
 
 (define (make-menu-entry-shortcut label action opt-key)
   (cond (opt-key (kbd-system opt-key #t))
-	((pair? label) "")
-	(else (with source (promise-source action)
-		(if source (kbd-find-shortcut source #t) "")))))
+        ((pair? label) "")
+        (else (with source (promise-source action)
+                (if source (kbd-find-shortcut source #t) "")))))
 
 (define (make-menu-entry-check-sub result propose)
   (cond ((string? result) result)
-	(result propose)
-	(else "")))
+        (result propose)
+        (else "")))
 
 (define (make-menu-entry-check opt-check action)
   (if opt-check
       (make-menu-entry-check-sub ((cadr opt-check)) (car opt-check))
       (with source (promise-source action)
-	(cond ((not (and source (pair? source))) "")
-	      (else (with prop (property (car source) :check-mark)
-		      (make-menu-entry-check-sub
-		       (and prop (apply (cadr prop) (cdr source)))
-		       (and prop (car prop)))))))))
+        (cond ((not (and source (pair? source))) "")
+              (else (with prop (property (car source) :check-mark)
+                      (make-menu-entry-check-sub
+                       (and prop (apply (cadr prop) (cdr source)))
+                       (and prop (car prop)))))))))
 
 (define (menu-label-add-dots l)
   (cond ((match? l ':string?) (string-append l "..."))
-	((match? l '(concat :*))
-	 `(,@(cDr l) ,(menu-label-add-dots (cAr l))))
-	((match? l '(verbatim :*))
-	 `(,@(cDr l) ,(menu-label-add-dots (cAr l))))
-	((match? l '(text :tuple? :string?))
-	 `(text ,(cadr l) ,(string-append (caddr l) "...")))
-	((match? l '(icon :string?)) l)
-	(else `(,(car l) ,(menu-label-add-dots (cadr l)) ,(caddr l)))))
+        ((match? l '(concat :*))
+         `(,@(cDr l) ,(menu-label-add-dots (cAr l))))
+        ((match? l '(verbatim :*))
+         `(,@(cDr l) ,(menu-label-add-dots (cAr l))))
+        ((match? l '(text :tuple? :string?))
+         `(text ,(cadr l) ,(string-append (caddr l) "...")))
+        ((match? l '(icon :string?)) l)
+        (else `(,(car l) ,(menu-label-add-dots (cadr l)) ,(caddr l)))))
 
 (define (make-menu-entry-dots label action)
   (with source (promise-source action)
     (if (and source (pair? source) (property (car source) :interactive))
-	(menu-label-add-dots label)
-	label)))
+        (menu-label-add-dots label)
+        label)))
 
 (define (make-menu-entry-attrs label action opt-key opt-check)
   (cond ((match? label '(shortcut :%1 :string?))
-	 (make-menu-entry-attrs (cadr label) action (caddr label) opt-check))
-	((match? label '(check :%1 :string? :%1))
-	 (make-menu-entry-attrs (cadr label) action opt-key (cddr label)))
-	(else (values label action opt-key opt-check))))
+         (make-menu-entry-attrs (cadr label) action (caddr label) opt-check))
+        ((match? label '(check :%1 :string? :%1))
+         (make-menu-entry-attrs (cadr label) action opt-key (cddr label)))
+        (else (values label action opt-key opt-check))))
 
 (define (make-menu-entry-sub p style bar?)
   (receive
@@ -324,18 +338,20 @@
 (define (make-menu-entry p style bar?)
   "Make @:menu-wide-item menu item."
   (let ((but (make-menu-entry-sub p style bar?))
-	(label (car p)))
+        (label (car p)))
     (if (tuple? label 'balloon 2)
-	(let* ((text (caddr label))
-	       (cmd (and (nnull? (cdr p)) (procedure? (cadr p)) (cadr p)))
-	       (src (and cmd (promise-source cmd)))
-	       (sh (and src (kbd-find-shortcut src #f)))
-	       (txt (if (or (not sh) (== sh "")) text
-			(string-append text " (" sh ")")))
-	       (ftxt (translate txt))
-	       (twid (widget-text ftxt style (color "black") #t)))
-	  (widget-balloon but twid))
-	but)))
+        (let* ((text (caddr label))
+               (cmd (and (nnull? (cdr p)) (procedure? (cadr p)) (cadr p)))
+               (src (and cmd (promise-source cmd)))
+               (sh (and src (kbd-find-shortcut src #f)))
+               (txt (if (or (not sh) (== sh "")) text
+                        (if (string? text) 
+                            (string-append text " (" sh ")")
+                            text)))
+               (ftxt (translate txt))
+               (twid (widget-text ftxt style (color "black") #t)))
+          (widget-balloon but twid))
+        but)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Symbol fields
@@ -344,12 +360,12 @@
 (define (make-menu-symbol-button style sym opt-cmd)
   (with col (color (if (greyed? style) "dark grey" "black"))
     (if opt-cmd
-	(widget-menu-button (widget-box '() sym col #t #f)
-			    (make-menu-command (apply opt-cmd '()))
-			    "" "" style)
-	(widget-menu-button (widget-box '() sym col #t #f)
-			    (make-menu-command (insert sym))
-			    "" "" style))))
+        (widget-menu-button (widget-box '() sym col #t #f)
+                            (make-menu-command (apply opt-cmd '()))
+                            "" "" style)
+        (widget-menu-button (widget-box '() sym col #t #f)
+                            (make-menu-command (insert sym))
+                            "" "" style))))
 
 (define (make-menu-symbol p style)
   "Make @(symbol :string? :*) menu item."
@@ -358,15 +374,15 @@
   (with (tag symstring . opt) p
     (with opt-cmd (and (nnull? opt) (car opt))
       (if (and opt-cmd (not (procedure? opt-cmd)))
-	  (make-menu-error "invalid symbol command in " p)
-	  (let* ((source (and opt-cmd (promise-source opt-cmd)))
-		 (sh (kbd-find-shortcut (if source source symstring) #f)))
-	    (if (== sh "")
-		(make-menu-symbol-button style symstring opt-cmd)
-		(widget-balloon
-		 (make-menu-symbol-button style symstring opt-cmd)
-		 (make-menu-label (string-append "Keyboard equivalent: " sh)
-				  style))))))))
+          (make-menu-error "invalid symbol command in " p)
+          (let* ((source (and opt-cmd (promise-source opt-cmd)))
+                 (sh (kbd-find-shortcut (if source source symstring) #f)))
+            (if (== sh "")
+                (make-menu-symbol-button style symstring opt-cmd)
+                (widget-balloon
+                 (make-menu-symbol-button style symstring opt-cmd)
+                 (make-menu-label (string-append "Keyboard equivalent: " sh)
+                                  style))))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Composite menus and submenus
@@ -414,6 +430,27 @@
   (display* "Error 'make-menu-tab', " p ", " style "\n")
   (list 'vlist))
 
+(define (icon-tab-icon x)
+  (string->url (cadr x)))
+
+(define (icon-tab-key x)
+  (caddr x))
+
+(define (icon-tab-value x)
+  (list 'vlist (cdddr x)))
+
+(define (make-menu-icon-tabs p style)
+  "Make @(icon-tabs :menu-item-list) menu item."
+  (with style* (logior style widget-style-mini)
+    (widget-icon-tabs (map icon-tab-icon (cdr p))
+                      (make-menu-items (map icon-tab-key (cdr p)) style* #f)
+                      (make-menu-items (map icon-tab-value (cdr p)) style #f))))
+
+(define (make-menu-icon-tab p style)
+  "Make @(icon-tab :menu-item-list) menu item."
+  (display* "Error 'make-menu-icon-tab', " p ", " style "\n")
+  (list 'vlist))
+
 (define (make-menu-extend p style bar?)
   "Make @(extend :menu-item :menu-item-list) menu item."
   (with l (make-menu-items (cdr p) style bar?)
@@ -435,17 +472,17 @@
   "Make @((:or -> =>) :menu-label :menu-item-list) menu item."
   (with (tag label . items) p
     (let ((button
-	   ((cond ((== tag '=>) widget-pulldown-button)
-		  ((== tag '->) widget-pullright-button))
-	    (make-menu-label label style)
-	    (object->promise-widget
-	     (lambda () (make-menu-widget (list 'vertical items) style))))))
+           ((cond ((== tag '=>) widget-pulldown-button)
+                  ((== tag '->) widget-pullright-button))
+            (make-menu-label label style)
+            (object->promise-widget
+             (lambda () (make-menu-widget (list 'vertical items) style))))))
       (if (tuple? label 'balloon 2)
-	  (let* ((text (caddr label))
-		 (ftxt (translate text))
-		 (twid (widget-text ftxt style (color "black") #t)))
-	    (widget-balloon button twid))
-	  button))))
+          (let* ((text (caddr label))
+                 (ftxt (translate text))
+                 (twid (widget-text ftxt style (color "black") #t)))
+            (widget-balloon button twid))
+          button))))
 
 (define (make-menu-tile p style)
   "Make @(tile :integer? :menu-item-list) menu item."
@@ -501,8 +538,8 @@
   "Make @(when :%1 :menu-item-list) menu items."
   (with (tag pred? . items) p
     (let* ((old-active? (== (logand style widget-style-inert) 0))
-	   (new-active? (and old-active? (pred?)))
-	   (new-style (logior style
+           (new-active? (and old-active? (pred?)))
+           (new-style (logior style
                               (if new-active? 0
                                   (+ widget-style-inert widget-style-grey)))))
       (make-menu-items-list items new-style bar?))))
@@ -511,22 +548,22 @@
   "Make @(mini :%1 :menu-item-list) menu items."
   (with (tag pred? . items) p
     (let* ((style-maxi (logand style (lognot widget-style-mini)))
-	   (style-mini (logior style-maxi widget-style-mini))
-	   (new-style (if (pred?) style-mini style-maxi)))
+           (style-mini (logior style-maxi widget-style-mini))
+           (new-style (if (pred?) style-mini style-maxi)))
       (make-menu-items-list items new-style bar?))))
 
 (define (make-menu-link p style bar?)
   "Make @(link :%1) menu items."
   (with linked ((eval (cadr p)))
     (if linked (make-menu-items linked style bar?)
-	(make-menu-error "bad link: " (object->string (cadr p))))))
+        (make-menu-error "bad link: " (object->string (cadr p))))))
 
 (define (make-menu-promise p style bar?)
   "Make @(promise :%1) menu items."
   (with value ((cadr p))
     ;;(make-menu-items value style bar?)
     (if (match? value ':menu-item) (make-menu-items value style bar?)
-	(make-menu-error "promise did not yield a menu: " value))))
+        (make-menu-error "promise did not yield a menu: " value))))
 
 (define (make-refresh p style bar?)
   "Make @(refresh s) widget."
@@ -546,22 +583,22 @@
   ;;(display* "Make items " p ", " style "\n")
   (if (pair? p)
       (cond ((match? p '(input :%1 :string? :%1 :string?))
-	     (list (make-menu-input p style)))
-	    ((translatable? (car p))
-	     (list (make-menu-entry p style bar?)))
-	    ((symbol? (car p))
-	     (with result (ahash-ref make-menu-items-table (car p))
-	       (if (or (not result) (not (match? (cdr p) (car result))))
-		   (make-menu-items-list p style bar?)
-		   ((cadr result) p style bar?))))
-	    ((match? (car p) ':menu-wide-label)
-	     (list (make-menu-entry p style bar?)))
-	    (else
-	     (make-menu-items-list p style bar?)))
+             (list (make-menu-input p style)))
+            ((translatable? (car p))
+             (list (make-menu-entry p style bar?)))
+            ((symbol? (car p))
+             (with result (ahash-ref make-menu-items-table (car p))
+               (if (or (not result) (not (match? (cdr p) (car result))))
+                   (make-menu-items-list p style bar?)
+                   ((cadr result) p style bar?))))
+            ((match? (car p) ':menu-wide-label)
+             (list (make-menu-entry p style bar?)))
+            (else
+             (make-menu-items-list p style bar?)))
       (cond ((== p '---) (list (make-menu-hsep)))
-	    ((== p '|) (list (make-menu-vsep)))
-	    ((== p '()) p)
-	    (else (list (make-menu-bad-format p style))))))
+            ((== p '|) (list (make-menu-vsep)))
+            ((== p '()) p)
+            (else (list (make-menu-bad-format p style))))))
 
 (define-table make-menu-items-table
   (glue (:boolean? :boolean? :integer? :integer?)
@@ -572,15 +609,15 @@
          ,(lambda (p style bar?)
             (list (make-menu-color (second p) (third p)
                                    (fourth p) (fifth p) (sixth p)))))
-  (group (:string?)
-	 ,(lambda (p style bar?) (list (make-menu-group (cadr p) style))))
-  (text (:string?)
-	 ,(lambda (p style bar?) (list (make-menu-text (cadr p) style))))
+  (group (:%1)
+         ,(lambda (p style bar?) (list (make-menu-group (cadr p) style))))
+  (text (:%1)
+         ,(lambda (p style bar?) (list (make-menu-text (cadr p) style))))
   (symbol (:string? :*)
-	  ,(lambda (p style bar?) (list (make-menu-symbol p style))))
-  (texmacs-output (:%1)
+          ,(lambda (p style bar?) (list (make-menu-symbol p style))))
+  (texmacs-output (:%2)
     ,(lambda (p style bar?) (list (make-texmacs-output p style))))
-  (texmacs-input (:%3)
+  (texmacs-input (:%4)
     ,(lambda (p style bar?) (list (make-texmacs-input p style))))
   (input (:%1 :string? :%1 :string?)
          ,(lambda (p style bar?) (list (make-menu-input p style))))
@@ -590,14 +627,16 @@
           ,(lambda (p style bar?) (list (make-choice p style))))
   (choices (:%3)
            ,(lambda (p style bar?) (list (make-choices p style))))
+  (filtered-choice (:%4)
+           ,(lambda (p style bar?) (list (make-filtered-choice p style))))
   (toggle (:%2)
-	  ,(lambda (p style bar?) (list (make-toggle p style))))
+          ,(lambda (p style bar?) (list (make-toggle p style))))
   (link (:%1)
-	,(lambda (p style bar?) (make-menu-link p style bar?)))
+        ,(lambda (p style bar?) (make-menu-link p style bar?)))
   (horizontal (:*)
-	      ,(lambda (p style bar?) (list (make-menu-horizontal p style))))
+              ,(lambda (p style bar?) (list (make-menu-horizontal p style))))
   (vertical (:*)
-	    ,(lambda (p style bar?) (list (make-menu-vertical p style))))
+            ,(lambda (p style bar?) (list (make-menu-vertical p style))))
   (hlist (:*)
          ,(lambda (p style bar?) (list (make-menu-hlist p style))))
   (vlist (:*)
@@ -610,10 +649,14 @@
         ,(lambda (p style bar?) (list (make-menu-tabs p style))))
   (tab (:*)
         ,(lambda (p style bar?) (list (make-menu-tab p style))))
+  (icon-tabs (:*)
+        ,(lambda (p style bar?) (list (make-menu-icon-tabs p style))))
+  (icon-tab (:*)
+        ,(lambda (p style bar?) (list (make-menu-icon-tab p style))))
   (minibar (:*)
-	    ,(lambda (p style bar?) (list (make-menu-minibar p style))))
+            ,(lambda (p style bar?) (list (make-menu-minibar p style))))
   (extend (:%1 :*)
-	  ,(lambda (p style bar?) (list (make-menu-extend p style bar?))))
+          ,(lambda (p style bar?) (list (make-menu-extend p style bar?))))
   (style (:%1 :*)
          ,(lambda (p style bar?) (make-menu-style p style bar?)))
   (-> (:%1 :*)
@@ -621,9 +664,9 @@
   (=> (:%1 :*)
       ,(lambda (p style bar?) (list (make-menu-submenu p style))))
   (tile (:integer? :*)
-	,(lambda (p style bar?) (list (make-menu-tile p style))))
+        ,(lambda (p style bar?) (list (make-menu-tile p style))))
   (scrollable (:*)
-	      ,(lambda (p style bar?) (list (make-scrollable p style))))
+              ,(lambda (p style bar?) (list (make-scrollable p style))))
   (resize (:%2 :*)
       ,(lambda (p style bar?) (list (make-resize p style))))
   (hsplit (:%2)
@@ -639,9 +682,9 @@
   (mini (:%1 :*)
         ,(lambda (p style bar?) (make-menu-mini p style bar?)))
   (promise (:%1)
-	   ,(lambda (p style bar?) (make-menu-promise p style bar?)))
+           ,(lambda (p style bar?) (make-menu-promise p style bar?)))
   (refresh (:%1)
-	   ,(lambda (p style bar?) (make-refresh p style bar?))))
+           ,(lambda (p style bar?) (make-refresh p style bar?))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menu expansion
@@ -661,8 +704,8 @@
   "Expand potentially greyed menu @p."
   (with (tag pred? . items) p
     (if (pred?)
-	(cons* 'when #t (menu-expand-list items))
-	(cons* 'when #f (replace-procedures items)))))
+        (cons* 'when #t (menu-expand-list items))
+        (cons* 'when #f (replace-procedures items)))))
 
 (define (menu-expand-mini p)
   "Expand mini menu @p."
@@ -679,20 +722,21 @@
   "Expand texmacs-input item @p."
   `(texmacs-input ,(replace-procedures (cadr p))
                   ,(replace-procedures (caddr p))
-                  ,(cadddr p)))
+                  ,(replace-procedures (cadddr p))
+                  ,(car (cdddr p))))
 
 (define (menu-expand-texmacs-output p)
-  "Expand conditional menu @p."
-  (with (tag out) p
-    `(texmacs-output ',(out))))
+  "Expand output menu item @p."
+  (with (tag doc tmstyle) p
+    `(texmacs-output ',(doc) ',(tmstyle))))
 
 (define (menu-expand-input p)
   "Expand input menu item @p."
   `(input ,(replace-procedures (cadr p))
           ,(caddr p)
-	  ,(with r ((cadddr p))
-	     (if (pair? r) (car r) (replace-procedures (cadddr p))))
-	  ,(fifth p)))
+          ,(with r ((cadddr p))
+             (if (pair? r) (car r) (replace-procedures (cadddr p))))
+          ,(fifth p)))
 
 (define (menu-expand-enum p)
   "Expand enum item @p."
@@ -704,13 +748,20 @@
 (define (menu-expand-choice p)
   "Expand choice item @p."
   `(,(car p) ,(replace-procedures (cadr p))
-             ,(replace-procedures (caddr p))
-             ,(replace-procedures (cadddr p))))
+             ,(caddr p)
+             ,(cadddr p)))
+
+(define (menu-expand-filtered-choice p)
+  "Expand filtered choice item @p."
+  `(,(car p) ,(replace-procedures (cadr p))
+             ,(caddr p)
+             ,(cadddr p)
+             ,(car (cddddr p))))
 
 (define (menu-expand-toggle p)
   "Expand toggle item @p."
   `(toggle ,(replace-procedures (cadr p))
-	   ,(replace-procedures (caddr p))))
+           ,(replace-procedures (caddr p))))
 
 (define (menu-expand-list l)
   "Expand links and conditional menus in list of menus @l."
@@ -718,28 +769,28 @@
 
 (define (replace-procedures x)
   (cond ((procedure? x) (procedure-source x))
-	((list? x) (map replace-procedures x))
-	(else x)))
+        ((list? x) (map replace-procedures x))
+        (else x)))
 
 (tm-define (menu-expand p)
   (:type (-> object object))
   (:synopsis "Expand links and conditional menus in menu @p.")
   ;;(display* "Expand " p "\n")
   (cond ((npair? p) (replace-procedures p))
-	((string? (car p)) p)
-	((symbol? (car p))
-	 (with result (ahash-ref menu-expand-table (car p))
-	   (if result ((car result) p) p)))
-	((match? (car p) '(check :menu-wide-label :string? :%1))
-	 (with a (cdar p)
-	   (list (list 'check
-		       (menu-expand (car a))
-		       (cadr a)
-		       ((caddr a)))
-		 (replace-procedures (cadr p)))))
-	((match? (car p) ':menu-wide-label)
-	 (replace-procedures p))
-	(else (menu-expand-list p))))
+        ((string? (car p)) p)
+        ((symbol? (car p))
+         (with result (ahash-ref menu-expand-table (car p))
+           (if result ((car result) p) p)))
+        ((match? (car p) '(check :menu-wide-label :string? :%1))
+         (with a (cdar p)
+           (list (list 'check
+                       (menu-expand (car a))
+                       (cadr a)
+                       ((caddr a)))
+                 (replace-procedures (cadr p)))))
+        ((match? (car p) ':menu-wide-label)
+         (replace-procedures p))
+        (else (menu-expand-list p))))
 
 (define-table menu-expand-table
   (--- ,(lambda (p) `(--- ,@(menu-expand-list (cdr p)))))
@@ -755,6 +806,7 @@
   (enum ,menu-expand-enum)
   (choice ,menu-expand-choice)
   (choices ,menu-expand-choice)
+  (filtered-choice ,menu-expand-filtered-choice)
   (toggle ,menu-expand-toggle)
   (link ,menu-expand-link p)
   (horizontal ,(lambda (p) `(horizontal ,@(menu-expand-list (cdr p)))))
@@ -765,6 +817,8 @@
   (aligned-item ,(lambda (p) `(aligned-item ,@(menu-expand-list (cdr p)))))
   (tabs ,(lambda (p) `(tabs ,@(menu-expand-list (cdr p)))))
   (tab ,(lambda (p) `(tab ,@(menu-expand-list (cdr p)))))
+  (icon-tabs ,(lambda (p) `(icon-tabs ,@(menu-expand-list (cdr p)))))
+  (icon-tab ,(lambda (p) `(icon-tab ,@(menu-expand-list (cdr p)))))
   (minibar ,(lambda (p) `(minibar ,@(menu-expand-list (cdr p)))))
   (extend ,(lambda (p) `(extend ,@(menu-expand-list (cdr p)))))
   (style ,(lambda (p) `(extend ,@(menu-expand-list (cdr p)))))
@@ -790,8 +844,8 @@
   "Transform the menu @p into a widget."
   (with l (make-menu-items p style #f)
     (cond ((null? l) (make-menu-empty))
-	  ((and (list? l) (null? (cdr l))) (car l))
-	  (else (make-menu-bad-format p style)))))
+          ((and (list? l) (null? (cdr l))) (car l))
+          (else (make-menu-bad-format p style)))))
 
 (tm-define (make-menu-widget p style)
   (:synopsis "Transform a menu into a widget.")
@@ -802,21 +856,21 @@
 (tm-define (top-window menu-promise name)
   (:interactive #t)
   (let* ((win (alt-window-handle))
-	 (qui (object->command (lambda () (alt-window-delete win))))
-	 (men (menu-promise))
-	 (scm (list 'vertical men))
-	 (wid (make-menu-widget scm 0)))
+         (qui (object->command (lambda () (alt-window-delete win))))
+         (men (menu-promise))
+         (scm (list 'vertical men))
+         (wid (make-menu-widget scm 0)))
     (alt-window-create-quit win wid name qui)
     (alt-window-show win)))
 
 (tm-define (dialogue-window menu-promise cmd name)
   (:interactive #t)
   (let* ((win (alt-window-handle))
-	 (qui (object->command (lambda () (alt-window-delete win))))
-	 (lbd (lambda x (apply cmd x) (alt-window-delete win)))
-	 (men (menu-promise lbd))
-	 (scm (list 'vertical men))
-	 (wid (make-menu-widget scm 0)))
+         (qui (object->command (lambda () (alt-window-delete win))))
+         (lbd (lambda x (apply cmd x) (alt-window-delete win)))
+         (men (menu-promise lbd))
+         (scm (list 'vertical men))
+         (wid (make-menu-widget scm 0)))
     (alt-window-create-quit win wid name qui)
     (alt-window-show win)))
 
@@ -827,9 +881,9 @@
 (tm-define (interactive-window wid-promise cmd name)
   (:interactive #t)
   (let* ((win (alt-window-handle))
-	 (lbd (lambda x (apply cmd x) (alt-window-delete win)))
-	 (com (object->command (menu-protect lbd)))
-	 (wid (wid-promise com)))
+         (lbd (lambda x (apply cmd x) (alt-window-delete win)))
+         (com (object->command (menu-protect lbd)))
+         (wid (wid-promise com)))
     (alt-window-create win wid name #t)
     (alt-window-show win)))
 
