@@ -5,10 +5,9 @@
 ;; DESCRIPTION : extra routines for lists
 ;; COPYRIGHT   : (C) 2002  Joris van der Hoeven, David Allouche
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -150,6 +149,12 @@
   "Extract sublist from @l beginning at @i and ending at @j."
   (list-head (list-tail l i) (- j i)))
 
+(define-public (list-delete l x)
+  "Remove all occurrences of @x from list @l."
+  (cond ((null? l) l)
+        ((== (car l) x) (list-delete (cdr l) x))
+        (else (cons (car l) (list-delete (cdr l) x)))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Circulating lists
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
