@@ -11,10 +11,9 @@
 ;; combined with usual pattern matching, and the extensibility of Scheme.
 ;; In the future, we also plan to use this facility for search & replace.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (kernel regexp regexp-select))
@@ -53,6 +52,18 @@
 	       (select-symbol (cdr l) (+ nr 1) sym bl)))
 	(else (select-symbol (cdr l) (+ nr 1) sym bl))))
 
+(define (select-exclude-symbols l nr syms bl)
+  "Select all except symbols in a given list"
+  (cond ((null? l) l)
+	((and (tm-compound? (car l)) (nin? (tm-car (car l)) syms))
+	 (cons (cons* (list nr) (car l) bl)
+	       (select-exclude-symbols (cdr l) (+ nr 1) syms bl)))
+	(else (select-exclude-symbols (cdr l) (+ nr 1) syms bl))))
+
+(define (select-exclude x args bl)
+  "Select :exclude patterns"
+  (select-exclude-symbols (cdr (tm->list x)) 0 args bl))
+
 (define (select-range l nr begin end bl)
   "Select ranges"
   (cond ((or (null? l) (>= nr end)) '())
@@ -165,6 +176,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define select-table (make-ahash-table))
+(ahash-set! select-table :exclude select-exclude)
 (ahash-set! select-table :range select-range*)
 (ahash-set! select-table :or select-or)
 (ahash-set! select-table :and select-and)
@@ -245,13 +257,16 @@
     ;; (display* "sols= " sols "\n")
     (map cadr sols)))
 
-(with-module texmacs-user
-  (define-public guile-select select)
-  (define-public (select . args)
-    (import-from (kernel regexp regexp-select))
-    (if (= (length args) 2)
-	(apply tm-select args)
-	(apply guile-select args))))
+(if (os-mingw?) ;; mingw guile does not define select
+    (with-module texmacs-user
+      (define-public (select . args) (apply tm-select args)))
+    (with-module texmacs-user
+      (begin (define-public guile-select select)
+	     (define-public (select . args)
+	       (import-from (kernel regexp regexp-select))
+	       (if (= (length args) 2)
+		   (apply tm-select args)
+		   (apply guile-select args))))))
 
 (define-public (tm-ref t . l)
   (and (tm? t)
