@@ -12,13 +12,28 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (texmacs-module (link link-navigate)
-  (:use (utils library cursor) (link link-edit) (link link-extern)))
+  (:use (utils library cursor) (link link-edit) (link link-extern)
+        (generic generic-edit)))
+
+; FIXME: remove these two and find a better way
+(define (escape-link-args s)
+  "Escape only args of the type #some:label"
+  (let* ((m (string-length s))
+         (h (or (string-index s #\#) m))
+         (a (or (string-index s #\?) m))
+         (i (min m h a))
+         (base (substring s 0 i))
+         (qry (substring s (min m i) m)))
+    (if (< i m) (string-append base (string-replace qry ":" "%3A")) s)))
+
+(define (unescape-link-args s)
+  (string-replace s "%3A" ":"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Navigation mode
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define navigation-bidirectional-links? #t)
+(define navigation-bidirectional-links? #f)
 (define navigation-external-links? #t)
 (define navigation-link-pages? #t)
 (define navigation-blocked-types (make-ahash-table))
@@ -27,19 +42,22 @@
 (tm-define (navigation-toggle-bidirectional)
   (:synopsis "Toggle whether we may follow links in both directions.")
   (:check-mark "v" navigation-bidirectional?)
-  (toggle! navigation-bidirectional-links?))
+  (set-boolean-preference "bidirectional navigation"
+                          (not navigation-bidirectional-links?)))
 
 (define (navigation-external?) navigation-external-links?)
 (tm-define (navigation-toggle-external)
   (:synopsis "Toggle whether we may follow links defined in other loci.")
   (:check-mark "v" navigation-external?)
-  (toggle! navigation-external-links?))
+  (set-boolean-preference "external navigation"
+                          (not navigation-external-links?)))
 
 (define (navigation-build-link-pages?) navigation-link-pages?)
 (tm-define (navigation-toggle-build-link-pages)
   (:synopsis "Toggle whether we generate link pages.")
   (:check-mark "v" navigation-build-link-pages?)
-  (toggle! navigation-link-pages?))
+  (set-boolean-preference "link pages"
+                          (not navigation-link-pages?)))
 
 (define (navigation-allow-type? type)
   (not (ahash-ref navigation-blocked-types type)))
@@ -47,17 +65,17 @@
   (:synopsis "Toggle whether we may follow links of a given @type.")
   (:check-mark "v" navigation-allow-type?)
   (ahash-set! navigation-blocked-types type
-	      (not (ahash-ref navigation-blocked-types type))))
+              (not (ahash-ref navigation-blocked-types type))))
 
 (define (navigation-allow-no-types?)
   (with l (ahash-table->list navigation-blocked-types)
     (null? (list-difference (current-link-types)
-			    (map car (list-filter l cdr))))))
+                            (map car (list-filter l cdr))))))
 (tm-define (navigation-allow-no-types)
   (:synopsis "Disallow any link types from being followed.")
   (:check-mark "v" navigation-allow-no-types?)
   (for-each (cut ahash-set! navigation-blocked-types <> #t)
-	    (current-link-types)))
+            (current-link-types)))
 
 (define (navigation-allow-all-types?)
   (with l (ahash-table->list navigation-blocked-types)
@@ -67,6 +85,24 @@
   (:check-mark "v" navigation-allow-all-types?)
   (set! navigation-blocked-types (make-ahash-table)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Navigation preferences
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (notify-bidirectional-navigation var val)
+  (set! navigation-bidirectional-links? (== val "on")))
+
+(define (notify-external-navigation var val)
+  (set! navigation-external-links? (== val "on")))
+
+(define (notify-link-pages var val)
+  (set! navigation-link-pages? (== val "on")))
+
+(define-preferences
+  ("bidirectional navigation" "off" notify-bidirectional-navigation)
+  ("external navigation" "on" notify-external-navigation)
+  ("link pages" "on" notify-link-pages))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Finding links in the form of "link lists". Items in such a list
 ;;   (id type attrs vertex-1 ... vertex-n)
@@ -82,7 +118,7 @@
 
 (define (id->link-list id)
   (let* ((lns (vertex->links `(id ,id)))
-	 (sts (map link-flatten lns)))
+         (sts (map link-flatten lns)))
     (map (cut cons id <>) (map cdr sts))))
 
 (tm-define (ids->link-list ids)
@@ -95,9 +131,9 @@
 (define (exact-link-list-local t)
   (if (not (tm-func? t 'locus)) '()
       (let* ((id (locus-id t))
-	     (lc (list-filter (cdr (tree-children t)) (cut tm-func? <> 'link)))
-	     (lns (map link-flatten lc)))
-	(map (cut cons id <>) (map cdr lns)))))
+             (lc (list-filter (cdr (tree-children t)) (cut tm-func? <> 'link)))
+             (lns (map link-flatten lc)))
+        (map (cut cons id <>) (map cdr lns)))))
 
 (define (filter-on-bidirectional item)
   (== (link-item-id item)
@@ -115,8 +151,8 @@
 (define (filter-link-list l event)
   (let* ((f1 (if (navigation-bidirectional?) l
                  (list-filter l filter-on-bidirectional)))
-         (f2 (list-filter l filter-on-type))
-         (f3 (list-filter l (filter-on-event event))))
+         (f2 (list-filter f1 filter-on-type))
+         (f3 (list-filter f2 (filter-on-event event))))
     f3))
 
 (tm-define (exact-link-list t filter?)
@@ -127,8 +163,8 @@
   ;;(display* "local : " (exact-link-list-local  t) "\n")
   ;;(display* "global: " (exact-link-list-global t) "\n")
   (with l (if (and filter? (not (navigation-external?)))
-	      (exact-link-list-local t)
-	      (exact-link-list-global t))
+              (exact-link-list-local t)
+              (exact-link-list-global t))
     (if filter? (filter-link-list l "click") l)))
 
 (tm-define (upward-link-list t filter?)
@@ -137,8 +173,8 @@
   (:argument filter? "Filter on navigation mode?")
   (if (or (not t) (null? (tree->path t))) '()
       (with l (exact-link-list t filter?)
-	(if (root? t) l
-	    (append l (upward-link-list (tree-up t) filter?))))))
+        (if (root? t) l
+            (append l (upward-link-list (tree-up t) filter?))))))
 
 (tm-define (complete-link-list t filter?)
   (:synopsis "Build possibly filtered link list for @t and its descendants.")
@@ -146,8 +182,8 @@
   (:argument filter? "Filter on navigation mode?")
   (with l (exact-link-list t filter?)
     (if (tree-atomic? t) l
-	(with ls (map (cut complete-link-list <> filter?) (tree-children t))
-	  (apply append (cons l ls))))))
+        (with ls (map (cut complete-link-list <> filter?) (tree-children t))
+          (apply append (cons l ls))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Prospect for active links
@@ -160,10 +196,10 @@
 (define (link-active-upwards-sub t active-ids)
   (if (or (not t) (null? (tree->path t))) '()
       (let* ((ids (tree->ids t))
-	     (add? (nnull? (list-intersection ids active-ids)))
-	     (r (if add? (list t) '())))
-	(if (root? t) r
-	    (append r (link-active-upwards-sub (tree-up t) active-ids))))))
+             (add? (nnull? (list-intersection ids active-ids)))
+             (r (if add? (list t) '())))
+        (if (root? t) r
+            (append r (link-active-upwards-sub (tree-up t) active-ids))))))
 
 (tm-define (link-active-upwards t)
   (:synopsis "Return active ancestor trees for the tree @t.")
@@ -194,61 +230,61 @@
 (define (navigation-list-sub type attrs nr source l)
   (if (null? l) l
       (let* ((head (list type attrs nr source (car l)))
-	     (tail (navigation-list-sub type attrs (+ nr 1) source (cdr l))))
-	(if (== source (vertex->id (car l))) tail
-	    (cons head tail)))))
+             (tail (navigation-list-sub type attrs (+ nr 1) source (cdr l))))
+        (if (== source (vertex->id (car l))) tail
+            (cons head tail)))))
 
 (tm-define (link-list->navigation-list l)
   (:synopsis "Transforms the link list @t into a navigation list")
   (if (null? l) l
       (let* ((item (car l))
-	     (source (link-item-id item))
-	     (type (link-item-type item))
-	     (attrs (link-item-attributes item))
-	     (vertices (link-item-vertices item))
-	     (h (navigation-list-sub type attrs 0 source vertices))
-	     (r (link-list->navigation-list (cdr l))))
-	(list-remove-duplicates (append h r)))))
+             (source (link-item-id item))
+             (type (link-item-type item))
+             (attrs (link-item-attributes item))
+             (vertices (link-item-vertices item))
+             (h (navigation-list-sub type attrs 0 source vertices))
+             (r (link-list->navigation-list (cdr l))))
+        (list-remove-duplicates (append h r)))))
 
 (tm-define (upward-navigation-list t)
   (link-list->navigation-list (upward-link-list t #t)))
 
 (tm-define (navigation-list-filter l type nr jumpable?)
   (cond ((null? l) l)
-	((and (or (== type #t) (== (navigation-type (car l)) type))
-	      (or (== nr #t) (== (navigation-pos (car l)) nr))
-	      (or (not jumpable?)
-		  (func? (navigation-target (car l)) 'id 1)
-		  (func? (navigation-target (car l)) 'url 1)
-		  (func? (navigation-target (car l)) 'script)))
-	 (cons (car l) (navigation-list-filter (cdr l) type nr jumpable?)))
-	(else (navigation-list-filter (cdr l) type nr jumpable?))))
+        ((and (or (== type #t) (== (navigation-type (car l)) type))
+              (or (== nr #t) (== (navigation-pos (car l)) nr))
+              (or (not jumpable?)
+                  (func? (navigation-target (car l)) 'id 1)
+                  (func? (navigation-target (car l)) 'url 1)
+                  (func? (navigation-target (car l)) 'script)))
+         (cons (car l) (navigation-list-filter (cdr l) type nr jumpable?)))
+        (else (navigation-list-filter (cdr l) type nr jumpable?))))
 
 (tm-define (navigation-list-types l)
   (list-remove-duplicates (map navigation-type l)))
 
 (tm-define (navigation-list-xtypes l)
   (let* ((direct (navigation-list-filter l #t 1 #t))
-	 (inverse (navigation-list-filter l #t 0 #t))
-	 (dtypes (map navigation-type direct))
-	 (itypes (map (cut string-append <> "*")
-		      (map navigation-type inverse))))
+         (inverse (navigation-list-filter l #t 0 #t))
+         (dtypes (map navigation-type direct))
+         (itypes (map (cut string-append <> "*")
+                      (map navigation-type inverse))))
     (list-remove-duplicates (append dtypes itypes))))
 
 (tm-define (navigation-list-first-xtype l xtype)
   (let* ((inverse? (string-ends? xtype "*"))
-	 (type (if inverse? (string-drop-right xtype 1) xtype))
-	 (fl (navigation-list-filter l type (if inverse? 0 1) #t)))
+         (type (if inverse? (string-drop-right xtype 1) xtype))
+         (fl (navigation-list-filter l type (if inverse? 0 1) #t)))
     (and (nnull? fl) (navigation-type fl))))
 
 (define (resolve-navigation-list l fun)
   (if (null? l) (fun)
       (let* ((id (vertex->id (navigation-target (car l))))
-	     (ok (or (nstring? id) (nnull? (id->trees id)))))
-	(if ok (resolve-navigation-list (cdr l) fun)
-	    (begin
-	      (resolve-id id)
-	      (delayed (:idle 25) (resolve-navigation-list (cdr l) fun)))))))
+             (ok (or (nstring? id) (nnull? (id->trees id)))))
+        (if ok (resolve-navigation-list (cdr l) fun)
+            (begin
+              (resolve-id id)
+              (delayed (:idle 25) (resolve-navigation-list (cdr l) fun)))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Link pages
@@ -256,67 +292,184 @@
 
 (define (automatic-link-text back)
   (cond ((func? back 'id 1)
-	 (with ts (id->trees (vertex->id back))
-	   (and (nnull? ts) (tree->stree (car ts)))))
-	((func? back 'url 1)
-	 `(verbatim ,(vertex->url back)))
-	((func? back 'script)
-	 `(verbatim ,(vertex->script back)))
-	(else #f)))
+         (with ts (id->trees (vertex->id back))
+           (and (nnull? ts) (tree->stree (car ts)))))
+        ((func? back 'url 1)
+         `(verbatim ,(vertex->url back)))
+        ((func? back 'script)
+         `(verbatim ,(vertex->script back)))
+        (else #f)))
 
 (tm-define (automatic-link back . opt)
   (let* ((broken-text (if (null? opt) "Broken" (car opt)))
-	 (id (create-unique-id))
-	 (text (automatic-link-text back)))
+         (id (create-unique-id))
+         (text (automatic-link-text back)))
     (if (not text) `(with "color" "red" ,broken-text)
-	`(locus (id ,id) (link "automatic" (id ,id) ,back) ,text))))
+        `(locus (id ,id) (link "automatic" (id ,id) ,back) ,text))))
 
 (tm-define (build-enumeration l)
   (if (<= (length l) 1) l
       `((enumerate
-	 (document
-	  ,@(map (lambda (x) `(surround (item) "" ,x)) l))))))
+         (document
+          ,@(map (lambda (x) `(surround (item) "" ,x)) l))))))
 
 (define (navigation-item->document item)
   (automatic-link (navigation-target item)))
 
 (define (navigation-list-by-type->document type l)
   (cons `(strong ,type)
-	(build-enumeration (map navigation-item->document l))))
+        (build-enumeration (map navigation-item->document l))))
 
 (define (navigation-list->document style l)
   (let* ((direct (navigation-list-filter l #t 1 #t))
-	 (inverse (navigation-list-filter l #t 0 #t))
-	 (direct-types (navigation-list-types direct))
-	 (inverse-types (navigation-list-types inverse))
-	 (direct-by-type (map (cut navigation-list-filter direct <> #t #f)
-			      direct-types))
-	 (inverse-by-type (map (cut navigation-list-filter inverse <> #t #f)
-			       inverse-types)))
+         (inverse (navigation-list-filter l #t 0 #t))
+         (direct-types (navigation-list-types direct))
+         (inverse-types (navigation-list-types inverse))
+         (direct-by-type (map (cut navigation-list-filter direct <> #t #f)
+                              direct-types))
+         (inverse-by-type (map (cut navigation-list-filter inverse <> #t #f)
+                               inverse-types)))
     `(document
       (style ,style)
       (body (document
-	     (strong "Source")
-	     ,(automatic-link `(id ,(navigation-source (car l)))
-			      "Unaccessible")
-	     ,@(append-map
-		navigation-list-by-type->document
-		(map (cut string-append "Direct " <>) direct-types)
-		direct-by-type)
-	     ,@(append-map
-		navigation-list-by-type->document
-		(map (cut string-append "Inverse " <>) inverse-types)
-		inverse-by-type))))))
+             (strong "Source")
+             ,(automatic-link `(id ,(navigation-source (car l)))
+                              "Unaccessible")
+             ,@(append-map
+                navigation-list-by-type->document
+                (map (cut string-append "Direct " <>) direct-types)
+                direct-by-type)
+             ,@(append-map
+                navigation-list-by-type->document
+                (map (cut string-append "Inverse " <>) inverse-types)
+                inverse-by-type))))))
 
 (define (build-navigation-page-sub style l)
   (with doc (navigation-list->document style l)
     (open-auxiliary "Link page" doc)))
 
-(define (build-navigation-page l)
+(tm-define (build-navigation-page l)
   (let* ((style (tree->stree (get-style-tree)))
-	 (fun (lambda () (build-navigation-page-sub style l))))
+         (fun (lambda () (build-navigation-page-sub style l))))
     (resolve-navigation-list l fun)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Jumping to different types of URLs is done in two stages. The load handler,
+;; changing with the type of root of the url and the post-load handler, which
+;; will tipically depend on the file format.
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (url->item u)
+  (with (base qry) (process-url u)
+    (let* ((file (url->string u))
+           (help? (and (== "texmacs-file" (file-format u)) 
+                       (url-exists-in-help? file)))
+           (text (if help? (help-file-title u) (basename (url->string base)))))
+      ($link file text))))
+
+(define (url-list->document l)
+  ($tmdoc
+    ($tmdoc-title "Link disambiguation")
+    ($para "The link you followed points to several locations:")
+    ($description-aligned
+      (with c 0
+        ($for (x l)
+          ($describe-item 
+              (number->string (begin (set! c (+ 1 c)) c)) (url->item x)))))))
+
+(tm-define (build-disambiguation-page l)
+  (open-auxiliary "Disambiguation page" (url-list->document l)))
+
+; FIXME: many corner cases will get through 
+;(inexistent relative paths for instance)
+(define (default-filter-url u)
+  (with (base qry) (process-url u)
+    (or (== base "")
+        (or (!= (url-root base) "default")
+            (url-exists? base)))))
+
+(define (default-root-disambiguator u)
+ (with l (list-filter (url->list u) default-filter-url)
+    (cond ((null? l) 
+           (set-message `(verbatim ,(url->string u)) "Not found"))
+          ((== 1 (length l)) (load-browse-buffer (car l)))
+          (else (build-disambiguation-page l)))))
+
+(define (process-url u)
+  "Split a simple (not or'ed!!) url in base and query"
+  (let* ((s (url->string u))
+         (m (string-length s))
+         (h (or (string-index s #\#) m))
+         (a (or (string-index s #\?) m))
+         (i (min m h a))
+         (base (substring s 0 i))
+         (qry (substring s (min m (+ 1 i)) m)))
+    (if (< i m)  ; was there either a '?' or a '#' (with args)?
+        (list (string->url (string-drop-right s (+ 1 (string-length qry))))
+              (unescape-link-args qry))
+        (list u ""))))
+
+(define (texmacs-file-post qry)
+  (if (and (string? qry) (not (string-null? qry)))
+      (with dest (unescape-link-args qry)
+        (go-to-label dest)
+        (set-message (replace "At %1." dest) ""))))
+
+(define generic-file-post texmacs-file-post)
+
+(define (source-file-post qry)
+  (let* ((lstr (or (query-ref qry "line") "0"))
+         (cstr (or (query-ref qry "column") "0"))
+         (sstr (or (query-ref qry "select") ""))
+         (line (or (string->number lstr) 0))
+         (column (or (string->number cstr) 0)))
+    (go-to-line line)
+    (go-to-column column)
+    (set! column (or (select-word sstr (cursor-tree) column) 0))
+    (set-message sstr (string-append lstr ":" (number->string column)))))
+
+; FIXME? will this jump to HTML anchors?
+(define html-file-post generic-file-post)
+
+(define (default-post-handler u)
+  (with (base qry) (process-url u)
+    (with fm (file-format base)
+      (cond ((== fm "texmacs-file") (texmacs-file-post qry))
+            ((== fm "generic-file") (generic-file-post qry))
+            ((== fm "scheme-file") (source-file-post qry))
+            ((== fm "cpp-file") (source-file-post qry))
+            ((== fm "html-file") (html-file-post qry))
+            (else 
+              (display* "Unhandled format for default queries: " fm "\n"))))))
+
+(define (http-post-handler u)
+  ; TODO: jump to anchors in HTML
+  (noop))
+
+(define (default-root-handler u)
+  (if (url-or? (url-expand u))
+      (default-root-disambiguator (url-expand u))
+      (with (base qry) (process-url u)
+        (if (!= "" (url->string base))
+            (load-browse-buffer base)))))
+
+(define (tmfs-root-handler u)
+  (load-browse-buffer u))
+
+(define (http-root-handler u)
+  (load-browse-buffer u))
+
+(define (url-handlers u)
+  (with root (or (and (url-rooted? u) (url-root u)) "default")
+    (cond ((== root "default") 
+           (list default-root-handler default-post-handler))
+          ((== root "tmfs") 
+           (list tmfs-root-handler (lambda (x) (noop))))
+          ((or (== root "http") (== root "https"))
+           (list http-root-handler http-post-handler))
+          (else (display* "Unhandled url root: " root "\n")
+                (list default-root-handler default-post-handler)))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Actual navigation
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -326,31 +479,20 @@
   (:argument opt-from "Optional path for the cursor history")
   (with l (id->trees id)
     (if (nnull? l)
-	(begin
-	  (if (nnull? opt-from) (cursor-history-add (car opt-from)))
-	  (tree-go-to (car l) :end)
-	  (if (nnull? opt-from) (cursor-history-add (cursor-path))))
-	(and (resolve-id id)
-	     (delayed (:idle 25) (apply go-to-id (cons id opt-from)))))))
+        (begin
+          (if (nnull? opt-from) (cursor-history-add (car opt-from)))
+          (tree-go-to (car l) :end)
+          (if (nnull? opt-from) (cursor-history-add (cursor-path))))
+        (and (resolve-id id)
+             (delayed (:idle 25) (apply go-to-id (cons id opt-from)))))))
 
-(define (decompose-url s)
-  (with i (string-index s #\#)
-    (if (not i) (list s "")
-	(list (substring s 0 i) (substring s (+ i 1) (string-length s))))))
-
-(tm-define (go-to-url name-label . opt-from)
-  (:synopsis "Jump to the url @name-label.")
+(tm-define (go-to-url u . opt-from)
+  (:synopsis "Jump to the url @u")
   (:argument opt-from "Optional path for the cursor history")
   (if (nnull? opt-from) (cursor-history-add (car opt-from)))
-  (with (name label) (decompose-url name-label)
-    (cond ((== name "") (go-to-label label))
-	  ((== label "")
-	   (with u (url-relative (buffer-master) name)
-	     (load-browse-buffer u)))
-	  (else
-	   (with u (url-relative (buffer-master) name)
-	     (load-browse-buffer u)
-	     (go-to-label label)))))
+  (if (string? u) (set! u (string->url u)))
+  (with (action post) (url-handlers u) 
+    (action u) (post u))
   (if (nnull? opt-from) (cursor-history-add (cursor-path))))
 
 (define (execute-at cmd opt-location)
@@ -359,34 +501,34 @@
 
 (tm-define (execute-script s secure-origin? . opt-location)
   (let* ((secure-s (string-append "(secure? '" s ")"))
-	 (ok? (or secure-origin? (eval (string->object secure-s))))
-	 (cmd-s (string-append "(lambda () " s ")"))
-	 (cmd (eval (string->object cmd-s))))
+         (ok? (or secure-origin? (eval (string->object secure-s))))
+         (cmd-s (string-append "(lambda () " s ")"))
+         (cmd (eval (string->object cmd-s))))
     (cond ((or ok? (== (get-preference "security") "accept all scripts"))
-	   (execute-at cmd opt-location))
-	  ((== (get-preference "security") "prompt on scripts")
-	   (user-confirm `(concat "Execute " ,s "?") #f
-	     (lambda (answ)
-	       (when answ (execute-at cmd opt-location)))))
-	  (else (set-message "Unsecure script refused" "Evaluate script")))))
+           (execute-at cmd opt-location))
+          ((== (get-preference "security") "prompt on scripts")
+           (user-confirm `(concat "Execute " ,s "?") #f
+             (lambda (answ)
+               (when answ (execute-at cmd opt-location)))))
+          (else (set-message "Unsecure script refused" "Evaluate script")))))
 
 (define (go-to-vertex v attrs)
   (cond ((func? v 'id 1) (go-to-id (cadr v) (cursor-path)))
-	((func? v 'url 1) (go-to-url (cadr v) (cursor-path)))
-	((func? v 'script)
-	 (with ok? (== (assoc-ref attrs "secure") "true")
-	   (apply execute-script (cons* (cadr v) ok? (cddr v)))))
-	(else (noop))))
+        ((func? v 'url 1) (go-to-url (escape-link-args (cadr v)) (cursor-path)))
+        ((func? v 'script)
+         (with ok? (== (assoc-ref attrs "secure") "true")
+           (apply execute-script (cons* (cadr v) ok? (cddr v)))))
+        (else (noop))))
 
 (define (vertex-linked-ids v)
   (let* ((lns (vertex->links v))
-	 (vs (list-difference (append-map link-vertices lns) (list v))))
+         (vs (list-difference (append-map link-vertices lns) (list v))))
     (list-remove-duplicates (filter-map vertex->id vs))))
 
 (define (id-update id)
   (let* ((ts1 (id->trees id))
-	 (ts2 (id->trees (string-append "&" id)))
-	 (pl (filter-map tree->path (append ts1 ts2))))
+         (ts2 (id->trees (string-append "&" id)))
+         (pl (filter-map tree->path (append ts1 ts2))))
     (for-each update-all-path pl)))
 
 (define (id-set-visited id)
@@ -400,7 +542,7 @@
 
 (define (navigation-item-follow hit)
   (let* ((source (navigation-source hit))
-	 (target (navigation-target hit)))
+         (target (navigation-target hit)))
     (id-set-visited source)
     (and-with target-id (vertex->id target)
       (id-set-visited target-id))
@@ -421,17 +563,17 @@
   (:synopsis "Follow one of the links in the navigation list @nl.")
   (with types (navigation-list-types nl)
     (if (and (>= (length types) 2) (in? "automatic" types))
-	(with auto-nl (navigation-list-filter nl "automatic" #t #f)
-	  (set! nl (list-difference nl auto-nl))))
+        (with auto-nl (navigation-list-filter nl "automatic" #t #f)
+          (set! nl (list-difference nl auto-nl))))
     (with xtypes (navigation-list-xtypes nl)
       (cond ((null? xtypes) (noop))
-	    ((and (navigation-build-link-pages?) (>= (length nl) 2))
-	     (id-set-visited (navigation-source (car nl)))
-	     (build-navigation-page nl))
-	    ((null? (cdr xtypes)) (navigation-item-follow (car nl)))
-	    (else
-	     (set! the-navigation-list nl)
-	     (interactive navigation-list-follow-xtyped))))))
+            ((and (navigation-build-link-pages?) (>= (length nl) 2))
+             (id-set-visited (navigation-source (car nl)))
+             (build-navigation-page nl))
+            ((null? (cdr xtypes)) (navigation-item-follow (car nl)))
+            (else
+             (set! the-navigation-list nl)
+             (interactive navigation-list-follow-xtyped))))))
 
 (tm-define (link-follow-ids ids event)
   (:synopsis "Follow one of the links for identifiers in @ids.")
@@ -442,5 +584,5 @@
 (tm-define (locus-link-follow)
   (:synopsis "Follow one of the links in the current locus.")
   (let* ((ts (link-active-upwards (cursor-tree)))
-	 (ids (append-map tree->ids ts)))
+         (ids (append-map tree->ids ts)))
     (link-follow-ids ids "click")))
