@@ -244,7 +244,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define wide-list-1
-  '("~" "^" "<bar>" "<vect>" "<check>" "<breve>"))
+  '("~" "^" "<bar>" "<vect>" "<check>" "<breve>" "<invbreve>"))
 
 (define wide-list-2
   '("<acute>" "<grave>" "<dot>" "<ddot>" "<abovering>"))
@@ -268,6 +268,20 @@
         (with j (modulo (+ i (if forward? 1 -1)) (length wide-list-3))
           (tree-set t 1 (list-ref wide-list-3 j)))))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Wide arrows
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (make-long-arrow s)
+  (when (and (string? s) (string-starts? s "<") (string-ends? s ">"))
+    (with rs (string-append "<rubber-" (substring s 1 (string-length s)))
+      (insert-go-to `(long-arrow ,rs "") '(1 0)))))
+
+(tm-define (make-long-arrow* s)
+  (when (and (string? s) (string-starts? s "<") (string-ends? s ">"))
+    (with rs (string-append "<rubber-" (substring s 1 (string-length s)))
+      (insert-go-to `(long-arrow ,rs "" "") '(2 0)))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Modifying the shape of brackets
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
