@@ -245,6 +245,7 @@
   ("accent:grave" "accent `")
   ("accent:cedilla" "accent C")
   ("accent:breve" "accent U")
+  ("accent:invbreve" "accent A")
   ("accent:check" "accent V")
   ("accent:doubleacute" "accent H")
   ("accent:abovering" "accent O")
@@ -281,6 +282,7 @@
   ("grave grave" "grave")
   ("cedilla cedilla" "cedilla")
   ("breve breve" "breve")
+  ("invbreve invbreve" "invbreve")
   ("check check" "check")
   ("doubleacute doubleacute" "doubleacute")
   ("abovering abovering" "abovering")
@@ -294,6 +296,7 @@
   ("grave" "accent `")
   ("cedilla" "accent C")
   ("breve" "accent U")
+  ("invbreve" "accent A")
   ("check" "accent V")
   ("doubleacute" "accent H")
   ("abovering" "accent O")
