@@ -27,8 +27,8 @@
     (let* ((abbr (buffer-get-title name))
            (abbr* (if (== abbr "") (url->system (url-tail name)) abbr))
            (mod? (buffer-modified? name))
-           (short-name (string-append abbr* (if mod? " *" "")))
-           (long-name (url->system name)))
+           (short-name `(verbatim ,(string-append abbr* (if mod? " *" ""))))
+           (long-name `(verbatim ,(url->system name))))
       ((balloon (eval short-name) (eval long-name))
        (switch-to-buffer name)))))
 
@@ -54,19 +54,20 @@
 
 (tm-menu (file-list-menu l)
   (for (name l)
-    (let* ((short-name (url->system (url-tail name)))
-	   (long-name (url->system name)))
-      ((balloon (eval short-name) (eval long-name)) (load-buffer name)))))
+    (let* ((short-name `(verbatim ,(url->system (url-tail name))))
+           (long-name `(verbatim ,(url->system name))))
+      ((balloon (eval short-name) (eval long-name))
+       (load-buffer name)))))
 
 (tm-define (recent-file-list nr)
   (let* ((l1 (map cdar (learned-interactive "recent-buffer")))
-	 (l2 (map unix->url l1))
+         (l2 (map unix->url l1))
          (l3 (list-filter l2 buffer-in-recent-menu?)))
     (sublist l3 0 (min (length l3) nr))))
 
 (tm-define (recent-unloaded-file-list nr)
   (let* ((l1 (map cdar (learned-interactive "recent-buffer")))
-	 (l2 (map unix->url l1))
+         (l2 (map unix->url l1))
          (l3 (list-filter l2 buffer-in-recent-menu?))
          (dl (list-difference l3 (buffer-list))))
     (sublist dl 0 (min (length dl) nr))))
