@@ -54,7 +54,7 @@
   (learn-interactive 'recent-buffer (list (cons "0" (url->unix name)))))
 
 (define (has-faithful-format? name)
-  (in? (url-suffix name) '("tm" "ts" "tp" "stm" "tmml")))
+  (in? (url-suffix name) '("tm" "ts" "tp" "stm" "tmml" "scm")))
 
 (define (save-buffer-post name opts)
   ;;(display* "save-buffer-post " name "\n")
@@ -105,7 +105,7 @@
     (cond ((url-scratch? name)
            (choose-file
              (lambda (x) (apply save-buffer-as-main (cons x opts)))
-             "Save TeXmacs file" ""))
+             "Save TeXmacs file" "texmacs"))
           ((not (buffer-exists? name))
            (with msg `(concat "The buffer " ,vname " does not exist")
              (set-message msg "Save file")))
@@ -388,7 +388,8 @@
   (apply load-buffer-main (cons name (cons :new-window opts))))
 
 (tm-define (load-browse-buffer name)
-  (load-buffer name))
+  (:synopsis "Load a buffer or switch to it if already open")
+  (if (buffer-exists? name) (switch-to-buffer name) (load-buffer name)))
 
 (tm-define (open-buffer)
   (:synopsis "Open a new file")
