@@ -22,34 +22,27 @@
   (-> "Name"
       ;;("Modern" (make-with "font" "modern"))
       ("Roman" (make-with "font" "roman"))
-      (if (url-exists-in-tex? "pnr10.mf")
-	  ("Pandora" (make-with "font" "pandora")))
       (if (url-exists-in-tex? "ccr10.mf")
 	  ("Concrete" (make-with "font" "concrete")))
+      (if (url-exists-in-tex? "pnr10.mf")
+	  ("Pandora" (make-with "font" "pandora")))
+      (if (font-exists-in-tt? "STIX-Regular")
+          ("Stix" (make-with "font" "stix")))
       ---
       (-> "Adobe"
-	  (if (url-exists-in-tex? "rpagk.tfm")
-	      ("Avant Garde" (make-with "font" "avant-garde")))
-	  (if (url-exists-in-tex? "rpbkl.tfm")
-	      ("Bookman" (make-with "font" "bookman")))
+	  ("Avant Garde" (make-with "font" "avant-garde"))
+          ("Bookman" (make-with "font" "bookman"))
 	  (if (url-exists-in-tex? "rpzcmi.tfm")
 	      ("Chancery" (make-with "font" "chancery")))
-	  (if (url-exists-in-tex? "rpcrr.tfm")
-	      ("Courier" (make-with "font" "courier")))
+	  ("Courier" (make-with "font" "courier"))
 	  (if (url-exists-in-tex? "rpzdr.tfm")
 	      ("Dingbat" (make-with "font" "dingbat")))
-	  (if (url-exists-in-tex? "rphvr.tfm")
-	      ("Helvetica" (make-with "font" "helvetica")))
-	  (if (url-exists-in-tex? "rpncr.tfm")
-	      ("New Century Schoolbook"
-	       (make-with "font" "new-century-schoolbook")))
-	  (if (url-exists-in-tex? "rpplr.tfm")
-	      ("Palatino" (make-with "font" "palatino")))
-	  (if (url-exists-in-tex? "rptmr.tfm")
-	      ("Times" (make-with "font" "times"))))
+          ("Helvetica" (make-with "font" "helvetica"))
+          ("N.C. Schoolbook" (make-with "font" "new-century-schoolbook"))
+          ("Palatino" (make-with "font" "palatino"))
+	  ("Times" (make-with "font" "times")))
       (if (or (font-exists-in-tt? "luxirr")
-              (font-exists-in-tt? "Apple Symbols")
-              (font-exists-in-tt? "STIXGeneral"))
+              (font-exists-in-tt? "Apple Symbols"))
           (-> "True type"
               (if (font-exists-in-tt? "DejaVuSerif")
                   ("Dejavu" (make-with "font" "dejavu")))
@@ -57,8 +50,6 @@
                   ("Lucida Grande" (make-with "font" "apple-lucida")))
               (if (font-exists-in-tt? "luxirr")
                   ("Luxi" (make-with "font" "luxi")))
-              (if (font-exists-in-tt? "STIXGeneral")
-                  ("Stix" (make-with "font" "stix")))
               (if (font-exists-in-tt? "Apple Symbols")
                   ("Symbols" (make-with "font" "apple-symbols")))))
       (if (font-exists-in-tt? "times")
