@@ -5,10 +5,9 @@
 ;; DESCRIPTION : Routines for structuring the sections and lists
 ;; COPYRIGHT   : (C) 2005  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -39,11 +38,13 @@
 	(if (!= title "no title") title
 	    (tm/section-get-title-string-sub (cdr l))))))
 
+(tm-define (texmacs->string x)
+  (texmacs->code (verbatim-expand x)))
+
 (tm-define (tm/section-get-title-string t)
   (cond ((tm-atomic? t) "no title")
 	((or (section-tag? (tm-car t)) (section*-tag? (tm-car t)))
-	 (plugin-math-input
-	  (list 'tuple "default" (tree->stree (tm->tree (tm-ref t 0))))))
+         (texmacs->string (tm-ref t 0)))
 	((tree-is? (tm-car t) 'the-index) "Index")
 	((tree-is? (tm-car t) 'the-glossary) "Glossary")
 	((or (special-section-tag? (tm-car t))
