@@ -1,4 +1,4 @@
-<TeXmacs|1.0.7.15>
+<TeXmacs|1.0.7.17>
 
 <style|source>
 
@@ -164,7 +164,7 @@
 
   <assign|author-render-name|<macro|author|<surround|<vspace*|0.25fn>|<vspace|0.25fn>|<doc-author-block|<title-ss|<arg|author>>>>>>
 
-  <assign|author-address|<\macro|address>
+  <assign|author-affiliation|<\macro|address>
     <surround|<vspace*|0.25fn>|<vspace|0.25fn>|<doc-author-block|<title-ss|<with|font-base-size|10|<arg|address>>>>>
   </macro>>
 
@@ -172,19 +172,19 @@
 
   <assign|author-homepage|<macro|homepage|<doc-author-block|<title-ss|<arg|homepage>>>>>
 
-  <assign|doc-abstract|<\macro|body>
+  <assign|render-abstract|<\macro|body>
     <section*|<abstract-text>>
 
     <surround|<no-indent>||<arg|body>>
   </macro>>
 
-  <assign|doc-keywords|<\xmacro|args>
+  <assign|abstract-keywords|<\xmacro|args>
     <subsection*|<keywords-text>>
 
     <no-indent><concat-tuple|<copy|<quote-arg|args>>|, >
   </xmacro>>
 
-  <assign|doc-AMS-class|<\xmacro|args>
+  <assign|abstract-msc|<\xmacro|args>
     <subsection*|<AMS-class-text>>
 
     <no-indent><concat-tuple|<copy|<map|msc-ref|<quote-arg|args>>>|, >
