@@ -1,9 +1,9 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
-;; MODULE      : init-axiom.scm
-;; DESCRIPTION : Initialize axiom plugin
-;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
+;; MODULE      : init-fricas.scm
+;; DESCRIPTION : Initialize fricas plugin
+;; COPYRIGHT   : (C) 1999, 2012  Joris van der Hoeven and Andrey Grozin
 ;;
 ;; This software falls under the GNU general public license and comes WITHOUT
 ;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
@@ -12,13 +12,17 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;(define (fricas-initialize)
-;  (import-from (utils plugins plugin-convert))
-;  (lazy-input-converter (fricas-input) fricas))
+(define (fricas-initialize)
+  (import-from (utils plugins plugin-convert))
+  (import-from (utils plugins plugin-cmd))
+  (import-from (dynamic session-menu))
+  (import-from (fricas-kbd))
+  (import-from (fricas-menus))
+  (lazy-input-converter (fricas-input) fricas))
 
 (plugin-configure fricas
   (:require (url-exists-in-path? "fricas"))
-  ;(:initialize (fricas-initialize))
+  (:initialize (fricas-initialize))
   (:launch "fricas -texmacs")
   (:session "Fricas")
   (:scripts "Fricas"))
