@@ -5,21 +5,16 @@
 ;; DESCRIPTION : Initialize giac plugin
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(lazy-menu (giac-menus) giac-functions-menu)
-
 (define (giac-initialize)
   (import-from (utils plugins plugin-convert))
-  (lazy-input-converter (giac-input) giac)
-  (menu-extend texmacs-extra-menu
-    (if (in-giac?)
-	(=> "Giac" (link giac-functions-menu)))))
+  (import-from (giac-menus))
+  (lazy-input-converter (giac-input) giac))
 
 (plugin-configure giac
   (:require (url-exists-in-path? "giac"))
