@@ -1,14 +1,13 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
-;; MODULE      : init-mathemagix.scm
+;; MODULE      : mathemagix-input.scm
 ;; DESCRIPTION : Initialize mathemagix plugin
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven, 2005  Andrey Grozin
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -63,4 +62,5 @@
   ("<in>" " in ")
   ("<neg>" "!")
   ("<wedge>" "/\\")
-  ("<vee>" "\\/"))
+  ("<vee>" "\\/")
+  ("<mapsto>" ":-<gtr>"))
