@@ -5,10 +5,9 @@
 ;; DESCRIPTION : Initialize octave plugin
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
-;; This software falls under the GNU general public license and comes WITHOUT
-;; ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for details.
-;; If you don't have this file, write to the Free Software Foundation, Inc.,
-;; 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+;; This software falls under the GNU general public license version 3 or later.
+;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -16,8 +15,10 @@
   (import-from (utils plugins plugin-convert))
   (plugin-input-converters octave))
 
+(define octave-launcher (if (os-mingw?) "tm_octave.bat" "tm_octave"))
 (plugin-configure octave
+  (:winpath ,(url-append (url-wildcard "Octave*") "bin"))
   (:require (url-exists-in-path? "octave"))
   (:initialize (octave-initialize))
-  (:launch "tm_octave")
+  (:launch ,octave-launcher)
   (:session "Octave"))
