@@ -4,13 +4,12 @@
 * DESCRIPTION: TeXmacs shell
 * COPYRIGHT  : (C) 2000  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
-#include "../../../src/System/config.h"
+#include "config.h"
 #include <iostream>
 #include <stdlib.h>
 #include <stdio.h>
@@ -46,6 +45,7 @@ extern "C" charp* environ;
 //#define DATA_BEGIN   "[BEGIN]"
 //#define DATA_END     "[END]"
 //#define DATA_ESCAPE  "[ESCAPE]"
+
 static int pid;
 static int master;
 static char prompt[] = "tmshell$ ";
@@ -61,9 +61,12 @@ static void append (charp &s, char c, int& pos, int& max) {
   }
   s[pos++]= c;
 }
+
 int output_pos;
 charp output;
-static void shell_interrupt (int sig) {
+
+static void
+shell_interrupt (int sig) {
   if (output != NULL) {
     int i;
     for (i=0; i<output_pos; i++) cout << output[i];
@@ -80,8 +83,10 @@ static void shell_interrupt (int sig) {
   wait (NULL);
   exit (0);
 }
-static void shell_output (bool hide= false) {
-  static struct timeval tv = {0, 100};
+
+static void
+shell_output (bool hide= false) {
+  static struct timeval tv;
   int output_max= 1024;
   output = (charp) malloc (output_max);
   output_pos= 0;
@@ -90,6 +95,8 @@ static void shell_output (bool hide= false) {
     fd_set rfds;
     FD_ZERO (&rfds);
     FD_SET (master, &rfds);
+    tv.tv_sec = 0;
+    tv.tv_usec = 10000;
     int r = select (master+1, &rfds, NULL, NULL, &tv);
     if (r == 0) continue;
     if (r == -1) continue;
@@ -122,7 +129,8 @@ static void shell_output (bool hide= false) {
       }
     }
 
-    if (output_pos >= promptlen && strncmp(output + output_pos - promptlen, prompt, promptlen) == 0)
+    if (output_pos >= promptlen &&
+	strncmp(output + output_pos - promptlen, prompt, promptlen) == 0)
       {
 	output[output_pos-promptlen]=0;
 	if (hide) hide= false; 
@@ -135,23 +143,32 @@ static void shell_output (bool hide= false) {
   cout << DATA_END << flush;
   free (output);
 }
-static void shell_input () {
+
+static void
+shell_input () {
   char input [10000];
   cin.getline (input, 10000, '\n');
   strcat (input, "\n");
   write (master, input, strlen (input));
 }
-static void child() {
+
+static void
+child() {
   struct termios t;
   tcgetattr(STDIN, &t);
   t.c_lflag &= ~ECHO;
   tcsetattr(STDIN, TCSANOW, &t);
   setenv ("PS1", prompt, true);
-  static charp argv[] = { "sh", "-i", NULL };
+  const charp argv[] = {
+    const_cast<charp> ("sh"),
+    const_cast<charp> ("-i"),
+    NULL };
   execve("/bin/sh", argv, environ);
   exit(127);
 }
-static void parent() {
+
+static void
+parent() {
   signal (SIGINT, shell_interrupt);
   shell_output (true);
   cout << DATA_END << flush;
@@ -160,7 +177,9 @@ static void parent() {
     shell_output ();
   }
 }
-int main () {
+
+int
+main () {
   cout << DATA_BEGIN << "verbatim:" << "Shell session inside TeXmacs" << flush;
   pid = forkpty(&master,NULL,NULL,NULL);
   if (pid==0) child();
