@@ -10,6 +10,7 @@
 ******************************************************************************/
 
 #include "convert.hpp"
+#include "wencoding.hpp"
 #include "analyze.hpp"
 #include "list.hpp"
 #include "tree_traverse.hpp"
@@ -17,6 +18,13 @@
 
 static string bib_current_tag= "";
 
+bool
+bibtex_non_empty_comment (string s) {
+  for (int i=0; i<N(s); i++)
+    if (is_alpha (s[i]) || is_numeric (s[i])) return true;
+  return false;
+}
+
 bool
 bib_ok (string s, int pos) {
   return 0 <= pos && pos < N(s);
@@ -123,12 +131,12 @@ void bib_atomic_arg (string s, int& pos, string ce, tree& a) {
   switch (s[pos]) {
     case '\"': {
       bib_within (s, pos, '\"', '\"', sa);
-      a= sa;
+      a= western_to_cork (sa);
       break;
     }
     case '{': {
       bib_within (s, pos, '{', '}', sa);
-      a= sa;
+      a= western_to_cork (sa);
       break;
     }
     default: {
@@ -136,11 +144,11 @@ void bib_atomic_arg (string s, int& pos, string ce, tree& a) {
       cs << ce;
       if (!is_digit (s[pos])) {
         bib_until (s, pos, cs, sa);
-        a= compound ("bib-var", sa);
+        a= compound ("bib-var", western_to_cork (sa));
       }
       else {
         bib_until (s, pos, cs, sa);
-        a= sa;
+        a= western_to_cork (sa);
       }
       break;
     }
@@ -342,6 +350,13 @@ bib_list (string s, int& pos, tree& t) {
             if (comment) te= tree (DOCUMENT);
             else te= tentry;
             bib_entry (s, pos, stype, te);
+            /* dirty hack to get comments between entries */
+            int start= pos;
+            while (pos+1 < N(s) && s[pos+1] != '@') pos++;
+            if (bibtex_non_empty_comment (s(start, pos+1)))
+              tentry << compound ("bib-comment",
+                  tree (DOCUMENT, western_to_cork (s(start, pos+1))));
+            /* end */
             if (comment) {
               if (N(te) == 1) tentry << compound ("bib-comment", te[0]);
               else tentry << compound ("bib-comment", te);
