@@ -15,7 +15,7 @@
 extern bool textm_class_flag;
 hashmap<string,int> textm_recursion_level (0);
 
-string string_arg (tree t);
+string string_arg (tree t, bool url= false);
 tree latex_symbol_to_tree (string s);
 
 /******************************************************************************
@@ -47,11 +47,15 @@ tree latex_symbol_to_tree (string s);
 struct latex_parser {
   int level;
   bool unicode;
+  char lf;
+  hashmap<string,bool> loaded_package;
   latex_parser (bool unicode2): level (0), unicode (unicode2) {}
   void latex_error (string s, int i, string message);
 
+  bool is_opening_option (char c);
   tree parse             (string s, int& i, string stop= "", bool ch= false);
   tree parse_backslash   (string s, int& i);
+  tree parse_linefeed    (string s, int& i);
   tree parse_symbol      (string s, int& i);
   tree parse_command     (string s, int& i, string which);
   tree parse_argument    (string s, int& i);
@@ -103,6 +107,21 @@ is_tex_alpha (string s) {
   return true;
 }
 
+tree
+latex_parser::parse_linefeed (string s, int& i) {
+  int ln=0;
+  tree r=concat ();
+  while ((i<N(s)) && is_space (s[i])) {
+    if (s[i++] == '\n') ln++;
+  }
+  if (i>N(s)) return "";
+  if (lf == 'N' && ln > 0) ln++;
+  if (lf != 'N' && ln == 1) r << " ";
+  else if (ln > 1) r << "\n";
+  if (ln > 0) lf = 'M';
+  return r;
+}
+
 tree
 latex_parser::parse (string s, int& i, string stop, bool change) {
   bool no_error= true;
@@ -124,6 +143,7 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
 	   (i+2>n || s(i,i+2) != "\\]") &&
 	   (i+2>n || s(i,i+2) != "\\)") &&
 	   (i+4>n || s(i,i+4) != "\\end")))) {
+    if (lf == 'N' && s[i] != '\n') lf= 'M';
     switch (s[i]) {
     case '~':
       t << tuple ("\\nbsp");
@@ -135,16 +155,9 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
       while ((i<n) && ((s[i]==' ') || (s[i]=='\t') || (s[i]=='\r'))) i++;
       if ((i<n) && (s[i]!='\n')) t << " ";
       break;
-    case '\n': {
-      int ln=0;
-      while ((i<n) && is_space (s[i]))
-	if (s[i++]=='\n') ln++;
-      if (i<n) {
-	if (ln == 1) t << " ";
-	else t << "\n";
-      }
+    case '\n':
+      t << latex_parser::parse_linefeed (s, i);
       break;
-    }
     case '%': {
       while ((i<n) && (s[i]!='\n')) i++;
       if (i<n) i++;
@@ -168,6 +181,7 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
       else t << s (i-1, i);
       break;
     case '\\':
+      // TODO: move this in parse_command
       if (s (i+1, i+6) == "hskip" || s (i+1, i+6) == "vskip"){
         string skip = s (i+1, i+6);
         i+=7;
@@ -181,6 +195,7 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
         }
         textm_class_flag = tmp_textm_class_flag;
       }
+      // end of move
       else if (((i+7)<n && !is_tex_alpha (s (i+5, i+7)) &&
 	  (s (i, i+5) == "\\over" || s (i, i+5) == "\\atop")) ||
 	  ((i+9)<n && !is_tex_alpha (s (i+7, i+9)) && s (i, i+7) == "\\choose"))
@@ -231,7 +246,9 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
 	while ((i < N(s)) && (s[i] == '\'')) i++;
 	t << tuple ("\\prime", s (start, i));
       }
-      else t << s (i-1, i);
+      else {
+        t << s (i-1, i);
+      }
       break;
     case '*':
       if (command_type ["!mode"] == "math") t << tree (TUPLE, "\\ast");
@@ -278,7 +295,7 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
       while ((i<n) && is_space (s[i]))
 	if (s[i++]=='\n') ln++;
       if (ln >= 2) t << "\n";
-      else if (i<n) t << tree (TUPLE, "\\ ");
+      else if (i<n) t << " ";
       break;
     }
     case '$': {
@@ -304,7 +321,11 @@ latex_parser::parse (string s, int& i, string stop, bool change) {
       break;
     }
     default:
-      if ((s[i] == '-' || (s[i] >= '0' && s[i] <= '9')) &&
+      if (i+2<n && s[i] == '-' && s[i+1] == '-' && s[i+2] == '-') {
+        i+=3;
+        t << tree (TUPLE, "\\emdash");
+      }
+      else if ((s[i] == '-' || (s[i] >= '0' && s[i] <= '9')) &&
 	  can_parse_length (s, i))
 	t << parse_length (s, i);
       else if (unicode && ((unsigned char) s[i]) >= 128) {
@@ -432,6 +453,8 @@ latex_parser::parse_backslash (string s, int& i) {
   while ((i<n) && is_tex_alpha (s[i])) i++;
   if ((i<n) && (s[i]=='*') && latex_type (s (start, i+1)) != "undefined") i++;
   string r= s (start, i);
+  while ((i<n) && s[i] == ' ') i++;
+  if (s[i] == '\n') {lf= 'N'; i++;}
   if ((r == "\\begin") || (r == "\\end")) {
     while ((i<n) && is_space (s[i])) i++;
     if ((i==n) || (s[i]!='{')) {
@@ -461,7 +484,7 @@ sharp_to_arg (string s, tree args) {
 
 tree
 latex_parser::parse_symbol (string s, int& i) {
-  int start= i;
+  int start= i, end;
   if ((s[i] == '*') && (command_type ["!mode"] == "math")) {
     i++; return tree (TUPLE, "\\ast"); }
   if (s[i] == '<') { i++; return tree (TUPLE, "\\<less>"); }
@@ -469,10 +492,15 @@ latex_parser::parse_symbol (string s, int& i) {
   if (s[i] != '\\') { i++; return s(start, i); }
   i++;
   if (i == N(s)) return tree (TUPLE, "\\backslash");
-  if (!is_tex_alpha (s[i])) { i++; return s(start, i); }
-  while ((i<N(s)) && is_tex_alpha (s[i])) i++;
-  if ((i<N(s)) && (s[i]=='*')) i++;
-  return s(start,i);
+  if (!is_tex_alpha (s[i])) end= ++i;
+  else {
+    while ((i<N(s)) && is_tex_alpha (s[i])) i++;
+    if ((i<N(s)) && (s[i]=='*')) i++;
+    end= i;
+  }
+  while ((i<N(s)) && s[i] == ' ') i++;
+  if (s[i] == '\n') {lf= 'N'; i++;}
+  return s(start, end);
 }
 
 static bool
@@ -519,11 +547,18 @@ skip_linespaces (string s, int& i) {
   skip_spaces (s, i);
 }
 
+bool
+latex_parser::is_opening_option (char c) {
+  if (c == '[') return true;
+  if (loaded_package["algorithm2e"] && c == '(') return true;
+  return false;
+}
+
 tree
 latex_parser::parse_command (string s, int& i, string cmd) {
   bool delimdef = false;
-  //cout << cmd << " [" << latex_type (cmd) << ", "
-  //<< command_type ["!mode"] << ", " << latex_arity (cmd) << "]" << LF;
+  // cout << cmd << " [" << latex_type (cmd) << ", "
+  // << command_type ["!mode"] << ", " << latex_arity (cmd) << "]" << LF;
   if (cmd == "\\gdef" || cmd == "\\xdef" || cmd == "\\edef") cmd= "\\def";
   if (cmd == "\\def" && s[i] == '\\') delimdef = true;
   if (cmd == "\\newcommand") cmd= "\\def";
@@ -531,11 +566,14 @@ latex_parser::parse_command (string s, int& i, string cmd) {
   if (cmd == "\\renewcommand") cmd= "\\def";
   if (cmd == "\\DeclareMathOperator") cmd= "\\def";
   if (cmd == "\\DeclareMathOperator*") cmd= "\\def";
+  if (cmd == "\\RequirePackage") cmd= "\\usepackage";
   if (cmd == "\\renewenvironment") cmd= "\\newenvironment";
   if (cmd == "\\begin-split") cmd= "\\begin-eqsplit";
   if (cmd == "\\end-split") cmd= "\\end-eqsplit";
   if (cmd == "\\begin-split*") cmd= "\\begin-eqsplit*";
   if (cmd == "\\end-split*") cmd= "\\end-eqsplit*";
+  if (cmd == "\\begin-tabular*") cmd= "\\begin-tabularx";
+  if (cmd == "\\end-tabular*") cmd= "\\end-tabularx";
 
   if (latex_type (cmd) == "undefined")
     return parse_unknown (s, i, cmd);
@@ -560,16 +598,49 @@ latex_parser::parse_command (string s, int& i, string cmd) {
     return tuple (cmd, name, arg);
   }
 
+  if (cmd == "\\cmidrule") {
+    if (s[i] == '[') {
+      i++;
+      parse (s, i, ']');
+      skip_linespaces (s, ++i);
+    }
+    if (s[i] == '(') {
+      i++;
+      parse (s, i, ')');
+      skip_linespaces (s, ++i);
+    }
+    tree a= parse_argument (s, i);
+    skip_linespaces (s, ++i);
+    return tuple ("\\cline", a);
+  }
+
+  if (cmd == "\\multirow") {
+    tree a= parse_argument (s, i);
+    skip_linespaces (s, ++i);
+    if (s[i] == '[') {
+      i++;
+      parse (s, i, ']');
+      skip_linespaces (s, ++i);
+    }
+    tree b= parse_argument (s, i);
+    skip_linespaces (s, ++i);
+    if (s[i] == '[') {
+      i++;
+      parse (s, i, ']');
+      skip_linespaces (s, ++i);
+    }
+    tree c= parse_argument (s, i);
+    skip_linespaces (s, ++i);
+    return tuple (cmd, a, b, c);
+  }
+
   if (cmd == "\\category") {
     tree a= parse_argument (s, i);
-    i++;
-    skip_linespaces (s, i);
+    skip_linespaces (s, ++i);
     tree b= parse_argument (s, i);
-    i++;
-    skip_linespaces (s, i);
+    skip_linespaces (s, ++i);
     tree c= parse_argument (s, i);
-    i++;
-    skip_linespaces (s, i);
+    skip_linespaces (s, ++i);
     if (s[i] == '[') {
       i++;
       tree d= parse (s, i, ']'); i++;
@@ -584,6 +655,7 @@ latex_parser::parse_command (string s, int& i, string cmd) {
   if (mbox_flag) command_type ("!mode") = "text";
 
   int  n     = N(s);
+  string type= latex_type (cmd);
   int  arity = latex_arity (cmd);
   bool option= (arity<0);
   if (option) arity= -1-arity;
@@ -624,23 +696,32 @@ latex_parser::parse_command (string s, int& i, string cmd) {
 /************************ retrieve arguments *******************************/
     t = tree(TUPLE, copy (cmd)); // parsed arguments
     u = tree(TUPLE, copy (cmd)); // unparsed arguments
+    // Should be in a drd.
+    bool option2= (cmd == "\\def" || cmd == "\\newenvironment");
 
     while (i<n && arity>=0 && (arity>0 || option)) {
       int j= i;
       while ((j<n) && is_space (s[j])) j++;
       if (j==n) break;
       if (s[i]=='$') break; // in most cases, this should not be an argument
-      if (option && (s[j]=='[')) {
+      if (option && (is_opening_option (s[j]) ||
+                    (type == "algorithm2e" && s[j] == '{'))) {
+        char ec= closing_delimiter (s[j]);
         j++;
         i=j;
-        tree opt= parse (s, i, "]");
+        tree opt= parse (s, i, ec);
         if (cmd != "\\newtheorem" && cmd != "\\newtheorem*")
           t << opt;
         u << s (j, i);
-        if ((i<n) && (s[i]==']')) i++;
+        if ((i<n) && (s[i]==ec)) i++;
         if (cmd != "\\newtheorem" && cmd != "\\newtheorem*")
           t[0]->label= t[0]->label * "*";
         option= false;
+        if (!option && option2) {
+          option = true;
+          option2= false;
+          continue;
+        }
       }
       else if ((arity>0) && (s[j]=='{')) {
         bool text_arg=
@@ -657,7 +738,7 @@ latex_parser::parse_command (string s, int& i, string cmd) {
         u << s (j, i);
         if ((i<n) && (s[i]=='}')) i++;
         arity--;
-        if (arity == 0) option= false;
+        if (arity == 0) option= option2= false;
       }
       else if (s[j] == '}') break;
       else if (option && (s[j]=='#') && (cmd == "\\def")) {
@@ -668,7 +749,7 @@ latex_parser::parse_command (string s, int& i, string cmd) {
           i= j+2;
         }
         t[0]->label= t[0]->label * "*";
-        option= false;
+        option= option2= false;
       }
       else if (s[i] == '%') {
         while(i < N(s) && s[i] != '\n') i++;
@@ -680,7 +761,7 @@ latex_parser::parse_command (string s, int& i, string cmd) {
           t << st;
           u << st;
           arity--;
-          if (arity == 0) option= false;
+          if (arity == 0) option= option2= false;
         }
         else break;
       }
@@ -688,6 +769,22 @@ latex_parser::parse_command (string s, int& i, string cmd) {
     if (arity>0) latex_error (s, i, "too little arguments for " * cmd);
   }
 
+  /******************** store and process loaded packages ********************/
+  if (is_tuple (t, "\\usepackage", 1) || is_tuple (t, "\\usepackage*", 2)) {
+    array<string> p = trim_spaces (tokenize (as_string(u[N(t)-1]), ","));
+    for (int i=0; i<N(p); i++) {
+      loaded_package (p[i]) = true;
+    }
+    if (loaded_package["algorithm2e"]) {
+      command_arity ("\\Else")   = -2;
+      command_arity ("\\For")    = -3;
+      command_arity ("\\ForAll") = -3;
+      command_arity ("\\If")     = -3;
+      command_arity ("\\Return") = -1;
+      command_arity ("\\While")  = -3;
+    }
+  }
+
   /******************** new commands and environments ************************/
   if (is_tuple (t, "\\def", 2)) {
     string var= string_arg (t[1]);
@@ -705,6 +802,12 @@ latex_parser::parse_command (string s, int& i, string cmd) {
     command_arity (var)= as_int (t[2]);
     command_def   (var)= as_string (u[3]);
   }
+  if (is_tuple (t, "\\def**", 4)) {
+    string var= string_arg (t[1]);
+    command_type  (var)= "user";
+    command_arity (var)= - as_int (t[2]);
+    command_def   (var)= as_string (u[4]);
+  }
   if (is_tuple (t, "\\declaretheorem*", 2) || 
       is_tuple (t, "\\declaretheorem",  1)) {
     string var= "\\begin-" * string_arg (t[N(t)-1]);
@@ -722,6 +825,21 @@ latex_parser::parse_command (string s, int& i, string cmd) {
     command_type  (var)= "environment";
     command_arity (var)= 0;
   }
+  if (is_tuple (t, "\\SetKwData", 2) || is_tuple (t, "\\SetKwFunction", 2)) {
+    string var= "\\"*string_arg (t[1]);
+    command_type  (var)= "algorithm2e";
+    command_arity (var)= -1;
+  }
+  if (is_tuple (t, "\\SetKwInput", 2) || is_tuple (t, "\\SetKwInOut", 2)) {
+    string var= "\\"*string_arg (t[1]);
+    command_type  (var)= "algorithm2e";
+    command_arity (var)= 1;
+  }
+  if (is_tuple (t, "\\SetKw")) {
+    string var= "\\"*string_arg (t[1]);
+    command_type  (var)= "algorithm2e";
+    command_arity (var)= 0;
+  }
   if (is_tuple (t, "\\newdimen", 1) || is_tuple (t, "\\newlength", 1)
       || is_tuple (t, "\\newskip", 1)) {
     string var= string_arg (t[1]);
@@ -752,9 +870,22 @@ latex_parser::parse_command (string s, int& i, string cmd) {
     command_def   (var)= as_string (u[4]);
     if (is_math_environment (t)) command_type (var)= "math-environment";
   }
+  if (is_tuple (t, "\\newenvironment**", 5)) {
+    string var= "\\begin-" * string_arg (t[1]);
+    command_type  (var)= "user";
+    command_arity (var)= -as_int (t[2]);
+    command_def   (var)= as_string (u[4]);
+    if (is_math_environment (t)) command_type (var)= "math-environment";
+    var= "\\end-" * string_arg (t[1]);
+    command_type  (var)= "user";
+    command_arity (var)= 0;
+    command_def   (var)= as_string (u[5]);
+    if (is_math_environment (t)) command_type (var)= "math-environment";
+  }
 
   /***************** environment changes for user commands  ******************/
-  if (latex_type (cmd) == "user") {
+  if ((is_tuple (t, "\\def", 2) || is_tuple (t, "\\def*", 3))
+      && latex_type (cmd) == "user") {
     int pos= 0;
     string body= command_def[cmd];
     textm_recursion_level (cmd)++;
@@ -786,7 +917,7 @@ latex_parser::parse_argument (string s, int& i) {
 tree
 latex_parser::parse_unknown (string s, int& i, string cmd) {
   int  n     = N(s);
-  bool option= false;
+  bool option= true;
 
   tree t (TUPLE, copy (cmd));
   while (i<n) {
@@ -963,7 +1094,7 @@ static char Cork_unaccented[128]= {
   'D', 'N', 'O', 'O', 'O', 'O', 'O', ' ',
   ' ', 'U', 'U', 'U', 'U', 'Y', ' ', ' ',
   'a', 'a', 'a', 'a', 'a', 'a', ' ', 'c',
-  'e', 'e', 'e', 'e', 25 , 25 , 25 , 25 ,
+  'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i',
   'd', 'n', 'o', 'o', 'o', 'o', 'o', ' ',
   ' ', 'u', 'u', 'u', 'u', 'y', ' ', ' '
 };
@@ -1018,7 +1149,7 @@ accented_to_Cork (tree t) {
     }
     else {
       char c1= v[0], c2= s[1];
-      if (v == "\\i") c1= (char) 25;
+      if (v == "\\i") c1= 'i';
       if ((N(v)==1) || (v=="\\i"))
 	for (i=0; i<127; i++)
 	  if ((Cork_unaccented[i]==c1) && (Cork_accent[i]==c2))
@@ -1321,16 +1452,20 @@ latex_encoding_to_iconv (string s) {
 }
 
 tree
-parse_latex (string s, bool change) {
+parse_latex (string s, bool change, bool using_cork) {
   s= dos_to_better (s);
+  string encoding= "Cork";
   string lan= get_latex_language (s);
-  string encoding= latex_encoding_to_iconv (get_latex_encoding (s));
-  if (encoding != "UTF-8" && encoding != "Cork" && encoding != "")
-    s= convert (s, encoding, "UTF-8");
-  else if (encoding == "")
-    s= convert (s, "ISO-8859-1", "UTF-8");
+  if (!using_cork) {
+    encoding= latex_encoding_to_iconv (get_latex_encoding (s));
+    if (encoding != "UTF-8" && encoding != "Cork" && encoding != "")
+      s= convert (s, encoding, "UTF-8");
+    else if (encoding == "")
+      s= convert (s, "ISO-8859-1", "UTF-8");
+  }
 
-  latex_parser ltx (encoding  != "Cork");
+  latex_parser ltx (encoding != "Cork");
+  ltx.lf= 'M';
   tree r= ltx.parse (s, change);
   r= accented_to_Cork (ltx.parse (s, change));
   if (lan == "") return r;
