@@ -16,7 +16,7 @@
 ******************************************************************************/
 
 string DPI ("dpi");
-string SFACTOR ("sfactor");
+string ZOOM_FACTOR ("zoom-factor");
 string PREAMBLE ("preamble");
 string SAVE_AUX ("save-aux");
 string MODE ("mode");
@@ -203,36 +203,55 @@ string CELL_COL_NR ("cell-col-nr");
 * Environment variables for graphics
 ******************************************************************************/
 
-string POINT_STYLE ("point-style");
-
-string LINE_WIDTH ("line-width");
-string DASH_STYLE ("dash-style");
-string DASH_STYLE_UNIT ("dash-style-unit");
-string LINE_ARROWS ("line-arrows");
-string LINE_CAPS ("line-caps");
-string FILL_COLOR ("fill-color");
-string FILL_STYLE ("fill-style");
-string TEXTAT_HALIGN ("text-at-halign");
-string TEXTAT_VALIGN ("text-at-valign");
-
 string GR_GEOMETRY ("gr-geometry");
 string GR_FRAME ("gr-frame");
 string GR_MODE ("gr-mode");
-string GR_OPACITY ("gr-opacity");
-string GR_COLOR ("gr-color");
-string GR_POINT_STYLE ("gr-point-style");
-string GR_LINE_WIDTH ("gr-line-width");
-string GR_DASH_STYLE ("gr-dash-style");
-string GR_DASH_STYLE_UNIT ("gr-dash-style-unit");
-string GR_LINE_ARROWS ("gr-line-arrows");
-string GR_FILL_COLOR ("gr-fill-color");
-string GR_TEXTAT_HALIGN ("gr-text-at-halign");
-string GR_TEXTAT_VALIGN ("gr-text-at-valign");
+string GR_AUTO_CROP ("gr-auto-crop");
+string GR_CROP_PADDING ("gr-crop-padding");
 string GR_GRID ("gr-grid");
 string GR_GRID_ASPECT ("gr-grid-aspect");
 string GR_EDIT_GRID ("gr-edit-grid");
 string GR_EDIT_GRID_ASPECT ("gr-edit-grid-aspect");
 
+string GR_MAGNIFY ("gr-magnify");
+string GR_OPACITY ("gr-opacity");
+string GR_COLOR ("gr-color");
+string GR_POINT_STYLE ("gr-point-style");
+string GR_LINE_WIDTH ("gr-line-width");
+string GR_LINE_JOIN ("gr-line-join");
+string GR_LINE_CAPS ("gr-line-caps");
+string GR_LINE_EFFECTS ("gr-line-effects");
+string GR_DASH_STYLE ("gr-dash-style");
+string GR_DASH_STYLE_UNIT ("gr-dash-style-unit");
+string GR_ARROW_BEGIN ("gr-arrow-begin");
+string GR_ARROW_END ("gr-arrow-end");
+string GR_ARROW_LENGTH ("gr-arrow-length");
+string GR_ARROW_HEIGHT ("gr-arrow-height");
+string GR_FILL_COLOR ("gr-fill-color");
+string GR_FILL_STYLE ("gr-fill-style");
+string GR_TEXT_AT_HALIGN ("gr-text-at-halign");
+string GR_TEXT_AT_VALIGN ("gr-text-at-valign");
+string GR_TEXT_AT_MARGIN ("gr-text-at-margin");
+
+string GID ("gid");
+string MAGNIFY ("magnify");
+string POINT_STYLE ("point-style");
+string LINE_WIDTH ("line-width");
+string LINE_JOIN ("line-join");
+string LINE_CAPS ("line-caps");
+string LINE_EFFECTS ("line-effects");
+string DASH_STYLE ("dash-style");
+string DASH_STYLE_UNIT ("dash-style-unit");
+string ARROW_BEGIN ("arrow-begin");
+string ARROW_END ("arrow-end");
+string ARROW_LENGTH ("arrow-length");
+string ARROW_HEIGHT ("arrow-height");
+string FILL_COLOR ("fill-color");
+string FILL_STYLE ("fill-style");
+string TEXT_AT_HALIGN ("text-at-halign");
+string TEXT_AT_VALIGN ("text-at-valign");
+string TEXT_AT_MARGIN ("text-at-margin");
+
 /******************************************************************************
 * Environment variables for preamble mode
 ******************************************************************************/
