@@ -130,6 +130,14 @@ locase (char c) {
   else return c;
 }
 
+char
+closing_delimiter (char c) {
+  if (c == '{') return '}';
+  if (c == '(') return ')';
+  if (c == '[') return ']';
+  return c;
+}
+
 string
 upcase_first (string s) {
   if ((N(s)==0) || (!is_locase (s[0]))) return s;
@@ -563,11 +571,14 @@ Alpha_nr (int nr) {
 string
 fnsymbol_nr (int nr) {
   string sym, r;
-  int i, m= (nr-1)%3, n= ((nr-1)/3)+1;
+  int i, m= (nr-1)%6, n= ((nr-1)/6)+1;
   switch (m) {
-  case 0: sym= "<ast>"; break;
-  case 1: sym= "<dag>"; break;
-  case 2: sym= "<ddag>"; break;
+    case 0: sym= "<ast>";        break;
+    case 1: sym= "<dag>";        break;
+    case 2: sym= "<ddag>";       break;
+    case 3: sym= "<paragraph>";  break;
+    case 4: sym= "<endofline>";  break;
+    case 5: sym= "||";           break;
   }
   for (i=0; i<n; i++) r << sym;
   return r;
@@ -839,6 +850,8 @@ escape_sh (string s) {
   string r;
   for (i=0; i<n; i++)
     switch (s[i]) {
+    case '<':
+    case '>':
     case '?':
     case '&':
     case '$':
@@ -900,6 +913,27 @@ dos_to_better (string s) {
   return r;
 }
 
+string
+unescape_guile (string s) {
+  int i, n= N(s);
+  string r;
+  for (i=0; i<n; i++) {
+    if (s[i] == '\\') {
+      if (i+3 < n && s[i+1] == 'x'
+          && is_hex_digit (s[i+2]) && is_hex_digit (s[i+3])) {
+        string e= s(i+2, i+4);
+        r << (unsigned char) from_hexadecimal (e);
+        i+=3;
+      }
+      else
+        r << s[i];
+    }
+    else
+      r << s[i];
+  }
+  return r;
+}
+
 /******************************************************************************
 * Reading input from a string
 ******************************************************************************/
@@ -1200,6 +1234,7 @@ tokenize (string s, string sep) {
       start= i;
     }
     else i++;
+  a << s(start, N(s));
   return a;
 }
 
@@ -1217,8 +1252,8 @@ string
 trim_spaces (string s) {
   int start, end;
   for (start=0; start<N(s) && is_space (s[start]); start++) ;
-  for (end=N(s); end>start && is_space (s[end]); end--) ;
-  return s (start, end);
+  for (end=N(s)-1; end > start && is_space (s[end]); end--) ;
+  return s (start, end+1);
 }
 
 array<string>
@@ -1229,6 +1264,20 @@ trim_spaces (array<string> a) {
   return b;
 }
 
+tree
+trim_spaces (tree t) {
+  if (is_atomic (t)) return trim_spaces (as_string (t));
+  else if (is_concat (t)) {
+    int start, end;
+    for (start=0; start < N(t) && t[start] == " "; start++);
+    for (end=N(t)-1; end > start && t[end] == " "; end--);
+    tree r= tree (L(t));
+    for (int i=start; i<=end; i++) r << t[i];
+    return r;
+  }
+  else return t;
+}
+
 /******************************************************************************
 * Computations with completions
 ******************************************************************************/
