@@ -32,6 +32,7 @@ bool is_numeric (string s);
 
 char   upcase (char s);
 char   locase (char s);
+char   closing_delimiter (char c);
 string upcase_first (string s);
 string locase_first (string s);
 string upcase_all (string s);
@@ -93,6 +94,7 @@ string escape_sh (string s);
 string escape_generic (string s);
 string escape_verbatim (string s);
 string escape_spaces (string s);
+string unescape_guile (string s);
 string dos_to_better (string s);
 
 bool test (string s, int i, const char* test);
@@ -130,6 +132,7 @@ bool   match_wildcard (string s, string w);
 array<string> tokenize (string s, string sep);
 string recompose (array<string> a, string sep);
 string trim_spaces (string s);
+tree   trim_spaces (tree t);
 array<string> trim_spaces (array<string> a);
 
 array<string> as_completions (hashset<string> h);
