@@ -26,7 +26,7 @@ RESOURCE(converter);
 * The hashtree and converter classes are used.
 ******************************************************************************/
 
-class converter_rep: public rep<converter> {
+struct converter_rep: rep<converter> {
   hashtree<char,string> ht;
   string output, nil_string, from, to;
   bool copy_unmatched;
@@ -40,7 +40,7 @@ public:
 
   inline bool has_value(hashtree<char,string> node);
 
-  friend class converter;
+  friend struct converter;
   friend string flush (converter c);
   friend string apply (converter c, string str);
   friend void operator << (converter c, string str);
@@ -77,6 +77,8 @@ string convert_to_cork (string input, string from);
 string convert_from_cork (string input, string to); 
 string utf8_to_cork (string input); 
 string cork_to_utf8 (string input); 
+string cork_to_sourcecode (string input);
+string sourcecode_to_cork (string input);
 string convert_utf8_to_LaTeX (string input);
 string utf8_to_html (string input);
 string t2a_to_utf8 (string input);
