@@ -68,6 +68,8 @@ public:
   double   get_env_double (string var_name);
   double   get_init_double (string var_name);
   language get_env_language ();
+  SI       get_page_width ();
+  SI       get_page_height ();
 
   tree     exec (tree t, hashmap<string,tree> env, bool expand_refs= true);
   tree     exec_texmacs (tree t, path p);
