@@ -4,10 +4,9 @@
 * DESCRIPTION: for cursor handling in TeXmacs
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #ifndef EDIT_CURSOR_H
@@ -30,7 +29,7 @@ protected:
   cursor& the_ghost_cursor ();
 
   path make_cursor_accessible (path p, bool forwards);
-  path tree_path (SI x, SI y, SI delta);
+  path tree_path (path sp, SI x, SI y, SI delta);
   bool cursor_move_sub (SI& x0, SI& y0, SI& delta, SI dx, SI dy);
   void cursor_move (SI dx, SI dy);
   void adjust_ghost_cursor (int status);
@@ -42,7 +41,7 @@ public:
   ~edit_cursor_rep ();
 
   /* visual cursor movement */
-  void go_to (SI x, SI y);
+  void go_to (SI x, SI y, bool absolute= true);
   void go_left_physical ();
   void go_right_physical ();
   void go_left ();
