@@ -28,7 +28,7 @@
 #  include "../Style/Memorizer/memorizer.hpp"
 #endif
 #include "new_data.hpp"
-#define TEXMACS_COPYRIGHT (string("(c) 1999-2006 by Joris van der Hoeven"))
+#define TEXMACS_COPYRIGHT (string("(c) 1999-2013 by Joris van der Hoeven and others"))
 
 #define THE_CURSOR 1
 #define THE_FOCUS 2
@@ -68,7 +68,6 @@ protected:
 #endif
 
   /* exchanging information with the interface */
-  virtual SI        get_window_height () = 0;
   virtual void      get_selection (path& start, path& end) = 0;
   virtual void      set_selection (path start, path end) = 0;
   virtual cursor&   the_cursor () = 0;
@@ -136,6 +135,10 @@ public:
   virtual void suspend () = 0;
   virtual void resume () = 0;
   virtual int  get_pixel_size () = 0;
+  virtual SI   get_visible_width () = 0;
+  virtual SI   get_visible_height () = 0;
+  virtual SI   get_window_width () = 0;
+  virtual SI   get_window_height () = 0;
   virtual void invalidate (SI x1, SI y1, SI x2, SI y2) = 0;
   virtual void invalidate (rectangles rs) = 0;
   virtual void notify_change (int changed) = 0;
@@ -171,6 +174,7 @@ public:
   virtual void mouse_select (SI x, SI y, int mods, bool drag) = 0;
   virtual void mouse_paste (SI x, SI y) = 0;
   virtual void mouse_adjust (SI x, SI y) = 0;
+  virtual void mouse_adjust_selection (SI x, SI y, int mods) = 0;
   virtual void mouse_scroll (SI x, SI y, bool up) = 0;
   virtual cursor get_cursor () = 0;
   virtual void set_pointer (string name) = 0;
@@ -257,6 +261,8 @@ public:
   virtual double   get_env_double (string var_name) = 0;
   virtual double   get_init_double (string var_name) = 0;
   virtual language get_env_language () = 0;
+  virtual SI       get_page_width () = 0;
+  virtual SI       get_page_height () = 0;
   virtual tree     exec_texmacs (tree t, path p) = 0;
   virtual tree     exec_texmacs (tree t) = 0;
   virtual tree     exec_verbatim (tree t, path p) = 0;
