@@ -12,6 +12,7 @@
 #include "modification.hpp"
 #include "analyze.hpp"
 #include "hashmap.hpp"
+#include "blackbox.hpp"
 
 #define DETACHED (-5)
 
@@ -728,6 +729,12 @@ observer_rep::get_tree (tree& t) {
   return false;
 }
 
+bool
+observer_rep::get_contents (int kind, blackbox& bb) {
+  (void) kind; (void) bb;
+  return false;
+}
+
 bool
 observer_rep::set_highlight (int lan, int col, int start, int end) {
   (void) col; (void) start; (void) end; (void) lan;
