@@ -30,7 +30,7 @@ class rectangle {
 };
 CONCRETE_CODE(rectangle);
 
-ostream& operator << (ostream& out, rectangle r);
+tm_ostream& operator << (tm_ostream& out, rectangle r);
 rectangle copy (rectangle r);
 bool operator == (rectangle r1, rectangle r2);
 bool operator != (rectangle r1, rectangle r2);
@@ -39,6 +39,9 @@ bool operator <= (rectangle r1, rectangle r2);
 rectangle translate (rectangle r, SI x, SI y);
 rectangle operator * (rectangle r, int d);
 rectangle operator / (rectangle r, int d);
+rectangle operator * (rectangle r, double x);
+rectangle operator / (rectangle r, double x);
+rectangle thicken (rectangle r, SI width, SI height);
 double area (rectangle r);
 
 typedef list<rectangle> rectangles;
