@@ -18,6 +18,7 @@
 ******************************************************************************/
 
 tree type_helper<tree>::init (UNINIT);
+int type_helper<tree>::id  = new_type_identifier ();
 
 void
 destroy_tree_rep (tree_rep* rep) {
@@ -362,6 +363,11 @@ is_mod_active_once (tree t) {
     ((L(t) == STYLE_ONLY) || (L(t) == ACTIVE) || (L(t) == INACTIVE));
 }
 
+bool
+is_graphical_text (tree t) {
+  return is_func (t, TEXT_AT) || is_func (t, MATH_AT);
+}
+
 bool
 is_empty (tree t) {
   if (is_atomic (t)) return (t == "");
