@@ -34,7 +34,8 @@ public:
   void  polygon (array<SI> x, array<SI> y, bool convex=true);
   void  xpm (url file_name, SI x, SI y);
   void  image (url u, SI w, SI h, SI x, SI y,
-	       double cx1, double cy1, double cx2, double cy2);
+	       double cx1, double cy1, double cx2, double cy2,
+               int alpha);
 
   /***** private section *****************************************************/
   
