@@ -10,6 +10,7 @@
 ******************************************************************************/
 
 #include "tt_file.hpp"
+#include "tt_tools.hpp"
 #include "file.hpp"
 #include "boot.hpp"
 #include "analyze.hpp"
@@ -26,6 +27,28 @@ search_sub_dirs (url root) {
   return expand (dirs);
 }
 
+url
+tt_font_path () {
+  string xtt= get_env ("TEXMACS_FONT_PATH");
+  url xu= url_none ();
+  if (xtt != "") xu= search_sub_dirs (xtt);
+  return
+    xu |
+    search_sub_dirs ("$TEXMACS_HOME_PATH/fonts/truetype") |
+    search_sub_dirs ("$TEXMACS_PATH/fonts/truetype") |
+#if defined __MINGW32__
+    search_sub_dirs ("$windir/Fonts");
+#elif defined OS_MACOS
+    search_sub_dirs ("$HOME/Library/Fonts") |
+    search_sub_dirs ("/Library/Fonts") |
+    search_sub_dirs ("/System/Library/Fonts");
+#else
+    search_sub_dirs ("$HOME/.fonts") |
+    search_sub_dirs ("/usr/share/fonts/truetype") |
+    search_sub_dirs ("/usr/local/share/fonts/truetype");
+#endif
+}
+
 static url
 tt_locate (string name) {
   if (ends (name, ".pfb")) {
@@ -71,19 +94,7 @@ tt_locate (string name) {
 	}
     }
 
-  url tt_path=
-    search_sub_dirs ("$TEXMACS_HOME_PATH/fonts/truetype") |
-#if defined __MINGW32__
-    search_sub_dirs ("$windir/Fonts");
-#elif defined OS_MACOS
-    search_sub_dirs ("$HOME/Library/Fonts") |
-    search_sub_dirs ("/Library/Fonts") |
-    search_sub_dirs ("/System/Library/Fonts");
-#else
-    search_sub_dirs ("$HOME/.fonts") |
-    search_sub_dirs ("/usr/share/fonts/truetype") |
-    search_sub_dirs ("/usr/local/share/fonts/truetype");
-#endif
+  url tt_path= tt_font_path ();
   //cout << "Resolve " << name << " in " << tt_path << "\n";
   return resolve (tt_path * name);
 }
@@ -91,7 +102,9 @@ tt_locate (string name) {
 url
 tt_font_find_sub (string name) {
   //cout << "tt_font_find " << name << "\n";
-  url u= tt_locate (name * ".pfb");
+  url u= tt_unpack (name);
+  if (!is_none (u)) return u;
+  u= tt_locate (name * ".pfb");
   //if (!is_none (u)) cout << name << " -> " << u << "\n";
   if (!is_none (u)) return u;
   u= tt_locate (name * ".ttf");
