@@ -42,7 +42,7 @@ gs_supports (url image) {
 bool
 gs_image_size_sub (string buf, int& w_pt, int& h_pt) {
   int pos= search_forwards ("\n%%BoundingBox: ", buf);
-  if (pos < 0) search_forwards ("%%BoundingBox: ", buf);
+  if (pos < 0) pos = search_forwards ("%%BoundingBox: ", buf);
   if (pos < 0) return false;
   if (buf[pos] == '\n') pos++;
   bool ok= read (buf, pos, "%%BoundingBox: ");
@@ -104,7 +104,7 @@ void
 gs_to_png (url image, url png, int w, int h) {
   if (use_converts (image)) {
     string cmd= "convert ";
-    cmd << "-geometry " << as_string (w) << "x" << as_string (h) << "! ";  
+    cmd << "-density 300x300 -geometry " << as_string (w) << "x" << as_string (h) << "! ";  
     cmd << sys_concretize (image) << " ";
     cmd << sys_concretize (png);
     system (cmd);
