@@ -17,7 +17,7 @@ bool imlib2_present ();
 bool imlib2_supports (url u);
 void imlib2_image_size (url u, int& w, int& h);
 
-#ifdef X11TEXMACS
+#ifdef IMLIB2_X11TEXMACS
 #include <X11/Xlib.h>
 void imlib2_display (Display* dpy, Pixmap pm, url image, int w, int h,
 		     double cx1, double cy1, double cx2, double cy2);
