@@ -4,10 +4,9 @@
 * DESCRIPTION: load pk files
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 *******************************************************************************
 * This program is a modified version of the program 'pk2bm' by Piet Tutelaers.
 * It also uses parts of 'dvips' by Tomas Rokicki
@@ -15,9 +14,9 @@
 
 #include "load_tex.hpp"
 #include "timer.hpp"
+#include "renderer.hpp" // for PIXEL
 
 typedef short HI;
-#define PIXEL 256
 
 /******************************************************************************
 * Initialize the pk_loader
@@ -30,7 +29,7 @@ pk_loader::pk_loader (url pk_file_name, tex_font_metric tfm2, int dpi2):
   bc (tfm->bc), ec (tfm->ec),
   char_pos(0), char_flag(0), unpacked(0)
 {
-  (void) load_string (pk_file_name, input_s);
+  (void) load_string (pk_file_name, input_s, true);
   input_pos= 0;
 }
 
@@ -42,7 +41,7 @@ HI
 pk_loader::pkbyte () {
   if (input_pos == N(input_s)) {
     cerr << "\npk file= " << file_name << "\n";
-    fatal_error ("unexpected eof in pk file", "pkbyte", "load-pk.cpp");
+    FAILED ("unexpected eof in pk file");
   }
   return (HI) ((QN) input_s [input_pos++]);
 }
@@ -148,8 +147,8 @@ pk_loader::rest () {
     return i;
   }
   cerr << "\npk file= " << file_name << "\n";
-  fatal_error ("unexpected situation", "rest", "load-pk.cpp");
-  return 0; // Because of bug in certain versions of g++
+  FAILED ("unexpected situation");
+  return 0;
 }
 
 HN
@@ -264,8 +263,7 @@ pk_loader::unpack (glyph& gl) {
     }
     if ((rowsleft != 0) || (hbit != gl->width)) {
       cerr << "\npk file= " << file_name << "\n";
-      fatal_error ("more bits than required while unpacking",
-		   "unpack", "load-pk.cpp");
+      FAILED ("more bits than required while unpacking");
     }
   }
 }
@@ -287,10 +285,10 @@ pk_loader::load_pk () {
   register SI yoff;
   
   bench_start ("decode pk");
-  glyph* fng= new glyph [ec+1-bc];
-  char_pos = new int [ec+1-bc];
-  unpacked = new bool [ec+1-bc];
-  char_flag = new HN [ec+1-bc];
+  glyph* fng= tm_new_array<glyph> (ec+1-bc);
+  char_pos = tm_new_array<int> (ec+1-bc);
+  unpacked = tm_new_array<bool> (ec+1-bc);
+  char_flag = tm_new_array<HN> (ec+1-bc);
   for(i=0;i<ec+1-bc;i++) {
     char_pos[i] = 0;
     char_flag[i] = 0;
@@ -300,11 +298,11 @@ pk_loader::load_pk () {
   // Preamble
   if (pkbyte ()!=247) {
     cerr << "\npk file= " << file_name << "\n";
-    fatal_error ("bad pk file, expected pre", "load_pk", "load-pk.cpp");
+    FAILED ("bad pk file");
   }
   if (pkbyte ()!=89) {
     cerr << "\npk file= " << file_name << "\n";
-    fatal_error ("bad version of pk file", "load_pk", "load-pk.cpp");
+    FAILED ("bad version of pk file");
   }
   for(i=pkbyte (); i>0; i--) (void) pkbyte (); /* creator of pkfile */
   (void) pkquad (); /* design size */
@@ -338,13 +336,13 @@ pk_loader::load_pk () {
       case 5:
 	cerr << "\npk file= " << file_name << "\n";
 	cerr << "last charcode= " << charcode << "\n";
-	fatal_error ("lost sync in pk file (character too big / status = 5)",
-		     "load_pk", "load-pk.cpp");
+	FAILED ("lost sync in pk file (character too big / status = 5)");
+	break;
       case 6:
 	cerr << "\npk file= " << file_name << "\n";
 	cerr << "last charcode= " << charcode << "\n";
-	fatal_error ("lost sync in pk file (character too big / status = 6)",
-		     "load_pk", "load-pk.cpp");
+	FAILED ("lost sync in pk file (character too big / status = 6)");
+	break;
       case 7:
 	length = pkquad ();
 	charcode = pkquad ();
@@ -414,14 +412,14 @@ pk_loader::load_pk () {
 	cerr << "\npk file= " << file_name << "\n";
 	cerr << "last charcode= " << charcode << "\n";
 	cerr << "flagbyte= " << flagbyte << "\n";
-	fatal_error ("lost sync in pk file", "load_pk", "load-pk.cpp");
+	FAILED ("lost sync in pk file");
       }
     }
   }
 
   register int c;
   for (c=0; c<=ec-bc; c++)
-    if (!nil (fng[c])) {
+    if (!is_nil (fng[c])) {
       SI design_size = tfm->design_size () >> 12;
       SI display_size= (((design_size*dpi)/72)*PIXEL) >> 8;
       double unit    = ((double) display_size) / ((double) (1<<20));
