@@ -4,10 +4,9 @@
 * DESCRIPTION: manipulation of TeX font files
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "tex_files.hpp"
@@ -70,6 +69,11 @@ resolve_pfb (url name) {
   return resolve (the_pfb_path * name);
 }
 
+url
+tfm_font_path () {
+  return the_tfm_path;
+}
+
 /******************************************************************************
 * Caching results
 ******************************************************************************/
@@ -98,6 +102,7 @@ resolve_tex (url name) {
   bench_cumul ("resolve tex");
 
   if (!is_none (u)) cache_set ("font_cache.scm", s, as_string (u));
+  //cout << "Resolve " << name << " -> " << u << "\n";
   return u;
 }
 
@@ -113,10 +118,11 @@ exists_in_tex (url u) {
 void
 make_tex_tfm (string name) {
   string s;
+  int r= 0;
   if (get_setting ("MAKETFM") == "MakeTeXTFM") {
     s= "MakeTeXTFM " * name;
     if (DEBUG_VERBOSE) cout << "TeXmacs] Executing " << s << "\n";
-    system (s);
+    r= system (s);
   }
   if (get_setting ("MAKETFM") == "mktextfm") {
     url tfm_dir ("$TEXMACS_HOME_PATH/fonts/tfm");
@@ -124,7 +130,7 @@ make_tex_tfm (string name) {
       string ("--destdir ") * as_string (tfm_dir) * " " *
       name;
     if (DEBUG_VERBOSE) cout << "TeXmacs] Executing " << s << "\n";
-    system (s);
+    r= system (s);
     string superfluous= name * ".600pk";
     if (ends (name, ".tfm")) superfluous= name (0, N(name)-4) * ".600pk";
     remove (tfm_dir * superfluous);
@@ -135,19 +141,21 @@ make_tex_tfm (string name) {
     s = "maketfm --dest-dir \"" * get_env("$TEXMACS_HOME_PATH")
       * "\\fonts\\tfm\" " * name;
     if (DEBUG_VERBOSE) cout << "TeXmacs] Executing " << s << "\n";
-    system (s);
+    r= system (s);
   }
+  if (r) cout << "TeXmacs] system command failed: " << s << "\n";
 }
 
 void
 make_tex_pk (string name, int dpi, int design_dpi) {
   string s;
+  int r= 0;
   if (get_setting ("MAKEPK") == "MakeTeXPK") {
     s="MakeTeXPK " * name * " " *
       as_string (dpi) * " " * as_string (design_dpi) * " " *
       as_string (dpi) * "/" * as_string (design_dpi) * " localfont";
     if (DEBUG_VERBOSE) cout << "TeXmacs] Executing " << s << "\n";
-    system (s);
+    r= system (s);
   }
   if (get_setting ("MAKEPK") == "mktexpk") {
     url pk_dir ("$TEXMACS_HOME_PATH/fonts/pk");
@@ -158,7 +166,7 @@ make_tex_pk (string name, int dpi, int design_dpi) {
       string ("--destdir ") * as_string (pk_dir) * " " *
       name;
     if (DEBUG_VERBOSE) cout << "TeXmacs] Executing " << s << "\n";
-    system (s);
+    r= system (s);
   }
   if (get_setting ("MAKEPK") == "makepk") {
 #ifdef OS_WIN32
@@ -173,8 +181,9 @@ make_tex_pk (string name, int dpi, int design_dpi) {
       * " " * as_string(dpi) * "/" * as_string(design_dpi);
 #endif
     if (DEBUG_VERBOSE) cout << "TeXmacs] Executing " << s << "\n";
-    system (s);
+    r= system (s);
   }
+  if (r) cout << "TeXmacs] system command failed: " << s << "\n";
 }
 
 /******************************************************************************
