@@ -18,6 +18,7 @@
 ******************************************************************************/
 
 struct tex_rubber_font_rep: font_rep {
+  string           trl;
   string           family;
   int              dpi;
   int              dsize;
@@ -32,7 +33,8 @@ struct tex_rubber_font_rep: font_rep {
   void get_partial_extents (int c, metric& ex);
   void get_extents (string s, metric& ex);
   void draw (renderer ren, int c, SI x, SI& y, SI& real_y);
-  void draw (renderer ren, string s, SI x, SI y);
+  void draw_fixed (renderer ren, string s, SI x, SI y);
+  font magnify (double zoom);
 
   double get_left_slope (string s);
   double get_right_slope (string s);
@@ -43,7 +45,8 @@ struct tex_dummy_rubber_font_rep: font_rep {
   font base_fn;
   tex_dummy_rubber_font_rep (string name, font base_fn);
   void get_extents (string s, metric& ex);
-  void draw (renderer ren, string s, SI x, SI y);
+  void draw_fixed (renderer ren, string s, SI x, SI y);
+  font magnify (double zoom);
 };
 
 /******************************************************************************
@@ -54,7 +57,8 @@ struct tex_dummy_rubber_font_rep: font_rep {
 
 tex_rubber_font_rep::tex_rubber_font_rep (string name,
   string trl_name, string family2, int size2, int dpi2, int dsize2):
-    font_rep (name), dsize (dsize2), ext (load_translator (trl_name))
+    font_rep (name), trl (trl_name), dsize (dsize2),
+    ext (load_translator (trl_name))
 {
   load_tex (family2, size2, dpi2, dsize, tfm, pk);
 
@@ -202,14 +206,14 @@ void
 tex_rubber_font_rep::draw (renderer ren, int c, SI x, SI& y, SI& real_y) {
   ren->draw (c, pk, x, y);
   SI delta  = conv (tfm->h (c)+ tfm->d (c));
-  SI pixel  = PIXEL * ren->sfactor;
+  SI pixel  = ren->pixel;
   y        -= pixel * (delta/pixel);
   real_y   -= delta;
   while (y >= real_y + pixel) y -= pixel;
 }
 
 void
-tex_rubber_font_rep::draw (renderer ren, string s, SI x, SI y) {
+tex_rubber_font_rep::draw_fixed (renderer ren, string s, SI x, SI y) {
   metric ex;
   get_extents (s, ex);
 
@@ -243,6 +247,12 @@ tex_rubber_font_rep::draw (renderer ren, string s, SI x, SI y) {
   }
 }
 
+font
+tex_rubber_font_rep::magnify (double zoom) {
+  int ndpi= (int) tm_round (dpi * zoom);
+  return tex_rubber_font (trl, family, size, ndpi, dsize);
+}
+
 /******************************************************************************
 * Metric properties of rubber boxes
 ******************************************************************************/
@@ -297,10 +307,15 @@ tex_dummy_rubber_font_rep::get_extents (string s, metric& ex) {
 }
 
 void
-tex_dummy_rubber_font_rep::draw (renderer ren, string s, SI x, SI y) {
+tex_dummy_rubber_font_rep::draw_fixed (renderer ren, string s, SI x, SI y) {
   (void) ren; (void) s; (void) x; (void) y;
 }
 
+font
+tex_dummy_rubber_font_rep::magnify (double zoom) {
+  return tex_dummy_rubber_font (base_fn->magnify (zoom));
+}
+
 font
 tex_dummy_rubber_font (font base_fn) {
   string name= "tex-dummy(" * base_fn->res_name * ")";
