@@ -26,8 +26,10 @@
 #include "dictionary.hpp"
 #include "image_files.hpp"
 
-QTMFileDialog::QTMFileDialog (QWidget * parent, const QString & caption, const QString & directory, const QString & filter)
-  : QDialog (parent) {
+QTMFileDialog::QTMFileDialog (QWidget * parent, const QString & caption, 
+                              const QString & directory, const QString & filter)
+  : QDialog (parent) 
+{
   setWindowTitle (caption);
   hbox= new QHBoxLayout (this);
   hbox->setContentsMargins (0, 0, 0, 0);
@@ -78,7 +80,7 @@ simple_input (string s, QLineEdit* ledit, QWidget* parent= 0) {
 //  string in_lan= get_input_language ();
 //  string out_lan= get_output_language ();
 //  QLabel* label= new QLabel (to_qstring (tm_var_encode (translate (s, in_lan, out_lan))), parent);
-  QLabel* label= new QLabel (to_qstring (qt_translate (s)), parent);
+  QLabel* label= new QLabel (to_qstring (s), parent);
   layout->addWidget (label);
   layout->addWidget (ledit);
   widget->setLayout (layout);
