@@ -13,9 +13,7 @@
 #define QTMGUIHELPER_HPP
 
 #include "qt_gui.hpp"
-#include "qt_ui_element.hpp"  // qt_refresh_widget_rep
 #include <QObject>
-#include <QTranslator>
 
 /*!
  */
@@ -46,33 +44,4 @@ signals:
   void tmSlotRefresh ();   //!< qt_widgets which need to refresh connect here.
 };
 
-
-class QTMTranslator : public QTranslator {
-  Q_OBJECT
-  
-public:
-  QTMTranslator(QObject * parent = NULL ) : QTranslator(parent) {};
-  virtual QString translate (const char* context, const char* sourceText, 
-                             const char* disambiguation = 0 ) const ;  
-};
-
-
-/*! A container widget which redraws the widgets it owns. */
-class QTMRefreshWidget : public QWidget {
-  Q_OBJECT
-  
-  string tmwid;
-  object curobj;
-  widget cur;
-  hashmap<object,widget> cache;
-  
-public:
-  QTMRefreshWidget (string _tmwid);
-  
-  bool recompute ();
-  
-public slots:
-  void doRefresh ();  
-};
-
 #endif // QTMGUIHELPER_HPP
