@@ -166,22 +166,19 @@ QTMWidget::QTMWidget (QWidget* _parent, qt_simple_widget_rep* _tmwid)
 
   backing_pos = origin ();
   surface()->setMouseTracking (true);
-  if (_tmwid) 
+  if(_tmwid)
     set_tm_widget (_tmwid);
 }
 
 
 QTMWidget::~QTMWidget () {
-  if (DEBUG_QT) cout << "destroying QTMWidget: " << (long)this << LF;
+  if (DEBUG_QT) 
+    cout << "Destroying QTMWidget " << (long)this 
+         << " of widget " << (tm_widget() ? tm_widget()->type_as_string() : "NULL") 
+         << LF;
   
     // remove ourselves from the list of QWidgets to be repainted.
   all_widgets.remove(this);
-    // remove ourselves from the containing stack (if any) or we'll crash
-    // when it gets freed.
-    // FIXME: Under what conditions happens this after ~QTMWidget?
-  QStackedWidget* stack = qobject_cast<QStackedWidget*> (parentWidget());
-  if (stack)
-    stack->removeWidget(this);
 }
 
 /*! Sets the underlying qt_simple_widget_rep for this object.
@@ -193,11 +190,12 @@ QTMWidget::~QTMWidget () {
 */
 void
 QTMWidget::set_tm_widget (qt_simple_widget_rep* _tmwid) {
-  tmwid = _tmwid;
-  int width, height;
-  tmwid->handle_get_size_hint (width, height);
-  QSize sz = QSize (width/PIXEL, height/PIXEL);
-  surface()->resize(sz);
+  tmwid = widget(_tmwid);
+}
+
+qt_simple_widget_rep*
+QTMWidget::tm_widget () const { 
+  return concrete_simple_widget(tmwid); 
 }
 
 
@@ -327,15 +325,6 @@ QTMWidget::repaint_invalid_regions () {
     QSize _oldSize = backingPixmap.size();
     QSize _newSize = surface()->size();
     
-    /*
-      /////// HACK ALERT! HACK ALERT! HACK ALERT! HACK ALERT!
-    if (_newSize.width() == 0 || _newSize.height() == 0) { 
-      int width, height;
-      tmwid->handle_get_size_hint (width, height);
-      _newSize = QSize (width/PIXEL, height/PIXEL);
-      surface()->resize(_newSize);
-    }
-     */
       //cout << "      surface size of " << _newSize.width() << " x " 
       // << _newSize.height() << LF;
     
@@ -368,9 +357,9 @@ QTMWidget::repaint_invalid_regions () {
         invalid_regions= rectangles (lub);
       
       basic_renderer_rep* ren = getRenderer();
-      tmwid->set_current_renderer(ren);
+      tm_widget()->set_current_renderer(ren);
       
-      SI ox = -backing_pos.x()*PIXEL;
+      SI ox = -backing_pos.x()*PIXEL;  // Warning: this is NOT from_qpoint()
       SI oy = backing_pos.y()*PIXEL;
       
       rectangles rects = invalid_regions;
@@ -381,11 +370,11 @@ QTMWidget::repaint_invalid_regions () {
         rectangle r0 = rects->item;
         QRect qr = QRect(r0->x1, r0->y1, r0->x2 - r0->x1, r0->y2 - r0->y1);
         //cout << "repainting " << r0 << "\n";
-        ren->set_origin(ox,oy); 
+        ren->set_origin(ox, oy); 
         ren->encode (r->x1, r->y1);
         ren->encode (r->x2, r->y2);
         ren->set_clipping (r->x1, r->y2, r->x2, r->y1);
-        tmwid->handle_repaint (r->x1, r->y2, r->x2, r->y1);
+        tm_widget()->handle_repaint (r->x1, r->y2, r->x2, r->y1);
         if (ren->interrupted ()) {
           //cout << "interrupted repainting of  " << r0 << "\n";
           //ren->set_color(green);
@@ -397,7 +386,7 @@ QTMWidget::repaint_invalid_regions () {
         rects = rects->next;
       }
       
-      tmwid->set_current_renderer(NULL);
+      tm_widget()->set_current_renderer(NULL);
       ren->end();
     } // !is_nil(invalid_regions)
     
@@ -419,12 +408,9 @@ QTMWidget::scrollContentsBy ( int dx, int dy ) {
 
 void 
 QTMWidget::resizeEvent( QResizeEvent* event ) {
-  (void) event;
-  
-  // cout << "QTMWidget::resizeEvent (" << event->size().width()
-  //      << "," << event->size().height() << ")" << LF;
-  
-  the_gui -> process_resize(tmwid, 0, 0); // FIXME
+    // Is this ok?
+  coord2 s = from_qsize(event->size());
+  the_gui -> process_resize(tm_widget(), s.x1, s.x2);
 
   // force_update();
 
@@ -449,22 +435,20 @@ QTMWidget::resizeEvent( QResizeEvent* event ) {
 */
 void
 QTMWidget::paintEvent (QPaintEvent* event) {
-  if (DEBUG_QT) 
-  {
+  /*
+  if (DEBUG_QT) {
     QRect rect = event->rect ();
     cout << "paintEvent ("<< rect.x() << "," <<  rect.y()
     << "," <<  rect.width() << "," <<  rect.height() << ")" << LF ;
   }
-    
-  {    
-    QPainter p (surface());
-    QVector<QRect> rects = event->region().rects();
-    for (int i=0; i< rects.count(); i++) {
-      QRect qr = rects.at(i);
-      p.drawPixmap(qr,backingPixmap,qr);
-    }
-  } 
-  
+  */
+
+  QPainter p (surface());
+  QVector<QRect> rects = event->region().rects();
+  for (int i=0; i< rects.count(); i++) {
+    QRect qr = rects.at(i);
+    p.drawPixmap(qr,backingPixmap,qr);
+  }
 }
 
 
@@ -480,7 +464,7 @@ QTMWidget::keyPressEvent (QKeyEvent* event) {
 
   if (DEBUG_QT)
     cout << "keypressed\n";
-  if (tmwid->ref_count == 0) return;
+  if (tm_widget()->ref_count == 0) return;
 
   {
     int key = event->key();
@@ -508,7 +492,7 @@ QTMWidget::keyPressEvent (QKeyEvent* event) {
         if (ac && ac != ' ') { // a true ascii printable
           r= ac;
           if (DEBUG_QT) cout << "ascii key= " <<r << "\n";	
-          the_gui->process_keypress(tmwid, r, texmacs_time());
+          the_gui->process_keypress(tm_widget(), r, texmacs_time());
           return;
         }
       }
@@ -559,7 +543,7 @@ QTMWidget::keyPressEvent (QKeyEvent* event) {
             // but this format is not used for keypresses, so we must remove
             // them.
             int len= N(tstr);
-            if (len >= 1 && tstr(0,1) == "<" && tstr(len-1,len) == ">")
+            if (len >= 1 && tstr[0] == '<' && tstr[1] != '#' && tstr[len-1] == '>')
               r= tstr(1, len-1);
             else
               r= tstr;
@@ -594,8 +578,8 @@ QTMWidget::keyPressEvent (QKeyEvent* event) {
     if (DEBUG_QT)
       cout << "key press: " << r << LF;
     //int start= texmacs_time ();
-    //tmwid -> handle_keypress (r, texmacs_time());
-    the_gui -> process_keypress (tmwid, r, texmacs_time());
+    //tm_widget() -> handle_keypress (r, texmacs_time());
+    the_gui -> process_keypress (tm_widget(), r, texmacs_time());
     //int end= texmacs_time ();
     //if (end > start) cout << "Keypress " << end - start << "\n";
     //the_gui->update (); // FIXME: remove this line when
@@ -618,24 +602,27 @@ mouse_state (QMouseEvent* event, bool flag) {
   if ((bstate & Qt::XButton1       ) != 0) i += 8;
   if ((bstate & Qt::XButton2       ) != 0) i += 16;
 #ifdef Q_WS_MAC
-  if ((kstate & Qt::AltModifier    ) != 0) i = 2;
-  if ((kstate & Qt::MetaModifier   ) != 0) i = 4;
+    // We emulate right and middle clicks with ctrl and option, but we pass the
+    // modifiers anyway: old code continues to work and new one can use them.
+  if ((kstate & Qt::MetaModifier   ) != 0) i = 1024+4; // control key
+  if ((kstate & Qt::AltModifier    ) != 0) i = 2048+2; // option key
   if ((kstate & Qt::ShiftModifier  ) != 0) i += 256;
-  if ((kstate & Qt::ControlModifier) != 0) i += 2048;
+  if ((kstate & Qt::ControlModifier) != 0) i += 4096;   // cmd key
 #else
   if ((kstate & Qt::ShiftModifier  ) != 0) i += 256;
-  if ((kstate & Qt::ControlModifier) != 0) i += 512;
+  if ((kstate & Qt::ControlModifier) != 0) i += 1024;
   if ((kstate & Qt::AltModifier    ) != 0) i += 2048;
-  if ((kstate & Qt::MetaModifier   ) != 0) i += 16384;
+  if ((kstate & Qt::MetaModifier   ) != 0) i += 4096;
 #endif
   return i;
 }
 
 static string
 mouse_decode (unsigned int mstate) {
-  if      (mstate & 1 ) return "left";
-  else if (mstate & 2 ) return "middle";
+  if (mstate & 2 ) return "middle";
   else if (mstate & 4 ) return "right";
+    // we check for left clicks after the others for macos (see ifdef in mouse_state)
+  else if (mstate & 1 ) return "left";
   else if (mstate & 8 ) return "up";
   else if (mstate & 16) return "down";
   return "unknown";
@@ -805,8 +792,8 @@ QTMWidget::inputMethodEvent (QInputMethodEvent* event) {
     
     r = r * as_string(pos) * ":" * from_qstring(preedit_string);
   }
-  if (tmwid->ref_count != 0)
-    the_gui -> process_keypress (tmwid, r, texmacs_time());
+  if (tm_widget()->ref_count != 0)
+    the_gui -> process_keypress (tm_widget(), r, texmacs_time());
   event->accept();
 }  
 
@@ -827,14 +814,14 @@ QTMWidget::inputMethodQuery ( Qt::InputMethodQuery query ) const {
 
 void
 QTMWidget::mousePressEvent (QMouseEvent* event) {
-  if (tmwid->ref_count == 0) return;
+  if (tm_widget()->ref_count == 0) return;
   QPoint point = event->pos() + origin();
   scale (point);
   unsigned int mstate= mouse_state (event, false);
   string s= "press-" * mouse_decode (mstate);
-  the_gui -> process_mouse (tmwid, s, point.x (), point.y (), 
+  the_gui -> process_mouse (tm_widget(), s, point.x (), point.y (), 
                             mstate, texmacs_time ());
- // tmwid -> handle_mouse (s, point.x (), point.y (), mstate, texmacs_time ());
+ // tm_widget() -> handle_mouse (s, point.x (), point.y (), mstate, texmacs_time ());
   /*
   if (DEBUG_QT)
     cout << "mouse event: " << s << " at "
@@ -845,14 +832,14 @@ QTMWidget::mousePressEvent (QMouseEvent* event) {
 
 void
 QTMWidget::mouseReleaseEvent (QMouseEvent* event) {
-  if (tmwid->ref_count == 0) return;
+  if (tm_widget()->ref_count == 0) return;
   QPoint point = event->pos() + origin();
   scale (point);
   unsigned int mstate= mouse_state (event, true);
   string s= "release-" * mouse_decode (mstate);
-  the_gui -> process_mouse (tmwid, s, point.x (), point.y (), 
+  the_gui -> process_mouse (tm_widget(), s, point.x (), point.y (), 
                             mstate, texmacs_time ());
-//  tmwid -> handle_mouse (s, point.x (), point.y (), mstate, texmacs_time ());
+//  tm_widget() -> handle_mouse (s, point.x (), point.y (), mstate, texmacs_time ());
   /*
   if (DEBUG_QT)
     cout << "mouse event: " << s << " at "
@@ -863,14 +850,14 @@ QTMWidget::mouseReleaseEvent (QMouseEvent* event) {
 
 void
 QTMWidget::mouseMoveEvent (QMouseEvent* event) {
-  if (tmwid->ref_count == 0) return;
+  if (tm_widget()->ref_count == 0) return;
   QPoint point = event->pos() + origin();
   scale (point);
   unsigned int mstate= mouse_state (event, false);
   string s= "move";
-  the_gui -> process_mouse (tmwid, s, point.x (), point.y (), 
+  the_gui -> process_mouse (tm_widget(), s, point.x (), point.y (), 
                             mstate, texmacs_time ());
-//  tmwid -> handle_mouse (s, point.x (), point.y (), mstate, texmacs_time ());
+//  tm_widget() -> handle_mouse (s, point.x (), point.y (), mstate, texmacs_time ());
   /*
   if (DEBUG_QT)
     cout << "mouse event: " << s << " at "
@@ -893,20 +880,28 @@ QTMWidget::event (QEvent* event) {
 
 void
 QTMWidget::focusInEvent ( QFocusEvent * event ) {
-  if (tmwid->ref_count != 0) {
-    if (DEBUG_QT) cout << "FOCUSIN: " << tmwid->type_as_string() << LF;
-    the_gui -> process_keyboard_focus (tmwid, true, texmacs_time());
-    //tmwid -> handle_keyboard_focus (true, texmacs_time ());
+  if (tm_widget()->ref_count != 0) {
+    if (DEBUG_QT) cout << "FOCUSIN: " << tm_widget()->type_as_string() << LF;
+    the_gui -> process_keyboard_focus (tm_widget(), true, texmacs_time());
+    //tm_widget() -> handle_keyboard_focus (true, texmacs_time ());
   }
   QTMScrollView::focusInEvent (event);
 }
 
 void
 QTMWidget::focusOutEvent ( QFocusEvent * event ) {
-  if (tmwid->ref_count != 0) {
-    if (DEBUG_QT) cout << "FOCUSOUT: " << tmwid->type_as_string() << LF;
-    the_gui -> process_keyboard_focus (tmwid, false, texmacs_time());
-//    tmwid -> handle_keyboard_focus (false, texmacs_time ());
+  if (tm_widget()->ref_count != 0) {
+    if (DEBUG_QT) cout << "FOCUSOUT: " << tm_widget()->type_as_string() << LF;
+    the_gui -> process_keyboard_focus (tm_widget(), false, texmacs_time());
+//    tm_widget() -> handle_keyboard_focus (false, texmacs_time ());
   }
   QTMScrollView::focusOutEvent (event);
 }
+
+
+QSize
+QTMWidget::sizeHint () const {
+  SI w,h;
+  tm_widget()->handle_get_size_hint(w,h);
+  return to_qsize(w, h);
+}
