@@ -9,6 +9,7 @@
 * in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
+#include "convert.hpp"
 #include "iterator.hpp"
 #include "dictionary.hpp"
 #include "qt_gui.hpp"
@@ -24,6 +25,8 @@
 #include <QLabel>
 #include <QSocketNotifier>
 #include <QSetIterator>
+#include <QTranslator>
+#include <QLocale>
 #include "QTMGuiHelper.hpp"
 #include "QTMWidget.hpp"
 #include "QTMWindow.hpp"
@@ -32,22 +35,21 @@
 #include <QMimeData>
 #include <QByteArray>
 #include <QApplication>
+#include <QCoreApplication>
 #include <QImage>
 
 #ifdef MACOSX_EXTENSIONS
 #include "MacOS/mac_utilities.h"
 #endif
 
-
 #include "tm_link.hpp" // for number_of_servers
-
 #include "scheme.hpp"
-//#include "TeXmacs/server.hpp" // for get_server
-
+//#include "server.hpp" // for get_server
+#include "tm_window.hpp"
+#include "new_window.hpp"
 #include "qt_simple_widget.hpp"
 #include "qt_window_widget.hpp"
 
-extern window (*get_current_window) (void);
 
 qt_gui_rep* the_gui= NULL;
 int nr_windows = 0; // FIXME: fake variable, referenced in tm_server
@@ -69,48 +71,46 @@ bool wait_for_delayed_commands = true;
 * Constructor and geometry
 ******************************************************************************/
 
+#include <QLibraryInfo>
+
 qt_gui_rep::qt_gui_rep(int &argc, char **argv):
-  interrupted (false), waitWindow (NULL)
+  interrupted (false), waitWindow (NULL), popup_wid_time(0), q_translator(0)
 {
   (void) argc; (void) argv;
   // argc= argc2;
   // argv= argv2;
 
-  interrupted   = false;
-  time_credit = 100;
-  timeout_time= texmacs_time () + time_credit;
+  interrupted  = false;
+  time_credit  = 100;
+  timeout_time = texmacs_time () + time_credit;
 
   //waitDialog = NULL;
   
-  set_output_language (get_locale_language ());
   gui_helper = new QTMGuiHelper (this);
-  qApp -> installEventFilter (gui_helper);
-  
+  qApp->installEventFilter (gui_helper);
+
 #ifdef QT_MAC_USE_COCOA
   //HACK: this filter is needed to overcome a bug in Qt/Cocoa
   extern void mac_install_filter(); // defined in src/Plugins/MacOS/mac_app.mm
   mac_install_filter();
 #endif
-  
-  
-  
-  qApp-> installTranslator(new QTMTranslator(qApp));
-  
+
+  set_output_language (get_locale_language ());
+  refresh_language();
+
   updatetimer = new QTimer (gui_helper);
   updatetimer->setSingleShot (true);
-  QObject::connect ( updatetimer, SIGNAL(timeout()), 
-                     gui_helper, SLOT(doUpdate()));
+  QObject::connect (updatetimer, SIGNAL(timeout()),
+                    gui_helper, SLOT(doUpdate()));
 //  (void) default_font ();
 }
 
 /* important routines */
 void
 qt_gui_rep::get_extents (SI& width, SI& height) {
-  QDesktopWidget* d= QApplication::desktop();
-  int w = d->width();  // returns desktop width
-  int h = d->height(); // returns desktop height        
-  width = ((SI) w) * PIXEL;
-  height= ((SI) h) * PIXEL;
+  coord2 size = from_qsize (QApplication::desktop()->size());
+  width  = size.x1;
+  height = size.x2;
 }
 
 void
@@ -139,43 +139,75 @@ qt_gui_rep::~qt_gui_rep()  {
 
 bool
 qt_gui_rep::get_selection (string key, tree& t, string& s, string format) {
-  (void) format;
   QClipboard *cb= QApplication::clipboard ();
   QClipboard::Mode mode= QClipboard::Clipboard;
-  bool owns= false;
-  if (key == "primary" || (key == "mouse" && cb->supportsSelection ())) {
+  if (key == "primary" || (key == "mouse" && cb->supportsSelection ()))
     if (key == "mouse") mode= QClipboard::Selection;
-    const QMimeData *md= cb->mimeData (mode);
-    if (md) owns= md->hasFormat ("application/x-texmacs-clipboard");  
-  }
-  else owns= true;
-  
+
+  QString originalText= cb->text (mode);
+  const QMimeData *md= cb->mimeData (mode);
+  QByteArray buf;
+  string input_format;
+
   s= "";
   t= "none";
+  // Knowing when we owns (or not) the content is not clear
+  bool owns= (format != "temp" && format != "wrapbuf" && key != "primary") &&
+             !(key == "mouse" && cb->supportsSelection ());
+
+  if (!owns && md->hasFormat ("application/x-texmacs-pid")) {
+    buf= md->data ("application/x-texmacs-pid");
+    if (!(buf.isEmpty())) {
+      owns= string (buf.constData(), buf.size())
+            == as_string (QCoreApplication::applicationPid ());
+    }
+  }
+
   if (owns) {
     if (!selection_t->contains (key)) return false;
     t= copy (selection_t [key]);
     s= copy (selection_s [key]);
     return true;
   }
-  else {
-    QString originalText= cb->text (mode);
-    QByteArray buf;
-    if (format == "verbatim" &&
-	get_preference ("verbatim->texmacs:encoding") == "utf-8")
-      buf= originalText.toUtf8 ();
-    else buf= originalText.toAscii ();
-    if (!(buf.isEmpty())) s << string (buf.constData(), buf.size());
-    t= tuple ("extern", s);
-    return true;
+
+  if (format == "default") {
+    if (md->hasFormat ("application/x-texmacs-clipboard")) {
+      buf= md->data ("application/x-texmacs-clipboard");
+      input_format= "texmacs-snippet";
+    }
+    else if (md->hasHtml ()) {
+      buf= md->html().toUtf8 ();
+      input_format= "html-snippet";
+    }
+    else if (md->hasFormat ("text/plain;charset=utf8")) {
+      buf= md->data ("text/plain;charset=utf8");
+      input_format= "verbatim-snippet";
+    }
+    else {
+      buf= md->text().toUtf8 ();
+      input_format= "verbatim-snippet";
+    }
   }
+  else if (format == "verbatim" && (
+        get_preference ("texmacs->verbatim:encoding") == "utf-8" ||
+        get_preference ("texmacs->verbatim:encoding") == "auto"  ))
+    buf= md->text().toUtf8 ();
+  else {
+    if (md->hasFormat ("plain/text")) buf= md->data ("plain/text").data();
+    else buf= md->text().toUtf8 ();
+  }
+  if (!(buf.isEmpty())) s << string (buf.constData(), buf.size());
+  if (input_format != "")
+    s= as_string (call ("convert", s, input_format, "texmacs-snippet"));
+  t= tuple ("extern", s);
+  return true;
 }
 
 bool
 qt_gui_rep::set_selection (string key, tree t, string s, string format) {
   selection_t (key)= copy (t);
   selection_s (key)= copy (s);
-        
+
   QClipboard *cb= QApplication::clipboard ();
   QClipboard::Mode mode= QClipboard::Clipboard;
   if (key == "primary");
@@ -184,16 +216,37 @@ qt_gui_rep::set_selection (string key, tree t, string s, string format) {
   else return true;
   cb->clear (mode);
 
-  char *selection = as_charp (s);
+  char *selection= as_charp (s);
   cb->setText (selection, mode);
-  QByteArray ba (selection);
   QMimeData *md= new QMimeData;
-  md->setData ("application/x-texmacs-clipboard", ba);
-  if (format == "verbatim" &&
-      get_preference ("texmacs->verbatim:encoding") == "utf-8")
-    md->setText (QString::fromUtf8 (selection));
-  else md->setText (selection);
-  cb->setMimeData (md, mode); 
+
+  if (format == "verbatim" || format == "default") {
+    if (format == "default") {
+      md->setData ("application/x-texmacs-clipboard", selection);
+
+      selection= as_charp (as_string (QCoreApplication::applicationPid ()));
+      md->setData ("application/x-texmacs-pid", selection);
+
+      string html_s= as_string (call ("convert", s,
+                                      "texmacs-snippet", "html-snippet"));
+      selection= as_charp (html_s);
+      md->setHtml (selection);
+
+      s= as_string (call ("convert", s,
+                          "texmacs-snippet", "verbatim-snippet"));
+      selection= as_charp (s);
+    }
+
+    if (get_preference ("texmacs->verbatim:encoding") == "utf-8")
+      md->setText (QString::fromUtf8 (selection));
+    else if (get_preference ("texmacs->verbatim:encoding") == "iso-8859-1")
+      md->setText (QString::fromLatin1 (selection));
+    else
+      md->setText (selection);
+  }
+  else
+    md->setText (selection);
+  cb->setMimeData (md, mode);
   // according to the docs, ownership of mimedata is transferred to clipboard
   // so no memory leak here
   tm_delete_array (selection);
@@ -207,14 +260,14 @@ qt_gui_rep::clear_selection (string key) {
   
   QClipboard *cb= QApplication::clipboard();
   QClipboard::Mode mode= QClipboard::Clipboard;
-  bool owns= false;
   if (key == "primary");
   else if (key == "mouse" && cb->supportsSelection())
     mode= QClipboard::Selection;
   else return;
 
+  bool owns= false;
   const QMimeData *md= cb->mimeData (mode);
-  if (md) owns= md->hasFormat ("application/x-texmacs");
+  if (md) owns= md->hasFormat ("application/x-texmacs-clipboard");
   if (owns) cb->clear (mode);
 }
 
@@ -266,7 +319,7 @@ qt_gui_rep::show_wait_indicator (widget w, string message, string arg)  {
     QLabel* lab = new  QLabel();
     lab->setFocusPolicy(Qt::NoFocus);
     lab->setMargin(15);
-    lab->setText (to_qstring (tm_var_encode(message)));
+    lab->setText (to_qstring (message));
     waitDialogs << lab;
   } else {
     // pop the next wait message from the list
@@ -319,13 +372,11 @@ qt_gui_rep::event_loop () {
   app->exec();
 }
 
+
 /******************************************************************************
  * Sockets notifications
  ******************************************************************************/
 
-static hashmap<socket_notifier,pointer> read_notifiers;
-static hashmap<socket_notifier,pointer> write_notifiers;
-
 void 
 qt_gui_rep::add_notifier (socket_notifier sn)
 {
@@ -336,7 +387,6 @@ qt_gui_rep::add_notifier (socket_notifier sn)
   remove_notifier (sn);
 
   if (DEBUG_QT) cout << "ADD NOTIFIER " << sn->fd << LF;
-
   
   // installs both a read and a write notifier 
   // (the texmacs interface does not specify enough its needs)
@@ -388,7 +438,6 @@ qt_gui_rep::enable_notifier (socket_notifier sn, bool flag)
 }
 
 
-
 /******************************************************************************
  * Delayed commands
  ******************************************************************************/
@@ -491,88 +540,21 @@ void
 gui_root_extents (SI& width, SI& height) {
   // get the screen size
   the_gui->get_extents (width, height);
-  if (DEBUG_QT) 
-    cout << "gui_root_extents (" << width << "," << height << ")" << LF;
+    //if (DEBUG_QT) 
+    //cout << "gui_root_extents (" << width << "," << height << ")" << LF;
 }
 
 void
 gui_maximal_extents (SI& width, SI& height) {
   // get the maximal size of a window (can be larger than the screen size)
   the_gui->get_max_size (width, height);
-  if (DEBUG_QT) 
-    cout << "gui_maximal_extents (" << width << "," << height << ")" << LF;
+    //if (DEBUG_QT) 
+    //cout << "gui_maximal_extents (" << width << "," << height << ")" << LF;
 }
 
 void
 gui_refresh () {
-  // called upon change of output language
-  // emit a signal which forces every QTMAction to change his text
-  // according to the new language
-
-  the_gui->gui_helper->doRefresh();
-}
-
-
-/******************************************************************************
- * QTMGuiHelper methods
- ******************************************************************************/
-
-void
-QTMGuiHelper::doUpdate () {
-//  cout << "UPDATE " << texmacs_time () << LF;
-  gui->update();
-}
-
-void
-QTMGuiHelper::doRefresh () {
-  emit refresh();
-}
-
-bool
-QTMGuiHelper::eventFilter (QObject *obj, QEvent *event) {
-  if (event->type() == QEvent::FileOpen) {
-    QFileOpenEvent *openEvent = static_cast<QFileOpenEvent *>(event);
-    const char *s = openEvent->file().toAscii().constData();
-    //qDebug ("File Open Event %s", s);
-    call ("load-buffer", object (url_system (s)), eval (":new-window"));
-    return true;
-  }
-  else {
-    // standard event processing
-    return QObject::eventFilter(obj, event);
-  }
-}
-
-void
-QTMGuiHelper::doWriteSocketNotification (int socket) {
-  if (DEBUG_QT) 
-    cout << "WRITE SOCKET NOTIFICATION " << socket << " "
-         << texmacs_time () << LF;
-  iterator<socket_notifier> it = iterate (write_notifiers);
-  while (it->busy ()) {
-    socket_notifier sn= it->next ();
-    if (sn->fd == socket) {
-      //sn->notify();
-      the_gui->process_socket_notification (sn);
-      the_gui->enable_notifier (sn, false);
-    }
-  }
-}
-
-void
-QTMGuiHelper::doReadSocketNotification (int socket) {
-  if (DEBUG_QT) 
-    cout << "READ SOCKET NOTIFICATION " << socket << " "
-         << texmacs_time () << LF;
-  iterator<socket_notifier> it = iterate (read_notifiers);
-  while (it->busy ()) {
-    socket_notifier sn= it->next ();
-    if (sn->fd == socket) {
-      //sn->notify();
-      the_gui->process_socket_notification (sn);
-      the_gui->enable_notifier (sn, false);
-    }
-  }
+  the_gui->refresh_language(); 
 }
 
 
@@ -617,6 +599,7 @@ public:
 
 static array<queued_event> waiting_events;
 
+void add_event(const queued_event &ev);
 
 void
 process_event (queued_event ev) {
@@ -671,7 +654,7 @@ process_event (queued_event ev) {
     case QP_COMMAND_ARGS :
     {
       typedef pair<command, object> T;
-      T x = open_box <T> (ev.x2) ;
+      T x = open_box <T> (ev.x2);
       // cout << "QP_COMMAND_ARGS" << LF;
       x.x1->apply(x.x2);
     }
@@ -683,14 +666,13 @@ process_event (queued_event ev) {
       wait_for_delayed_commands = true;
     }
       break;
+
     default:   
       FAILED("Unexpected queued event");
   }
   //cout << ">" << (qp_type_id) ev.x1 << LF;
 }
 
-
-
 queued_event 
 next_event() {
   queued_event ev;
@@ -708,30 +690,30 @@ next_event() {
 
 void 
 qt_gui_rep::process_queued_events (int max) {
-  // we process a maximum of max events. There are two kind of events: those
-  // which need a pass on interpose_handler just after and the others. We count
-  // only the first kind of events. In update() we call this function with
-  // max=1 so that only one of these "sensible" events is handled. Otherwise
-  // updating of internal TeXmacs structure become very slow. This can be 
-  // considerer a limitation of the current implementation of interpose_handler
-  // Likewise this function is just an hack to get things working properly.
+    // we process a maximum of max events. There are two kind of events: those
+    // which need a pass on interpose_handler just after and the others. We count
+    // only the first kind of events. In update() we call this function with
+    // max=1 so that only one of these "sensible" events is handled. Otherwise
+    // updating of internal TeXmacs structure become very slow. This can be 
+    // considerer a limitation of the current implementation of interpose_handler
+    // Likewise this function is just an hack to get things working properly.
   
   int count = 0;
-  //cout << "(" << n << " events)"
+    //cout << "(" << n << " events)"
   while ((max < 0) || (count<max))  {
     queued_event ev = next_event();
     if (ev.x1 == QP_NULL) break;
     process_event(ev);
     switch (ev.x1) {
-        case QP_COMMAND:
-        case QP_COMMAND_ARGS:
-        case QP_SOCKET_NOTIFICATION:
-        case QP_RESIZE:
-        case QP_DELAYED_COMMANDS:
-          break;
-        default:
-          count++;
-          break;
+      case QP_COMMAND:
+      case QP_COMMAND_ARGS:
+      case QP_SOCKET_NOTIFICATION:
+      case QP_RESIZE:
+      case QP_DELAYED_COMMANDS:
+        break;
+      default:
+        count++;
+        break;
     }
   }
 }
@@ -762,7 +744,9 @@ qt_gui_rep::process_keypress (qt_simple_widget_rep *wid, string key, time_t t) {
   typedef triple<widget, string, time_t > T;
   if (wid->type != qt_widget_rep::simple_widget) {
     if (DEBUG_QT)
-      cout << "WTF! Situation] process_keypress() for non simple_widget.\n";
+      cout << "WTF! Situation] process_keypress() for non simple_widget. Widget: " 
+           << wid->type_as_string() << LF; 
+
     return;
   }
   add_event( queued_event ( QP_KEYPRESS, close_box<T> (T(wid, key, t)))); 
@@ -776,7 +760,9 @@ qt_gui_rep::process_keyboard_focus (qt_simple_widget_rep *wid, bool has_focus,
   typedef triple<widget, bool, time_t > T;
   if (wid->type != qt_widget_rep::simple_widget) {
     if (DEBUG_QT)
-      cout << "WTF! Situation] process_keyboard_focus() for non simple_widget.\n";
+      cout << "WTF! Situation] process_keyboard_focus() for non simple_widget. Widget: " 
+           << wid->type_as_string() << LF; 
+
     return;
   }
   add_event( 
@@ -790,9 +776,11 @@ qt_gui_rep::process_mouse (qt_simple_widget_rep *wid, string kind, SI x, SI y,
                             int mods, time_t t ) {
   typedef quintuple<string, SI, SI, int, time_t > T1;
   typedef pair<widget, T1> T;
+
   if (wid->type != qt_widget_rep::simple_widget) {
     if (DEBUG_QT)
-      cout << "WTF! Situation] process_mouse() for non simple_widget.\n"; 
+      cout << "WTF! Situation] process_mouse() for non simple_widget. Widget: " 
+           << wid->type_as_string() << LF; 
     return;
   }
   add_event ( 
@@ -806,7 +794,9 @@ qt_gui_rep::process_resize (qt_simple_widget_rep *wid, SI x, SI y ) {
   typedef triple<widget, SI, SI > T;
   if (wid->type != qt_widget_rep::simple_widget) {
     if (DEBUG_QT)
-      cout << "WTF! Situation] process_resize() for non simple_widget.\n";    
+      cout << "WTF! Situation] process_resize() for non simple_widget. Widget: " 
+           << wid->type_as_string() << LF; 
+   
     return;
   }
   add_event( queued_event ( QP_RESIZE, close_box<T> (T(wid, x, y)))); 
@@ -922,7 +912,11 @@ qt_gui_rep::update () {
     }
   }
   
-  
+  if (popup_wid_time > 0 && now > popup_wid_time) {
+    popup_wid_time = 0;
+    _popup_wid->send(SLOT_VISIBILITY, close_box<bool>(true));
+  }
+
   // 2.
   // manage delayed commands
   
@@ -995,23 +989,52 @@ qt_gui_rep::update () {
   //        The interval cannot be too small to keep CPU usage low in idle state
 } 
 
-/*
- FIXME: implement fade out of popup after mouse out events, etc.
- Maybe use a dedicated wrapper QWidget which handles events, giving it the
- focus and which releases it as soon as some key is pressed or the mouse is
- moved out of it (problem: the widget need not appear below the mouse pointer,
- thus making it impossible to access links or widgets inside it.
- Solution?: as soon as the mouse moves (out of the widget), start a timer, 
+/*! Called upon change of output language.
+ 
+ We currently emit a signal which forces every QTMAction to change his text
+ according to the new language, but the preferred Qt way seems to use
+ LanguageChange events (these are triggered upon installation of QTranslators)
+ */ 
+void
+qt_gui_rep::refresh_language() {
+  QTranslator* qtr = new QTranslator();
+  if (qtr->load("qt_" + 
+        QLocale (to_qstring (language_to_locale (get_output_language()))).name(),
+        QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
+    if (q_translator) 
+      qApp->removeTranslator(q_translator);
+    qApp->installTranslator(qtr);
+    q_translator = qtr;
+  } else {
+    delete qtr;
+  }
+  gui_helper->doRefresh();
+}
+
+
+
+/*! Display a popup help balloon (i.e. a tooltip) at window coordinates x, y 
+ 
+ We use a dedicated wrapper QWidget which handles mouse events: as soon as the 
+ mouse is moved out of we hide it.
+ Problem: the widget need not appear below the mouse pointer, thus making it
+ impossible to access links or widgets inside it.
+ Solution?? as soon as the mouse moves (out of the widget), start a timer, 
  giving enough time to the user to move (back) into the widget, then abort the
  close operation if he gets there.
- */
+*/
 void
 qt_gui_rep::show_help_balloon (widget wid, SI x, SI y) {
-  popup_wid= popup_widget (wid);
-  popup_win= popup_window_widget(popup_wid, "Balloon");
-  set_position (popup_win, x, y);
-  set_visibility(popup_win, true);
-    //send_mouse_grab(popup_win, true);
+  if (popup_wid_time > 0) return;
+
+  _popup_wid = popup_window_widget(wid, "Balloon");
+  SI winx, winy;
+    // HACK around wrong? reporting of window widget for embedded texmacs-inputs:
+    // call get_window on the current window (concrete_window()->win is set to
+    // the texmacs-input widget whenever there is one)
+  get_position (get_window (concrete_window()->win), winx, winy);
+  set_position (_popup_wid, x+winx, y+winy);
+  popup_wid_time = texmacs_time() + 666;  // update() will eventually show the widget
 }
 
 /******************************************************************************
@@ -1077,10 +1100,11 @@ qt_gui_rep::put_graphics_on_clipboard (url file) {
    
   // for bitmaps this works :
   if ((extension == "bmp") || (extension == "png") ||
-      (extension == "jpg") || (extension == "jpeg")) { 
-    QImage myqimage=QImage ( as_charp (as_string (file)) );
+      (extension == "jpg") || (extension == "jpeg")) {
     QClipboard *clipboard = QApplication::clipboard();
-    clipboard->setImage(myqimage);
+    char* tmp = as_charp (concretize (file));
+    clipboard->setImage (QImage (tmp));
+    tm_delete_array (tmp);
   }
   else {
     // vector formats
@@ -1093,8 +1117,10 @@ qt_gui_rep::put_graphics_on_clipboard (url file) {
    
     string filecontent;
     load_string (as_string (file), filecontent, true);
-
-    QByteArray rawdata= as_charp (filecontent);
+    
+    char* tmp = as_charp (filecontent);
+    QByteArray rawdata (tmp);
+    tm_delete_array(tmp);
 
     QMimeData *mymimeData = new QMimeData;
     mymimeData->setData(mime, rawdata);
@@ -1177,23 +1203,3 @@ external_event (string type, time_t t) {
     if (wid) the_gui -> process_keypress (wid, type, t);
   }
 }
-
-font x_font (string family, int size, int dpi)
-{
-  (void) family; (void) size; (void) dpi;
-  if (DEBUG_QT) cout << "x_font(): SHOULD NOT BE CALLED\n";
-  return NULL;
-}
-
-
-QString 
-QTMTranslator::translate ( const char * context, const char * sourceText, 
-                           const char * disambiguation ) const 
-{
-  (void) disambiguation;  (void) context;
-  if (DEBUG_QT) {
-    cout << "Translating: " << sourceText << LF;
-    cout << "Translation: " << qt_translate (sourceText) << LF;
-  }
-  return QString (to_qstring (qt_translate (sourceText)));
-}
