@@ -82,7 +82,7 @@ void QTMInteractiveInputHelper::commit(int result) {
       if (cb) {
         item = cb->currentText();
       }      
-      static_cast<qt_input_text_widget_rep*>(wid->int_input.rep)->text= from_qstring (item);
+      static_cast<qt_input_text_widget_rep*>(wid->int_input.rep)->input = from_qstring (item);
       static_cast<qt_input_text_widget_rep*>(wid->int_input.rep)->cmd ();      
     }
   }
@@ -109,11 +109,14 @@ tweak_iconbar_size (QSize& sz) {
 }
 
 qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
- : qt_view_widget_rep (new QTMWindow (0, this)), helper (this), 
-   full_screen(false), quit(_quit)
+ : qt_window_widget_rep (new QTMWindow (0), _quit), helper (this), 
+   prompt (NULL), full_screen (false)
 {
-  type = texmacs_widget;  // FIXME: remove this whole "type" thing
+  type = texmacs_widget;
+  orig_name = "popup";
 
+  main_widget = ::glue_widget (true, true, 1, 1);
+  
   // decode mask
   visibility[0] = (mask & 1)  == 1;  // header
   visibility[1] = (mask & 2)  == 2;  // main
@@ -140,21 +143,15 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
 #endif
   mw->setFocusPolicy (Qt::NoFocus);
   
-  
-  // central widget
-  
-  QStackedWidget* tw = new QStackedWidget (mw);
-  tw->setObjectName("stacked widget"); // to easily find this object
-  
   // status bar
   
   QStatusBar* bar= new QStatusBar(mw);
-  leftLabel= new QLabel ("Welcome to TeXmacs", mw);
-  rightLabel= new QLabel ("Booting", mw);
+  leftLabel= new QLabel (qt_translate ("Welcome to TeXmacs"), mw);
+  rightLabel= new QLabel (qt_translate ("Booting"), mw);
   leftLabel->setFrameStyle (QFrame::NoFrame);
   rightLabel->setFrameStyle (QFrame::NoFrame);
   {
-    QFont f=  leftLabel->font();
+    QFont f = leftLabel->font();
     f.setPixelSize(12);
     leftLabel->setFont(f);
     rightLabel->setFont(f);
@@ -178,20 +175,23 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
   bar->setMinimumWidth(2);
   mw->setStatusBar (bar);
  
-  
   // toolbars
   
   mainToolBar  = new QToolBar ("main toolbar", mw);
   modeToolBar  = new QToolBar ("mode toolbar", mw);
   focusToolBar = new QToolBar ("focus toolbar", mw);
   userToolBar  = new QToolBar ("user toolbar", mw);
-  sideToolBar  = new QToolBar ("side toolbar", mw);
-
+  
+  sideDock     = new QDockWidget ("Side tools", 0);
+    // HACK: Wrap the dock in a "fake" window widget (last parameter = true) to
+    // have clicks report the right position.
+  dock_window_widget = tm_new<qt_window_widget_rep> (sideDock, command(), true);
+  
   mainToolBar->setStyle (qtmstyle ());
   modeToolBar->setStyle (qtmstyle ());
   focusToolBar->setStyle (qtmstyle ());
   userToolBar->setStyle (qtmstyle ());
-  sideToolBar->setStyle (qtmstyle());
+  sideDock->setStyle (qtmstyle ());
   
   {
     // set proper sizes for icons
@@ -209,23 +209,25 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
     focusToolBar->setIconSize(sz);
   }  
   
-//#if 0
-#ifdef UNIFIED_TOOLBAR
-
-  mw->setUnifiedTitleAndToolBarOnMac(true);
-
-  QWidget *cw= new QWidget ();  // QMainWindow will take ownership later and delete it when needed.
-  cw->setObjectName("central widget"); // this is important for styling toolbars.
+  QWidget *cw= new QWidget();
+  cw->setObjectName("central widget");  // this is important for styling toolbars.
   
-  QBoxLayout *bl = new QBoxLayout(QBoxLayout::TopToBottom, cw);
-  bl->setContentsMargins(2,2,2,2);
+    // The main layout
+  
+  QVBoxLayout *bl = new QVBoxLayout(cw);
+  bl->setContentsMargins(0,1,0,0);
   bl->setSpacing(0);
   cw->setLayout(bl);
-  bl->addWidget(tw);
+  QWidget* q = concrete(main_widget)->as_qwidget(); // force creation of QWidget
+  q->setParent(qwid); // q->layout()->removeWidget(q) will reset the parent to this
+  bl->addWidget(q);
   
   mw->setCentralWidget(cw);
   
-  
+#ifdef UNIFIED_TOOLBAR
+
+  mw->setUnifiedTitleAndToolBarOnMac(true);
+    
   //WARNING: dumbToolBar is the toolbar installed on the top area of the
   //main widget which is  then unified in the title bar. 
   //to overcome some limitations of the unified toolbar implementation we
@@ -241,7 +243,7 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
   modeToolBarAction = NULL;
 
   
-  //a ruler
+  // A ruler
   rulerWidget = new QWidget(cw);
   rulerWidget->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
   rulerWidget->setMinimumHeight(1);
@@ -251,19 +253,24 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
   rulerWidget->setAutoFillBackground(true);
   // rulerWidget = new QLabel("pippo", cw);
   
+    // A second ruler (this one always visible) to separate from the canvas.
+  QWidget* r2 = new QWidget(mw);
+  r2->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Fixed);
+  r2->setMinimumHeight(1);
+  r2->setBackgroundRole(QPalette::Mid);
+  r2->setVisible(true);
+  r2->setAutoFillBackground(true);
 
   bl->insertWidget(0, modeToolBar);
   bl->insertWidget(1, rulerWidget);
   bl->insertWidget(2, focusToolBar);
   bl->insertWidget(3, userToolBar);
-
-  tw->setContentsMargins (2, 0, 2, 0);
-  mw->setContentsMargins (-2, -2, -2, -2);
-  bar->setContentsMargins (0, 0, 0, 2);
+  bl->insertWidget(4, r2);
+  
+    //mw->setContentsMargins (-2, -2, -2, -2);  // Why this?
+  bar->setContentsMargins (0, 1, 0, 1);
 
 #else
-  mw->setCentralWidget(tw);
-  
   mw->addToolBar (mainToolBar);
   mw->addToolBarBreak ();
   mw->addToolBar (modeToolBar);
@@ -273,13 +280,18 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
   mw->addToolBar (userToolBar);
  // mw->addToolBarBreak ();
 #endif
+
+  sideDock->setAllowedAreas(Qt::AllDockWidgetAreas);
+  sideDock->setFeatures(QDockWidget::DockWidgetMovable |
+                        QDockWidget::DockWidgetFloatable);
+  sideDock->setFloating(false);
+  mw->addDockWidget(Qt::RightDockWidgetArea, sideDock);
   
-  sideToolBar->setAllowedAreas(Qt::LeftToolBarArea | Qt::RightToolBarArea);
-    //This does nothing to forbid the toolbar from displaying horizontally when
-    //floating...
-    //sideToolBar->setOrientation(Qt::Vertical);
-  sideToolBar->setMovable(true);
-  mw->addToolBar(Qt::RightToolBarArea, sideToolBar);
+    // FIXME? add DockWidgetClosable and connect the close signal
+    // to the scheme code
+    //  QObject::connect(sideDock, SIGNAL(closeEvent()), 
+    //                   someHelper, SLOT(call_scheme_hide_side_tools()));  
+
   
   // handles visibility
   // at this point all the toolbars are empty so we avoid showing them
@@ -290,7 +302,7 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
   modeToolBar->setVisible (false);
   focusToolBar->setVisible (false);
   userToolBar->setVisible (false);
-  sideToolBar->setVisible(false);
+  sideDock->setVisible (false);
   mainwindow()->statusBar()->setVisible (true);
 #ifndef Q_WS_MAC
   mainwindow()->menuBar()->setVisible (false);
@@ -299,55 +311,31 @@ qt_tm_widget_rep::qt_tm_widget_rep(int mask, command _quit)
 
 qt_tm_widget_rep::~qt_tm_widget_rep () {
   if (DEBUG_QT)
-    cout << "qt_tm_widget_rep::~qt_tm_widget_rep\n";
-  
+    cout << "qt_tm_widget_rep::~qt_tm_widget_rep of widget" << type_as_string() << LF;
   
     // clear any residual waiting menu installation
   waiting_widgets = remove(waiting_widgets, this);
-
-  
-    // we must detach the QTMWidget canvas from the Qt widget hierarchy otherwise
-    // it will be destroyed when the view member of this object is deallocated
-    // this is another problem related to our choice of letting qt_widget own its
-    // underlying QWidget.
-    // NOTE: I (mbd) commented this out and added the call to all_widgets.remove
-    // to the destructor of QTMWidget, because other texmacs widgets can contain
-    // instances of QTMWidget (for instance box_widget, created by 
-    // texmacs_output_widget() )
-  /*
-  QTMWidget *canvas = canvas();
-  QStackedWidget* tw= centralwidget();
-  if (canvas) {
-    tw->removeWidget(canvas);
-    canvas->setParent(NULL);
-    QTMWidget::all_widgets.remove(canvas);
-  }
-   */
 }
 
-/*! Constructs a wrapper qt_window_widget for the widget and returns it.
- 
- qt_tm_widget_rep is special and needs overriding this method of the base class
- because we have assigned the underlying QWidget to be of type QTMWindow, which
- is a special QMainWindow, and don't want it replaced by a QTMPlainWindow, and
- that's what the default implementation does.
+/*! FIXME: should we overwrite the previous quit command?
  */
 widget
 qt_tm_widget_rep::plain_window_widget (string title, command quit) {
+  (void) quit;
+  orig_name = title;
   qwid->setWindowTitle (to_qstring (title));
-  widget w= tm_new<qt_window_widget_rep> (qwid, quit);
-  return w;
+  return this;
 }
 
-void qt_tm_widget_rep::updateVisibility()
-{
+void
+qt_tm_widget_rep::update_visibility () {
 #define XOR(exp1,exp2) (((!exp1) && (exp2)) || ((exp1) && (!exp2)))
 
   bool old_mainVisibility = mainToolBar->isVisible();
   bool old_modeVisibility = modeToolBar->isVisible();
   bool old_focusVisibility = focusToolBar->isVisible();
   bool old_userVisibility = userToolBar->isVisible();
-  bool old_sideVisibility = sideToolBar->isVisible();
+  bool old_sideVisibility = sideDock->isVisible();
   bool old_statusVisibility = mainwindow()->statusBar()->isVisible();
 
   bool new_mainVisibility = visibility[1] && visibility[0];
@@ -366,7 +354,7 @@ void qt_tm_widget_rep::updateVisibility()
   if ( XOR(old_userVisibility,  new_userVisibility) )
     userToolBar->setVisible (new_userVisibility);
   if ( XOR(old_sideVisibility,  new_sideVisibility) )
-    sideToolBar->setVisible (new_sideVisibility);
+    sideDock->setVisible (new_sideVisibility);
   if ( XOR(old_statusVisibility,  new_statusVisibility) )
     mainwindow()->statusBar()->setVisible (new_statusVisibility);
 
@@ -434,309 +422,310 @@ void qt_tm_widget_rep::updateVisibility()
 
 widget
 qt_tm_widget_rep::read(slot s, blackbox index) {
-  if (DEBUG_QT)
-    cout << "qt_tm_widget_rep::read " << slot_name (s) << LF;
-
+  widget ret;
+  
   switch (s) {
     case SLOT_CANVAS:
-      check_type_void (index, "SLOT_CANVAS");
-      return abstract (this);
+      check_type_void (index, s);
+      ret = main_widget;
+      break;
+      
     default:
-      return qt_view_widget_rep::read(s, index);
+      return qt_window_widget_rep::read(s, index);
   }
+  
+  if (DEBUG_QT)
+    cout << "qt_tm_widget_rep::read " << slot_name (s) << "\t\tfor widget\t" 
+         << type_as_string() << LF;
+  
+  return ret;
 }
 
 void
 qt_tm_widget_rep::send (slot s, blackbox val) {
-  if (DEBUG_QT)
-    cout << "qt_tm_widget_rep::send " << slot_name (s) << LF;
-
   switch (s) {
     case SLOT_INVALIDATE:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<coord4>::id);
-      coord4 p= open_box<coord4> (val);
-      if (DEBUG_QT)
-        cout << "   Invalidating rect " << rectangle(p.x1,p.x2,p.x3,p.x4) << LF;
-      qt_renderer_rep* ren = (qt_renderer_rep*)get_renderer (this);
-      QTMWidget *canvas = qobject_cast <QTMWidget*>(qwid);
-      if (ren && canvas) {
-        SI x1 = p.x1, y1 = p.x2, x2 = p.x3, y2 = p.x4;    
-        ren->outer_round (x1, y1, x2, y2);
-        ren->decode (x1, y1);
-        ren->decode (x2, y2);
-        canvas->invalidate_rect (x1,y2,x2,y1);
-      }
-    }
-      break;
     case SLOT_INVALIDATE_ALL:
-    {
-      ASSERT (is_nil (val), "type mismatch");
-      if (DEBUG_QT)
-        cout << "   Invalidating all"<<  LF;
-      QTMWidget *canvas = qobject_cast <QTMWidget*>(qwid);
-      if (canvas) canvas->invalidate_all ();
-    }
-      break;
-      
     case SLOT_EXTENTS:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<coord4>::id);
-      coord4 p= open_box<coord4> (val);
-      QRect rect = to_qrect (p);
-        //NOTE: rect.topLeft is ignored since it is always (0,0)
-      canvas() -> setExtents(rect);
-#if 0
-        //cout << "p= " << p << "\n";
-      QSize sz= to_qrect (p).size ();
-      QSize ws= scrollarea () -> size ();
-      sz.setHeight (max (sz.height (), ws.height () - 4));
-        //FIXME: the above adjustment is not very nice and useful only in papyrus 
-        //       mode. When setting the size we should ask the GUI of some 
-        //       preferred max size and set that without post-processing.
-        //      canvas () -> setFixedSize (sz);
-      canvas() -> setExtentsSize(sz);
-#endif
-    }
-      break;
+    case SLOT_SCROLL_POSITION:
+    case SLOT_ZOOM_FACTOR:
+    case SLOT_MOUSE_GRAB:
+      main_widget->send(s, val);
+      return;
+      
     case SLOT_HEADER_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[0] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[0] = open_box<bool> (val);
+      update_visibility();
     }
       break;
+
     case SLOT_MAIN_ICONS_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[1] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[1] = open_box<bool> (val);
+      update_visibility();
     }
       break;
+
     case SLOT_MODE_ICONS_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[2] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[2] = open_box<bool> (val);
+      update_visibility();
     }
       break;
+
     case SLOT_FOCUS_ICONS_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[3] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[3] = open_box<bool> (val);
+      update_visibility();
     }
       break;
+
     case SLOT_USER_ICONS_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[4] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[4] = open_box<bool> (val);
+      update_visibility();
     }
       break;
 
     case SLOT_FOOTER_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[5] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[5] = open_box<bool> (val);
+      update_visibility();
     }
       break;
- 
+
     case SLOT_SIDE_TOOLS_VISIBILITY:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
-      bool f= open_box<bool> (val);
-      visibility[6] = f;
-      updateVisibility();
+      check_type<bool>(val, s);
+      visibility[6] = open_box<bool> (val);
+      update_visibility();
     }
       break;
 
     case SLOT_LEFT_FOOTER:
     {
-      TYPE_CHECK (type_box (val) == type_helper<string>::id);
-      string msg= open_box<string> (val);
-      leftLabel->setText (to_qstring (tm_var_encode (msg)));
+      check_type<string>(val, s);
+      string msg = open_box<string> (val);
+      leftLabel->setText (to_qstring (msg));
       leftLabel->update ();
     }
       break;
+
     case SLOT_RIGHT_FOOTER:
     {
-      TYPE_CHECK (type_box (val) == type_helper<string>::id);
+      check_type<string>(val, s);
       string msg= open_box<string> (val);
-      rightLabel->setText (to_qstring (tm_var_encode (msg)));
+      rightLabel->setText (to_qstring (msg));
       rightLabel->update ();
     }
       break;
-      
-    case SLOT_SCROLL_POSITION:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<coord2>::id);
-      coord2 p= open_box<coord2> (val);
-      QPoint pt= to_qpoint (p);
-      if (DEBUG_QT)
-        cout << "   Position (" << pt.x() << "," << pt.y() << ")\n ";
-      scrollarea()->setOrigin(pt);
-    }
-      break;
-      
+
     case SLOT_SCROLLBARS_VISIBILITY:
         // ignore this: qt handles scrollbars independently
         //                send_int (THIS, "scrollbars", val);
       break;
-      
+
     case SLOT_INTERACTIVE_MODE:
     {
-      TYPE_CHECK (type_box (val) == type_helper<bool>::id);
+      check_type<bool>(val, s);
 
       if (open_box<bool> (val) == true) {
         prompt = new QTMInteractivePrompt (int_prompt, int_input);
-        mainwindow()->statusBar()->removeWidget(leftLabel);
-        mainwindow()->statusBar()->removeWidget(rightLabel);
-        mainwindow()->statusBar()->addWidget(prompt, 1);
+        mainwindow()->statusBar()->removeWidget (leftLabel);
+        mainwindow()->statusBar()->removeWidget (rightLabel);
+        mainwindow()->statusBar()->addWidget (prompt, 1);
         prompt->start();
       } else {
         if (prompt) prompt->end();
-        mainwindow()->statusBar()->removeWidget(prompt);
-        mainwindow()->statusBar()->addWidget(leftLabel);
-        mainwindow()->statusBar()->addPermanentWidget(rightLabel);
+        mainwindow()->statusBar()->removeWidget (prompt);
+        mainwindow()->statusBar()->addWidget (leftLabel);
+        mainwindow()->statusBar()->addPermanentWidget (rightLabel);
         leftLabel->show();
         rightLabel->show();
-        delete prompt;
+        prompt->deleteLater();
         prompt = NULL;
       }
     }
       break;
       
-    case SLOT_SHRINKING_FACTOR:
-      TYPE_CHECK (type_box (val) == type_helper<int>::id);
-      if (canvas()) {
-        int new_sf = open_box<int> (val);
-        if (DEBUG_QT) cout << "   New shrinking factor :" << new_sf << LF;
-        canvas()->tm_widget()->handle_set_shrinking_factor (new_sf);
-      }
-      break;
-      
     case SLOT_FILE:
     {
-      TYPE_CHECK (type_box (val) == type_helper<string>::id);
+      check_type<string>(val, s);
       string file = open_box<string> (val);
       if (DEBUG_QT) cout << "File: " << file << LF;
 #if (QT_VERSION >= 0x040400)
-      qwid->window()->setWindowFilePath(to_qstring(tm_var_encode(file)));
+      mainwindow()->setWindowFilePath(utf8_to_qstring(file));
 #endif
+    }
+      break;
+
+      /* SLOT_POSITION and SLOT_SIZE are ugly and wrong:
+       we have identified qt_tm_widget with its window, but read (SLOT_POSITION)
+       on the tm_widget must return position of the canvas relative to window
+       coordinates (for use for instance in right clicks, inside mouse_adjust()),
+       whereas, write (SLOT_POSITION) is (mostly?) used by texmacs thinking that
+       we are a window. This is because in plain_window_widget, we return the
+       qt_tm_widget_rep instead of another widget. As a consequence we have to
+       implement two behaviours: as widget and as window inside the same class
+       qt_tm_widget_rep. Therefore qt_tm_widget must handle SLOT_SIZE and 
+       SLOT_POSITION in two ways and at the same time workaround buggy reporting
+       of sizes by Qt, taking into account whether toolbars are on or not
+
+       The current "solution" is a hack until this mess is cleaned up.
+       */
+    case SLOT_POSITION:
+    {
+      check_type<coord2>(val, s);
+      coord2 p= open_box<coord2> (val);
+      QPoint pt = to_qpoint (p);
+      
+#ifdef OS_MACOS
+      if (!visibility[0]) {
+        pt.ry() -= (mainwindow()->frameGeometry().height() -
+                    mainwindow()->geometry().height());
+      }
+        // to avoid window under menu bar on MAC when moving at (0,0)
+        // FIXME: use the real menu bar height.
+      pt.ry() = (pt.y() <= 40) ? 40 : pt.y();
+
+#endif
+      mainwindow()->move (pt);
+    }
+      break;
+      
+    case SLOT_SIZE:
+    {
+      check_type<coord2>(val, s);
+      coord2 p= open_box<coord2> (val);
+      QSize sz= to_qsize (p);
+      
+#ifdef OS_MACOS
+      sz.rheight() += (mainwindow()->frameGeometry().height() -
+                       mainwindow()->geometry().height());
+      sz.rheight() += focusToolBar->height();
+#endif
+      mainwindow()->resize (sz);
     }
       break;
       
     case SLOT_DESTROY:
-    {  
+    {
       ASSERT (is_nil (val), "type mismatch");
       if (!is_nil (quit))
         quit ();
       needs_update ();
     }
       break;
-    default:
-      qt_view_widget_rep::send (s, val);
-  }
-}
 
+    case SLOT_FULL_SCREEN:
+    {
+      check_type<bool> (val, s);
+      set_full_screen(open_box<bool> (val));
+    }
+      break;
+      
+    default:
+      qt_window_widget_rep::send (s, val);
+      return;
+  }
+  
+  if (DEBUG_QT)
+    cout << "qt_tm_widget_rep: sent " << slot_name (s) 
+         << "\t\tto widget\t"      << type_as_string() << LF;
+}
 
 blackbox
 qt_tm_widget_rep::query (slot s, int type_id) {
-  if (DEBUG_QT)
-    cout << "qt_tm_widget_rep::query " << slot_name (s) << LF;
+  if ((DEBUG_QT) && (s != SLOT_RENDERER))
+    cout << "qt_tm_widget_rep: queried " << slot_name(s)
+         << "\t\tto widget\t" << type_as_string() << LF;
   
   switch (s) {
     case SLOT_SCROLL_POSITION:
-    {
-      TYPE_CHECK (type_id == type_helper<coord2>::id);
-      QPoint pt= canvas()->origin();
-      if (DEBUG_QT)
-        cout << "   Position (" << pt.x() << "," << pt.y() << ")\n";
-      return close_box<coord2> (from_qpoint (pt));
-    }
-      
     case SLOT_EXTENTS:
-    {
-      TYPE_CHECK (type_id == type_helper<coord4>::id);
-      QRect rect= canvas()->extents();
-      coord4 c= from_qrect (rect);
-      //if (DEBUG_QT) 
-        cout << "   Canvas geometry " << rect << LF;
-      return close_box<coord4> (c);
-    }
-      
     case SLOT_VISIBLE_PART:
-    {
-      TYPE_CHECK (type_id == type_helper<coord4>::id);
-      QSize sz = canvas()->surface()->size();
-        //sz.setWidth(sz.width()-2);
-      QPoint pos = canvas()->backing_pos;
-      coord4 c = from_qrect(QRect(pos,sz));
-      if (DEBUG_QT) 
-        cout << "   Visible Region " << c << LF;
-      return close_box<coord4> (c);
-    }
-      
+    case SLOT_ZOOM_FACTOR:
+      return main_widget->query(s, type_id);
+
     case SLOT_HEADER_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[0]);
       
     case SLOT_MAIN_ICONS_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[1]);
     
     case SLOT_MODE_ICONS_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[2]);
 
     case SLOT_FOCUS_ICONS_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[3]);      
 
     case SLOT_USER_ICONS_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[4]);
       
     case SLOT_FOOTER_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[5]);
 
     case SLOT_SIDE_TOOLS_VISIBILITY:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
+      check_type_id<bool> (type_id, s);
       return close_box<bool> (visibility[6]);
       
     case SLOT_INTERACTIVE_INPUT:
-      TYPE_CHECK (type_id == type_helper<string>::id);
     {
+      check_type_id<string> (type_id, s);
       qt_input_text_widget_rep* w = 
-        static_cast<qt_input_text_widget_rep*>(int_input.rep);
-      if (w->ok) {
-        return close_box<string>(scm_quote(w->text));
-      } else {
-        return close_box<string>("#f");
-      }
+        static_cast<qt_input_text_widget_rep*> (int_input.rep);
+      if (w->ok)
+        return close_box<string> (scm_quote (w->input));
+      else
+        return close_box<string> ("#f");
     }
+
+    case SLOT_POSITION:
+    {
+      check_type_id<coord2> (type_id, s);
+        // Skip title and toolbars
+      QPoint pt = QPoint (mainwindow()->geometry().x(),
+                          mainwindow()->geometry().y());
+      //cout << "wpos: " << pt.x() << ", " << pt.y() << LF;
       
+        // HACK: Qt seems seems not properly report geometry if the toolbars
+        // are hidden
+#ifdef OS_MACOS
+      if (!visibility[0]) {
+        pt.ry() -= (mainwindow()->frameGeometry().height() -
+                    mainwindow()->geometry().height());
+        if (visibility[3]) pt.ry() += focusToolBar->height();
+          //adding the user toolbar shifts the position too much
+          //if (visibility[4]) pt.ry() += userToolBar->height();
+      }
+#endif
+      return close_box<coord2> (from_qpoint (pt));
+    }
+
     case SLOT_INTERACTIVE_MODE:
-      TYPE_CHECK (type_id == type_helper<bool>::id);
-      return close_box<bool> (false); // FIXME: who needs this info?
-      
+      check_type_id<bool> (type_id, s);
+      return close_box<bool> (prompt && prompt->isActive());
+
     default:
-      return qt_view_widget_rep::query (s, type_id);
+      return qt_window_widget_rep::query (s, type_id);
   }
 }
 
 void
 qt_tm_widget_rep::install_main_menu () {
-    //widget tmp = main_menu_widget;
   main_menu_widget = waiting_main_menu_widget;
   QMenu* m= concrete (main_menu_widget)->get_qmenu();
   if (m) {
@@ -783,28 +772,41 @@ qt_tm_widget_rep::write (slot s, blackbox index, widget w) {
     cout << "qt_tm_widget_rep::write " << slot_name (s) << LF;
   
   switch (s) {
+        // Widget w is usually a qt_simple_widget_rep, with a QTMWidget as
+        // underlying widget. We must discard the current main_widget and 
+        // display the new. But while switching buffers the widget w is a
+        // glue_widget, so we may not just use canvas() everywhere.
     case SLOT_SCROLLABLE:
     {
-      check_type_void (index, "SLOT_SCROLLABLE");
-      QStackedWidget* tw= centralwidget();
-      qt_simple_widget_rep* wid= static_cast<qt_simple_widget_rep*>(w.rep);
-      QWidget* new_widget= wid->canvas();
-      QWidget* old_widget= tw->currentWidget();
-      if (old_widget) {
-        tw->removeWidget(old_widget);
-        old_widget->setParent(NULL);
+      check_type_void (index, s);
+      
+      QLayout* l = centralwidget()->layout();
+      
+        //// Reparent the current main_widget's QWidget to the window
+      QWidget* q = concrete(main_widget)->qwid;
+      l->removeWidget(q);
+      q->setParent(qwid);
+      q->deleteLater();                 // careful with pending QEvents...
+      concrete(main_widget)->qwid = 0;  // Unnecessary in principle.
+      
+      q = concrete(w)->as_qwidget();   // force creation of the new QWidget
+      q->setParent(qwid);  // l->removeWidget(q) will reset ownership to this
+      l->addWidget(q);
+
+      main_widget = w; // canvas() now returns the new QTMWidget (or 0)
+
+      if (canvas()) {
+        canvas()->show();
+        canvas()->setFocusPolicy(Qt::StrongFocus);
+        canvas()->setFocus();
+          // Fix horizontal size to draw vertical margins around.
+        scrollarea()->surface()->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
       }
-      if (new_widget) {
-        tw->addWidget(new_widget);
-        new_widget->setFocusPolicy (Qt::StrongFocus);
-        new_widget->setFocus ();
-      }
-        // QTMWidget takes care of QTMWidget::all_widgets
     }
       break;
       
     case SLOT_MAIN_MENU:
-      check_type_void (index, "SLOT_MAIN_MENU");
+      check_type_void (index, s);
     {
       waiting_main_menu_widget = w;
       if (menu_count <=0) {
@@ -821,83 +823,84 @@ qt_tm_widget_rep::write (slot s, blackbox index, widget w) {
       break;
       
     case SLOT_MAIN_ICONS:
-      check_type_void (index, "SLOT_MAIN_ICONS");
+      check_type_void (index, s);
     {
         //cout << "widget :" << (void*)w.rep << LF;
       main_icons_widget = w;
       QMenu* m= concrete (w)->get_qmenu();
       replaceButtons (mainToolBar, m);
-      updateVisibility();
+      update_visibility();
     }
       break;
       
     case SLOT_MODE_ICONS:
-      check_type_void (index, "SLOT_MODE_ICONS");
+      check_type_void (index, s);
     {   
       mode_icons_widget = w;
       QMenu* m= concrete (w)->get_qmenu();
       replaceButtons (modeToolBar, m);
-      updateVisibility();
+      update_visibility();
     }
       break;
       
     case SLOT_FOCUS_ICONS:
-      check_type_void (index, "SLOT_FOCUS_ICONS");
+      check_type_void (index, s);
     {   
       focus_icons_widget = w;
       QMenu* m= concrete (w)->get_qmenu();
       replaceButtons (focusToolBar, m);
-      updateVisibility();
+      update_visibility();
     }
       break;
       
     case SLOT_USER_ICONS:
-      check_type_void (index, "SLOT_USER_ICONS");
+      check_type_void (index, s);
     {   
       user_icons_widget = w;
       QMenu* m= concrete (w)->get_qmenu();
       replaceButtons (userToolBar, m);
-      updateVisibility();
+      update_visibility();
     }
       break;
       
     case SLOT_SIDE_TOOLS:
-      check_type_void (index, "SLOT_SIDE_TOOLS");
+      check_type_void (index, s);
     {
       side_tools_widget = w;
-      QMenu* m= concrete (w)->get_qmenu();
-      replaceButtons (sideToolBar, m);
-      updateVisibility();
+      QWidget* new_qwidget = concrete (w)->as_qwidget();
+      QWidget* old_qwidget = sideDock->widget();
+      old_qwidget->deleteLater();
+      old_qwidget = 0;  // HACK, FIXME
+      sideDock->setWidget (new_qwidget); 
+      update_visibility();
+      new_qwidget->show();
     }
       break;
       
     case SLOT_INTERACTIVE_PROMPT:
-      check_type_void (index, "SLOT_INTERACTIVE_PROMPT");
+      check_type_void (index, s);
       int_prompt= concrete (w);
       break;
       
     case SLOT_INTERACTIVE_INPUT:
-      check_type_void (index, "SLOT_INTERACTIVE_INPUT");
+      check_type_void (index, s);
       int_input= concrete (w);
       break;
 
     default:
-      qt_view_widget_rep::write (s, index, w);
+      qt_window_widget_rep::write (s, index, w);
   }
 }
 
-
 void
 qt_tm_widget_rep::set_full_screen(bool flag) {
   full_screen = flag;
   QWidget *win = mainwindow()->window();  
   if (win) {
     if (flag ) {
-      // remove the borders from some widgets
-      scrollarea()->setFrameShape(QFrame::NoFrame);
 #ifdef UNIFIED_TOOLBAR
       //HACK: we disable unified toolbar since otherwise
-      //  the application will crash when we return in normal mode
+      //  the application will crash when we return to normal mode
       // (bug in Qt? present at least with 4.7.1)
       mainwindow()->setUnifiedTitleAndToolBarOnMac(false);
       mainwindow()->centralWidget()->layout()->setContentsMargins(0,0,0,0);
@@ -908,18 +911,16 @@ qt_tm_widget_rep::set_full_screen(bool flag) {
     } else {
       bool cache = visibility[0];
       visibility[0] = false;
-      updateVisibility();
+      update_visibility();
 //      win->showNormal();
       win->setWindowState(win->windowState() ^ Qt::WindowFullScreen);
 
       visibility[0] = cache;
-      updateVisibility();
-      // reset the borders of some widgets
-      scrollarea()->setFrameShape(QFrame::Box);
+      update_visibility();
 #ifdef UNIFIED_TOOLBAR
-      mainwindow()->centralWidget()->layout()->setContentsMargins(2,2,2,2);
+      mainwindow()->centralWidget()->layout()->setContentsMargins (0,1,0,0);
       //HACK: we reenable unified toolbar (see above HACK) 
-      //  the application will crash return in normal mode
+      //  the application will crash when we return to normal mode
       mainwindow()->setUnifiedTitleAndToolBarOnMac(true);
 #endif
     }
@@ -935,71 +936,39 @@ qt_tm_widget_rep::set_full_screen(bool flag) {
  ******************************************************************************/
 
 qt_tm_embedded_widget_rep::qt_tm_embedded_widget_rep (command _quit) 
-  : qt_view_widget_rep(new QTMWidget(0, 0), embedded_tm_widget), quit(_quit) { }
+ : qt_widget_rep(embedded_tm_widget), quit(_quit) {
 
-qt_tm_embedded_widget_rep::~qt_tm_embedded_widget_rep () { }
+  main_widget = ::glue_widget (true, true, 1, 1);
+    // force creation of QWidget and reparent main_widget's QWidget to it.
+  qwid = as_qwidget();
+}
 
 void
 qt_tm_embedded_widget_rep::send (slot s, blackbox val) {
-  if (DEBUG_QT)
-    cout << "qt_tm_embedded_widget_rep::send " << slot_name (s) << LF;
-  
+
   switch (s) {
     case SLOT_INVALIDATE:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<coord4>::id);
-      coord4 p= open_box<coord4> (val);
-      if (DEBUG_QT)
-        cout << "Invalidating rect " << rectangle(p.x1,p.x2,p.x3,p.x4) << LF;
-      qt_renderer_rep* ren = (qt_renderer_rep*)get_renderer (this);
-      if (ren && canvas()) {
-        SI x1 = p.x1, y1 = p.x2, x2 = p.x3, y2 = p.x4;    
-        ren->outer_round (x1, y1, x2, y2);
-        ren->decode (x1, y1);
-        ren->decode (x2, y2);
-        canvas()->invalidate_rect (x1,y2,x2,y1);
-      }
-    }
-      break;
     case SLOT_INVALIDATE_ALL:
-    {
-      ASSERT (is_nil (val), "type mismatch");
-      if (DEBUG_QT)
-        cout << "Invalidating all"<<  LF;
-      if (canvas()) canvas()->invalidate_all ();
-    }
-      break;
-      
     case SLOT_EXTENTS:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<coord4>::id);
-      coord4 p= open_box<coord4> (val);
-      QRect rect = to_qrect (p);
-        //NOTE: rect.topLeft is ignored since it is always (0,0)
-      canvas()->setExtents(rect);
-    }
-      break;
-      
-    case SLOT_SHRINKING_FACTOR:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<int>::id);
-      if (canvas()) {
-        int new_sf = open_box<int> (val);
-        if (DEBUG_QT) cout << "   New shrinking factor :" << new_sf << LF;
-        canvas()->tm_widget()->handle_set_shrinking_factor (new_sf);
-      }
-      break;
-    }
-      
     case SLOT_SCROLL_POSITION:
-    {
-      TYPE_CHECK (type_box (val) == type_helper<coord2>::id);
-      coord2 p= open_box<coord2> (val);
-      QPoint pt= to_qpoint (p);
-      if (DEBUG_QT)
-        cout << "   Position (" << pt.x() << "," << pt.y() << ")\n ";
-      scrollarea()->setOrigin(pt);
-    }
+    case SLOT_ZOOM_FACTOR:
+    case SLOT_MOUSE_GRAB:
+      main_widget->send(s, val);
+      return;
+
+       /// FIXME: decide what to do with these for embedded widgets
+    case SLOT_HEADER_VISIBILITY:
+    case SLOT_MAIN_ICONS_VISIBILITY:    
+    case SLOT_MODE_ICONS_VISIBILITY:
+    case SLOT_FOCUS_ICONS_VISIBILITY:
+    case SLOT_USER_ICONS_VISIBILITY:
+    case SLOT_FOOTER_VISIBILITY:
+    case SLOT_SIDE_TOOLS_VISIBILITY:
+    case SLOT_LEFT_FOOTER:
+    case SLOT_RIGHT_FOOTER:
+    case SLOT_SCROLLBARS_VISIBILITY:
+    case SLOT_INTERACTIVE_MODE:
+    case SLOT_FILE:
       break;
 
     case SLOT_DESTROY:
@@ -1012,8 +981,12 @@ qt_tm_embedded_widget_rep::send (slot s, blackbox val) {
       break;
       
     default:
-      qt_view_widget_rep::send (s, val);
+      qt_widget_rep::send (s, val);
+      return;
   }
+  if (DEBUG_QT)
+    cout << "qt_tm_embedded_widget_rep: sent " << slot_name (s) 
+         << "\t\tto widget\t" << type_as_string() << LF;  
 }
 
 blackbox
@@ -1022,69 +995,106 @@ qt_tm_embedded_widget_rep::query (slot s, int type_id) {
     cout << "qt_tm_embedded_widget_rep::query " << slot_name (s) << LF;
   
   switch (s) {
+    case SLOT_IDENTIFIER:
+      return qt_window_widget_rep::widget_from_qwidget(qwid)->query(s, type_id);
+
     case SLOT_SCROLL_POSITION:
-    {
-      TYPE_CHECK (type_id == type_helper<coord2>::id);
-      QPoint pt= canvas()->origin();
-      if (DEBUG_QT)
-        cout << "   Position (" << pt.x() << "," << pt.y() << ")\n";
-      return close_box<coord2> (from_qpoint (pt));
-    }
-      
     case SLOT_EXTENTS:
-    {
-      TYPE_CHECK (type_id == type_helper<coord4>::id);
-      QRect rect= canvas()->extents();
-      coord4 c= from_qrect (rect);
-      if (DEBUG_QT) 
-        cout << "   Canvas geometry " << rect << LF;
-      return close_box<coord4> (c);
-    }
-      
     case SLOT_VISIBLE_PART:
-    {
-      TYPE_CHECK (type_id == type_helper<coord4>::id);
+    case SLOT_ZOOM_FACTOR:
+    case SLOT_POSITION:
+    case SLOT_SIZE:
+      return main_widget->query(s, type_id);
       
-      QSize sz = canvas()->surface()->size();
-      QPoint pos = canvas()->backing_pos;
-      coord4 c = from_qrect(QRect(pos,sz));
-      if (DEBUG_QT) 
-        cout << "   Visible Region " << c << LF;
-      return close_box<coord4> (c);
-    }
+        /// FIXME: decide what to do with these for embedded widgets
+    case SLOT_HEADER_VISIBILITY:
+    case SLOT_MAIN_ICONS_VISIBILITY:
+    case SLOT_MODE_ICONS_VISIBILITY:
+    case SLOT_FOCUS_ICONS_VISIBILITY:
+    case SLOT_USER_ICONS_VISIBILITY:
+    case SLOT_FOOTER_VISIBILITY:
+    case SLOT_SIDE_TOOLS_VISIBILITY:
+      check_type_id<bool> (type_id, s);
+      return close_box<bool> (false);
 
     default:
-      return qt_view_widget_rep::query (s, type_id);
+      return qt_widget_rep::query (s, type_id);
   }
 }
 
+widget
+qt_tm_embedded_widget_rep::read(slot s, blackbox index) {
+  widget ret;
+  
+  switch (s) {
+    case SLOT_CANVAS:
+      check_type_void (index, s);
+      ret = main_widget;
+      break;
+    default:
+      return qt_widget_rep::read(s, index);
+  }
+  
+  if (DEBUG_QT)
+    cout << "qt_tm_widget_rep::read " << slot_name (s) 
+         << "\t\tfor widget\t" << type_as_string() << LF;
+  
+  return ret;
+}
+
 void
 qt_tm_embedded_widget_rep::write (slot s, blackbox index, widget w) {
   if (DEBUG_QT)
     cout << "qt_tm_embedded_widget_rep::write " << slot_name (s) << LF;
 
   switch (s) {
-        // Widget w is a qt_simple_widget_rep, with a QTMWidget as underlying
-        // widget. We must discard the current QTMWidget and display the new.
-        // Also, because upon construction we created a dummy QTMWidget without
-        // an owning tm-widget, we set it here.
+      // Widget w is a qt_simple_widget_rep, with a QTMWidget as underlying
+      // widget. We must discard the current QTMWidget and display the new.
+      // see qt_tm_widget_rep::write()
     case SLOT_SCROLLABLE:
     {
-      check_type_void (index, "SLOT_SCROLLABLE");
-      qt_simple_widget_rep* wid = static_cast<qt_simple_widget_rep*>(w.rep);
-      QTMWidget* new_widget     = wid->canvas();     
-      if (new_widget) {
-        delete canvas();
-        new_widget->setFocusPolicy (Qt::StrongFocus);
-        new_widget->setFocus ();
-        new_widget->set_tm_widget(wid);
-        qwid = new_widget;
-      } else {
-        FAILED("Attempt to set an invalid scrollable widget for a qt_tm_embedded_widget");
-      }
+      check_type_void (index, s);
+      
+      QLayout* l = qwid->layout();
+      QWidget* q = concrete(main_widget)->qwid;
+      l->removeWidget(q);
+      q->deleteLater();
+      concrete(main_widget)->qwid = 0;
+      q = concrete(w)->as_qwidget();
+      q->setParent(qwid);
+      l->addWidget(q);
+      main_widget = w;
+        //qwid->show();
+      qwid->setFocusPolicy (Qt::StrongFocus);
+      qwid->setFocus ();       
     }
-      break; 
+      break;
+
+        /// FIXME: decide what to do with these for embedded widgets
+    case SLOT_MAIN_MENU:
+    case SLOT_MAIN_ICONS:
+    case SLOT_MODE_ICONS:
+    case SLOT_FOCUS_ICONS:
+    case SLOT_USER_ICONS:
+    case SLOT_SIDE_TOOLS:
+    case SLOT_INTERACTIVE_INPUT:
+    case SLOT_INTERACTIVE_PROMPT:
     default:
-      qt_view_widget_rep::write (s, index, w);
+      qt_widget_rep::write (s, index, w);
   }
 }
+
+QWidget*
+qt_tm_embedded_widget_rep::as_qwidget() {
+  qwid = new QWidget();
+  QVBoxLayout* l = new QVBoxLayout();
+  l->setContentsMargins(0,0,0,0);
+  qwid->setLayout(l);
+  l->addWidget(concrete(main_widget)->as_qwidget());
+  return qwid;
+}
+
+QLayoutItem*
+qt_tm_embedded_widget_rep::as_qlayoutitem () {
+  return new QWidgetItem(as_qwidget());
+}
