@@ -12,14 +12,16 @@
 #ifndef QT_UI_ELEMENT_HPP
 #define QT_UI_ELEMENT_HPP
 
-#include "qt_widget.hpp"
 #include "ntuple.hpp"
 #include "promise.hpp"
 #include "url.hpp"
-#include "Scheme/object.hpp"
+#include "scheme.hpp"
 #include "hashmap.hpp"
 
-#include <QAction>
+#include "qt_widget.hpp"
+#include "QTMMenuHelper.hpp"
+
+#include <QtGui>
 
 
 /*! Construction of UI elements / widgets.
@@ -92,6 +94,8 @@ public:
 };
 
 
+/*! A rectangular separator widget with a colored background.
+ */
 class qt_glue_widget_rep: public qt_widget_rep {
 public:
   
@@ -108,8 +112,95 @@ public:
   
   QPixmap render ();
   
-  virtual QAction *as_qaction();
-  virtual QWidget *as_qwidget();
+  virtual QAction* as_qaction ();
+  virtual QWidget* as_qwidget ();
 };
 
+
+/*!
+ We use this class to properly initialize style options for our QWidgets
+ which have to blend into QMenus
+    see #QTBUG-1993.
+    see #QTBUG-7707.
+ */
+class QTMAuxMenu: public QMenu {
+public:
+  QTMAuxMenu (): QMenu() {}
+  
+  void myInitStyleOption (QStyleOptionMenuItem *option) const {
+    QAction action (NULL);
+    initStyleOption(option,&action);
+  }
+};
+
+
+/*! QTMMenuButton is a custom button appropriate for menus
+ 
+ We need to subclass QToolButton for two reasons
+ 1) custom appearence
+ 2) if used in QWidgetAction the menu does not disappear upon triggering the
+ button. See QTBUG-10427.
+ */
+class QTMMenuButton: public QToolButton {
+  QStyleOptionMenuItem option;
+  
+public:
+  QTMMenuButton (QWidget* parent = NULL);
+  void mouseReleaseEvent (QMouseEvent *event);
+  void mousePressEvent (QMouseEvent *event);
+  void paintEvent (QPaintEvent *event);
+};
+
+
+/*!
+ */
+class QTMMenuWidget: public QWidget {
+  QStyleOptionMenuItem option;
+  
+public:
+  QTMMenuWidget (QWidget* parent = NULL);
+  void paintEvent(QPaintEvent *event);
+};
+
+/*! Ad-hoc command to be used with choice widgets.
+ 
+ The command associated with a qt_ui_element::choice_widget has one parameter
+ (a list of selected items).
+ For the reason to be of this class, see \sa qt_toggle_command_rep.
+ \sa qt_ui_element, , qt_ui_element_rep::as_qwidget, qt_ui_element_rep::choice_widget
+ */
+class qt_choice_command_rep: public command_rep {
+  QPointer<QTMListView> qwid;
+  command                cmd;
+  bool              multiple;  //<! Are multiple choices allowed in the widget?
+  bool              filtered;
+  
+public:
+  qt_choice_command_rep (QTMListView* w, command c, bool m, bool f=false)
+  : qwid(w), cmd(c), multiple(m), filtered(f) {}
+  
+  virtual void apply () {
+    if (qwid) {
+      QStringList selected;
+      foreach (QModelIndex item, qwid->selectionModel()->selectedIndexes())
+      selected << qwid->model()->data(item).toString();
+      
+      object l= null_object ();
+      if (multiple)
+        for (int i = selected.size() - 1; i >= 0; --i)
+          l = cons (from_qstring (selected[i]), l);
+      else if (selected.size() > 0)
+        l = from_qstring (selected[0]);
+      else
+        l = "";
+      
+      if (filtered)
+        cmd (list_object (l, from_qstring (qwid->filter()->filterRegExp().pattern())));
+      else
+        cmd (list_object (l));
+    }
+  }
+  
+  tm_ostream& print (tm_ostream& out) { return out << "Choice"; }
+};
 #endif // defined QT_UI_ELEMENT_HPP
