@@ -41,13 +41,15 @@ QPoint   to_qpoint (const coord2 & p);
 coord2 from_qpoint (const QPoint & pt);
 
 QSize    to_qsize (const coord2 & p);
+QSize    to_qsize (const SI& w, const SI& h);
 coord2 from_qsize (const QSize & s);
 
 QFont         to_qfont (int style, QFont font);
 QString to_qstylesheet (int style);
 QString to_qstylesheet (int style, color c);
 
-QSize qt_decode_length (QWidget* qwid, string width, string height);
+QSize qt_decode_length (string width, string height, 
+                        const QSize& ref, const QFontMetrics& fm);
 
 QKeySequence to_qkeysequence (string s);
 
@@ -56,12 +58,23 @@ array<string> from_qstringlist (const QStringList& l);
 
 ///// String conversion: Assumes UTF8 encodings both in QT and TeXmacs.
 
-QString        to_qstring (string s);
+QString        to_qstring (const string& s);
 string       from_qstring (const QString & s);
-QString   utf8_to_qstring (string s);
+QString   utf8_to_qstring (const string& s);
+QString latin1_to_qstring (const string& s);
 string  from_qstring_utf8 (const QString & s);
 
-string qt_translate (string s); //!< convert a QString to a TeXmacs cork string
+/*! Returns a QString with the translation of the argument to the current
+ language.
+ 
+ NOTE: translations of gui items are always done in the scheme side using 
+ (translate stuff-to-translate), and this is enabled by default for most widgets
+ displaying text. We need not and must not use Qt's mechanism for translations
+ nor even this function, unless the strings to be translated are hardcoded in
+ our code (which is wrong of course). While parsing widgets, etc. nothing is to
+ be done wrt. translations.
+ */
+QString qt_translate (const string& s);
 
 
 /******************************************************************************
@@ -72,6 +85,7 @@ bool qt_supports (url u);
 void qt_image_size (url image, int& w, int& h);
 void qt_convert_image (url image, url dest, int w =0, int h =0);
 void qt_image_to_eps (url image, url eps, int w_pt =0, int h_pt =0, int dpi= 0);
+string qt_image_to_eps (url image, int w_pt =0, int h_pt =0, int dpi= 0);
 
 string qt_application_directory ();
 string qt_get_date (string lan, string fm);
@@ -83,17 +97,25 @@ bool qt_print (bool&, bool&, string&, url&, string&, string&, string&);
  ******************************************************************************/
 
 inline void
-check_type_void (blackbox bb, string s) {
+check_type_void (blackbox bb, slot s) {
   if (!is_nil (bb)) {
-    cerr << "\nslot type= " << s << "\n";
+    cerr << "\nslot type= " << as_string(s) << LF;
+    FAILED ("type mismatch");
+  }
+}
+
+template<class T> inline void
+check_type_id (int type_id, slot s) {
+  if (type_id != type_helper<T>::id) {
+    cerr << "\nslot type= " << as_string(s) << LF;
     FAILED ("type mismatch");
   }
 }
 
 template<class T> void
-check_type (blackbox bb, string s) {
+check_type (blackbox bb, slot s) {
   if (type_box (bb) != type_helper<T>::id) {
-    cerr << "\nslot type= " << s << "\n";
+    cerr << "\nslot type= " << as_string(s) << LF;
     FAILED ("type mismatch");
   }
 }
@@ -113,7 +135,8 @@ extern int nr_windows;
  ******************************************************************************/
 extern tm_ostream& operator << (tm_ostream& out, QRect rect);
 
-#define TYPE_CHECK(b) ASSERT (b, "type mismatch")
+// deprecated, use check_type<T>(bb, slot) instead
+//#define TYPE_CHECK(b) ASSERT (b, "type mismatch")   
 
 #define NOT_IMPLEMENTED \
 { if (DEBUG_QT) cout << "NOT YET IMPLEMENTED\n"; }
