@@ -15,6 +15,7 @@
 #include "window.hpp"
 #include "Widkit/attribute_widget.hpp"
 #include "Widkit/layout.hpp"
+#include "scheme.hpp"
 
 #ifdef OS_WIN32
 #define URL_CONCATER  '\\'
@@ -29,10 +30,16 @@
 class input_widget_rep: public attribute_widget_rep {
   string  s;           // the string being entered
   string  draw_s;      // the string being displayed
+  SI      text_h;      // text height
   string  type;        // expected type of string
   array<string> def;   // default possible input values
   command call_back;   // routine called on <return> or <escape>
+  int     style;       // style of widget
+  bool    greyed;      // greyed input
+  string  width;       // width of input field
+  bool    persistent;  // don't complete after loss of focus
   bool    ok;          // input not canceled
+  bool    done;        // call back has been called
   int     def_cur;     // current choice between default possible values
   SI      dw, dh;      // border width and height
   int     pos;         // cursor position
@@ -44,9 +51,11 @@ class input_widget_rep: public attribute_widget_rep {
   int     tab_pos;     // cursor position where tab was pressed
 
 public:
-  input_widget_rep (command call_back);
+  input_widget_rep (command call_back, int style, string width, bool persist);
   operator tree ();
   void update_draw_s ();
+  void commit ();
+  void cancel ();
 
   void handle_get_size (get_size_event ev);
   void handle_repaint (repaint_event ev);
@@ -64,19 +73,21 @@ public:
 
 #define SHRINK 3
 
-input_widget_rep::input_widget_rep (command call_back2):
+input_widget_rep::input_widget_rep (command cb2, int st2, string w2, bool p2):
   attribute_widget_rep (south_west),
-  s (""), draw_s (""), type ("default"), def (), call_back (call_back2),
-  ok (true), def_cur (0),
-  dw (2*PIXEL), dh (2*PIXEL), pos (N(s)), scroll (0),
+  s (""), draw_s (""), type ("default"), def (),
+  call_back (cb2), style (st2),
+  greyed ((style & WIDGET_STYLE_INERT) != 0),
+  width (w2), persistent (p2),
+  ok (true), done (false), def_cur (0),
+  dw (4*PIXEL), dh (2*PIXEL), pos (N(s)), scroll (0),
   got_focus (false), hilit (false)
 {
-  if (use_macos_fonts ()) {
-    dw += PIXEL;
-    dh += 3*PIXEL;
-  }
+  if ((style & WIDGET_STYLE_MINI) != 0) dh= 1.5 * PIXEL;
   dw *= SHRINK;
   dh *= SHRINK;
+  font fn= get_default_styled_font (style);
+  text_h = (fn->y2- fn->y1+ 2*dh+ (SHRINK-1))/SHRINK;
 }
 
 input_widget_rep::operator tree () {
@@ -93,22 +104,49 @@ input_widget_rep::update_draw_s () {
   }
 }
 
+void
+input_widget_rep::commit () {
+  ok= true;
+  done= true;
+  call_back (list_object (object (s)));
+}
+
+void
+input_widget_rep::cancel () {
+  ok= false;
+  done= true;
+  call_back (list_object (object (false)));
+}
+
 void
 input_widget_rep::handle_get_size (get_size_event ev) {
-  SI dummy;
-  font fn= get_default_font ();
-  ev->h = (fn->y2- fn->y1+ 2*dh+ (SHRINK-1))/SHRINK;
+  SI ww = decode_length (width, this, style);
+  SI dww= (SI) ((2*dw) / SHRINK);
+  if (ends (width, "w") && is_double (width (0, N(width) - 1))) {
+    font fn= get_default_styled_font (style);
+    if (ev->mode == -1) ev->w= 0;
+    else if (ev->mode == 0);
+    else if (ev->mode == 1) ev->w= ww;
+    ev->w= max (ev->w, (4*fn->wquad) / SHRINK + dww);
+  }
+  else if (ends (width, "em") && is_double (width (0, N(width) - 2)))
+    ev->w= ww + dww;
+  else if (ends (width, "px") && is_double (width (0, N(width) - 2)))
+    ev->w= ww + dww;
+  else if (ev->mode == 1)
+    ev->w= ww;
+  ev->h= text_h;
   abs_round (ev->w, ev->h);
-  if (ev->mode == 1) gui_maximal_extents (ev->w, dummy);
 }
 
 void
 input_widget_rep::handle_repaint (repaint_event ev) { (void) ev;
   renderer ren= win->get_renderer ();
   update_draw_s (); 
+  SI ecart= max (0, (h - (2*dh / SHRINK) - text_h) >> 1);
 
   metric ex;
-  font fn= get_default_font ();
+  font fn= get_default_styled_font (style);
   fn->var_get_extents (draw_s, ex);
   SI left= ex->x1, bottom= fn->y1, right= ex->x2;
   fn->var_get_extents (draw_s (0, pos), ex);
@@ -124,33 +162,48 @@ input_widget_rep::handle_repaint (repaint_event ev) { (void) ev;
   left    += scroll;
   current -= scroll;
 
-  if (got_focus && hilit) {
+  layout_default (ren, 0, 0, w, h);
+  if (true) {
+    SI yy= ((ecart + PIXEL/2) / PIXEL) * PIXEL;
+    SI hh= ((h - 2*ecart + PIXEL/2) / PIXEL) * PIXEL;
+    if (yy + hh + 2*PIXEL <= h) hh += 2 * PIXEL;
+    else if (yy + hh + PIXEL <= h) hh += PIXEL;
+    if (greyed) layout_default (ren, 0, yy, w, hh);
+    else layout_pastel (ren, 0, yy, w, hh);
+    layout_lower (ren, 0, yy, w, hh);
+  }
+  else if (got_focus && hilit) {
     layout_dark (ren, 0, 0, w, h);
     layout_lower (ren, 0, 0, w, h);
   }
-  else layout_default (ren, 0, 0, w, h);
+
   ren->set_color (black);
+  if (greyed) ren->set_color (dark_grey);
   ren->set_shrinking_factor (SHRINK);
-  fn->var_draw (ren, draw_s, dw- left, dh- bottom);
+  ecart *= SHRINK;
+  fn->var_draw (ren, draw_s, dw - left, dh - bottom + ecart);
   if (got_focus) {
     SI pixel= SHRINK*PIXEL;
     ren->set_color (red);
-    ren->line (current+ dw, dh,
-	       current+ dw, height- pixel- dh);
-    ren->line (current+ dw- pixel, dh,
-	       current+ dw+ pixel, dh);
-    ren->line (current+ dw- pixel, height- pixel- dh,
-	       current+ dw+ pixel, height- pixel- dh);
+    ren->line (current + dw, dh + ecart,
+	       current + dw, height - pixel - dh - ecart);
+    ren->line (current + dw - pixel, dh + ecart,
+	       current + dw + pixel, dh + ecart);
+    ren->line (current + dw - pixel, height - pixel - dh - ecart,
+	       current + dw + pixel, height - pixel - dh - ecart);
   }
   ren->set_shrinking_factor (1);
 }
 
 void
 input_widget_rep::handle_keypress (keypress_event ev) {
+  if (greyed) return;
   string key= ev->key;
   while ((N(key) >= 5) && (key(0,3) == "Mod") && (key[4] == '-') &&
 	 (key[3] >= '1') && (key[3] <= '5')) key= key (5, N(key));
   if (key == "space") key= " ";
+  if (key == "<") key= "<less>";
+  if (key == ">") key= "<gtr>";
 
   /* tab-completion */
   if ((key == "tab" || key == "S-tab") && N(tabs) != 0) {
@@ -197,9 +250,9 @@ input_widget_rep::handle_keypress (keypress_event ev) {
   }
 
   /* other actions */
-  if (key == "return") { ok= true; call_back (); }
+  if (key == "return") commit ();
   else if ((key == "escape") || (key == "C-c") ||
-	   (key == "C-g")) { ok= false; call_back (); }
+	   (key == "C-g")) cancel ();
   else if ((key == "left") || (key == "C-b")) {
     if (pos>0) tm_char_backwards (s, pos); }
   else if ((key == "right") || (key == "C-f")) {
@@ -241,6 +294,7 @@ input_widget_rep::handle_keypress (keypress_event ev) {
   }
   else {
     if (starts (key, "<#"));
+    else if (key == "<less>" || key == "<gtr>");
     else {
       if (N(key)!=1) return;
       int i (key[0]);
@@ -254,11 +308,12 @@ input_widget_rep::handle_keypress (keypress_event ev) {
 
 void
 input_widget_rep::handle_mouse (mouse_event ev) {
+  if (greyed) return;
   update_draw_s ();
 
   string type= ev->type;
   SI     x   = ev->x;
-  font   fn  = get_default_font ();
+  font   fn  = get_default_styled_font (style);
 
   if (type == "press-left") {
     if (N(s)>0) {
@@ -281,9 +336,10 @@ input_widget_rep::handle_mouse (mouse_event ev) {
 
   if (type == "press-middle") {
     tree t; string sel;
-    (void) get_selection ("primary", t, sel);
+    (void) get_selection ("primary", t, sel, "verbatim");
     if (is_tuple (t, "extern", 1)) {
       string ins= as_string (t[1]);
+      ins= tm_encode (ins);
       s= s (0, pos) * ins * s(pos, N(s));
       pos += N(ins);
       this << emit_invalidate_all ();
@@ -294,8 +350,11 @@ input_widget_rep::handle_mouse (mouse_event ev) {
 
 void
 input_widget_rep::handle_keyboard_focus (keyboard_focus_event ev) {
+  if (got_focus && !ev->flag && !done && !persistent)
+    cancel ();
   got_focus= ev->flag;
-  this << emit_invalidate_all ();
+  if (attached ())
+    this << emit_invalidate_all ();
 }
 
 void
@@ -335,14 +394,20 @@ get_input_string (string& s) {
 }
 
 wk_widget
-input_text_wk_widget (command call_back) {
-  return tm_new<input_widget_rep> (call_back);
+input_text_wk_widget (command call_back,
+		      int style, string w, bool persistent)
+{
+  (void) style;
+  return tm_new<input_widget_rep> (call_back, style, w, persistent);
 }
 
 wk_widget
-input_text_wk_widget (command cb, string type, array<string> def) {
+input_text_wk_widget (command cb, string type, array<string> def,
+		      int style, string w, bool persistent)
+{
+  (void) style;
   int i, n= N(def);
-  wk_widget inp= input_text_wk_widget (cb);
+  wk_widget inp= input_text_wk_widget (cb, style, w, persistent);
   inp << set_string ("type", type);
   if (n>0) inp << set_string ("input", def[0]);
   for (i=0; i<n; i++) inp << set_string ("default", def[i]);
