@@ -47,6 +47,7 @@ public:
   void handle_set_widget (set_widget_event ev);
   void handle_get_widget (get_widget_event ev);
   void handle_set_integer (set_integer_event ev);
+  void handle_set_double (set_double_event ev);
   void handle_set_string (set_string_event ev);
   void handle_get_string (get_string_event ev);
   void handle_set_coord2 (set_coord2_event ev);
@@ -362,13 +363,18 @@ texmacs_widget_rep::handle_set_widget (set_widget_event ev) {
 
 void
 texmacs_widget_rep::handle_set_integer (set_integer_event ev) {
-  if (ev->which == "shrinking factor")
-    THIS ["canvas"] << set_integer ("shrinking factor", ev->i);
-  else if (ev->which == "scrollbars")
+  if (ev->which == "scrollbars")
     THIS ["canvas"] << set_integer ("scrollbars", ev->i);
   else WK_FAILED ("could not set integer attribute " * ev->which);
 }
 
+void
+texmacs_widget_rep::handle_set_double (set_double_event ev) {
+  if (ev->which == "zoom factor")
+    THIS ["canvas"] << set_double ("zoom factor", ev->x);
+  else WK_FAILED ("could not set double attribute " * ev->which);
+}
+
 void
 texmacs_widget_rep::handle_set_string (set_string_event ev) {
   if (ev->which == "window name") win->set_name (ev->s);
@@ -383,7 +389,7 @@ texmacs_widget_rep::handle_set_string (set_string_event ev) {
     set_subwidget_flag (THIS ["header"] ["focus"], ev->s == "on");
   else if (ev->which == "user icons")
     set_subwidget_flag (THIS ["header"] ["user"], ev->s == "on");
-  else if (use_side_tools && ev->which == "side tools")
+  else if (ev->which == "side tools")
     /*set_side_tools_flag (ev->s == "on")*/;
   else if (ev->which == "interactive mode")
     set_footer_mode (ev->s == "on"? 1: (footer_flag? 0: 2));
@@ -410,9 +416,9 @@ texmacs_widget_rep::handle_get_string (get_string_event ev) {
   else if (ev->which == "user icons")
     ev->s= get_subwidget_flag (THIS ["header"] ["user"])?
              string ("on"): string ("off");
-  else if (use_side_tools && ev->which == "side tools")
+  else if (ev->which == "side tools")
     //ev->s= get_side_tools_flag ()? string ("on"): string ("off");
-    ev->s= string ("on");
+    ev->s= string (use_side_tools? "on": "off");
   else if (ev->which == "interactive mode")
     ev->s= get_footer_mode () == 1? string ("on"): string ("off");
   else if (ev->which == "footer flag")
@@ -496,6 +502,9 @@ texmacs_widget_rep::handle (event ev) {
   case SET_INTEGER_EVENT:
     handle_set_integer (ev);
     return true;
+  case SET_DOUBLE_EVENT:
+    handle_set_double (ev);
+    return true;
   case GET_STRING_EVENT:
     handle_get_string (ev);
     return true;
