@@ -37,7 +37,8 @@ struct x_font_rep: font_rep {
   x_font_rep (string name, string family, int size, int dpi);
   void get_extents (string s, metric& ex);
   void get_xpositions (string s, SI* xpos);
-  void draw (renderer ren, string s, SI x, SI y);
+  void draw_fixed (renderer ren, string s, SI x, SI y);
+  font magnify (double zoom);
   glyph get_glyph (string s);
 };
 
