@@ -113,47 +113,53 @@ x_init_color_map () {
 }
 
 color
-rgb_color (int r, int g, int b) {
+rgb_color (int r, int g, int b, int a) {
   if (true_color) {
     if (reverse_colors) reverse (r, g, b);
-    return (r << 16) + (g << 8) + b;
+    return (a << 24) + (r << 16) + (g << 8) + b;
   }
-  else if ((r==g) && (g==b)) return (r*GREYS+ 128)/255;
+  else if ((r==g) && (g==b))
+    return (a << 24) + ((r*GREYS+ 128)/255);
   else {
     r= (r*CSCALES+ 128)/255;
     g= (g*CSCALES+ 128)/255;
     b= (b*CSCALES+ 128)/255;
-    return r*CFACTOR*CFACTOR+ g*CFACTOR+ b+ GREYS+ 1;
+    return (a << 24) + r*CFACTOR*CFACTOR + g*CFACTOR + b + GREYS + 1;
   }
 }
 
 void
-get_rgb_color (color col, int& r, int& g, int& b) {
+get_rgb_color (color col, int& r, int& g, int& b, int& a) {
   if (true_color) {
+    a= (col >> 24) & 255;
     r= (col >> 16) & 255;
     g= (col >> 8 ) & 255;
     b=  col        & 255;
     if (reverse_colors) reverse (r, g, b);
   }
-  else if (col <= GREYS) {
-    r= (col*255)/GREYS;
-    g= (col*255)/GREYS;
-    b= (col*255)/GREYS;
-  }
   else {
-    int rr, gg, bb;
-    col-= (GREYS+1);
-    bb  = col % CFACTOR;
-    gg  = (col/CFACTOR) % CFACTOR;
-    rr  = (col/(CFACTOR*CFACTOR)) % CFACTOR;
-    r   = (rr*255)/CSCALES;
-    g   = (gg*255)/CSCALES;
-    b   = (bb*255)/CSCALES;
+    a= (col >> 24) & 255;
+    col= col & 0xffffff;
+    if (col <= ((color) GREYS)) {
+      r= (col*255)/GREYS;
+      g= (col*255)/GREYS;
+      b= (col*255)/GREYS;
+    }
+    else {
+      int rr, gg, bb;
+      col-= (GREYS+1);
+      bb  = col % CFACTOR;
+      gg  = (col/CFACTOR) % CFACTOR;
+      rr  = (col/(CFACTOR*CFACTOR)) % CFACTOR;
+      r   = (rr*255)/CSCALES;
+      g   = (gg*255)/CSCALES;
+      b   = (bb*255)/CSCALES;
+    }
   }
 }
 
-color
-named_color (string s) {
+static color
+named_color_bis (string s) {
   if ((N(s) == 4) && (s[0]=='#')) {
     int r= 17 * from_hexadecimal (s (1, 2));
     int g= 17 * from_hexadecimal (s (2, 3));
@@ -203,16 +209,34 @@ named_color (string s) {
   return black;
 }
 
+color
+named_color (string s, int a) {
+  color c= named_color_bis (s);
+  return (a << 24) + (c & 0xffffff);
+}
+
 string
 get_named_color (color c) {
-  SI r, g, b;
-  get_rgb_color (c, r, g, b);
+  int r, g, b, a;
+  get_rgb_color (c, r, g, b, a);
   return "#" *
     as_hexadecimal (r, 2) *
     as_hexadecimal (g, 2) *
     as_hexadecimal (b, 2);
 }
 
+color
+blend (color fg, color bg) {
+  if (((fg >> 24) & 255) == 255) return fg;
+  int fR, fG, fB, fA, bR, bG, bB, bA;
+  get_rgb_color (fg, fR, fG, fB, fA);
+  get_rgb_color (bg, bR, bG, bB, bA);
+  fR= (bR * (255 - fA) + fR * fA) / 255;
+  fG= (bG * (255 - fA) + fG * fA) / 255;
+  fB= (bB * (255 - fA) + fB * fA) / 255;
+  return rgb_color (fR, fG, fB);
+}
+
 void
 x_initialize_colors () {
   if (the_gui->depth >= 16) {
