@@ -38,8 +38,8 @@
   (full-screen-mode full_screen_mode (void bool bool))
   (full-screen? in_full_screen_mode (bool))
   (full-screen-edit? in_full_screen_edit_mode (bool))
-  (set-shrinking-factor set_shrinking_factor (void int))
-  (get-shrinking-factor get_shrinking_factor (int))
+  (set-window-zoom-factor set_window_zoom_factor (void double))
+  (get-window-zoom-factor get_window_zoom_factor (double))
 
   (shell shell (void string))
   (dialogue-end dialogue_end (void))
@@ -52,8 +52,8 @@
   (set-printer-paper-type set_printer_page_type (void string))
   (get-printer-paper-type get_printer_page_type (string))
   (set-printer-dpi set_printer_dpi (void string))
-  (set-default-shrinking-factor set_default_shrinking_factor (void int))
-  (get-default-shrinking-factor get_default_shrinking_factor (int))
+  (set-default-zoom-factor set_default_zoom_factor (void double))
+  (get-default-zoom-factor get_default_zoom_factor (double))
   (image-gc image_gc (void))
   (inclusions-gc inclusions_gc (void))
   (update-all-path typeset_update (void path))
