@@ -20,6 +20,7 @@
 #include "convert.hpp"
 #include "file.hpp"
 #include "tmfs.hpp"
+#include "Freetype/tt_tools.hpp"
 
 tmscm 
 blackboxP (tmscm  t) {
@@ -1067,6 +1068,7 @@ tmscm_to_collection (tmscm  p) {
 #include "tmfs.hpp"
 #include "client_server.hpp"
 #include "analyze.hpp"
+#include "wencoding.hpp"
 #include "tree_traverse.hpp"
 #include "tree_analyze.hpp"
 #include "tree_correct.hpp"
