@@ -32,7 +32,7 @@ class evaluate_memorizer_rep: public compound_memorizer_rep {
 public:
   inline evaluate_memorizer_rep (environment env, tree t):
     env_in (env), t_in (t), env_out (), t_out (no_tree) {}
-  void print (ostream& out) {
+  void print (tm_ostream& out) {
     out << "evaluate_memorizer (" << t_in << ")"; }
 
   int type () { return MEMORIZE_EVALUATE; }
@@ -306,8 +306,8 @@ evaluate_impl (tree t) {
     return evaluate_sec_length ();
   case MIN_LENGTH:
     return evaluate_min_length ();
-  case H_LENGTH:
-    return evaluate_h_length ();
+  case HR_LENGTH:
+    return evaluate_hr_length ();
 
   /* Primitives for stylesheet editing */
   case STYLE_WITH:
