@@ -33,7 +33,7 @@ class rewrite_memorizer_rep: public compound_memorizer_rep {
 public:
   inline rewrite_memorizer_rep (environment env, tree t):
     env_in (env), t_in (t), env_out (), t_out (no_tree) {}
-  void print (ostream& out) {
+  void print (tm_ostream& out) {
     out << "rewrite_memorizer (" << t_in << ")"; }
 
   int type () { return MEMORIZE_REWRITE; }
@@ -90,7 +90,6 @@ rewrite_impl (tree t) {
 	expr= cons (object (r[i]), expr);
       string fun= evaluate_string (t[0]);
       expr= cons (string_to_object (fun), expr);
-      (void) eval ("(lazy-markup-modules-force)");
       bool secure= as_bool (std_env ["secure"]);
       if (!secure && script_status < 2) {
 	if (!as_bool (call ("secure?", expr)))
