@@ -14,7 +14,7 @@
 #include "sys_utils.hpp"
 #include "analyze.hpp"
 #include "hashmap.hpp"
-#include "Scheme/object.hpp"
+#include "scheme.hpp"
 
 #ifdef OS_WIN32
 #include <urlget.h>
@@ -138,7 +138,7 @@ get_from_server (url u) {
   if (!is_none (res)) return res;
 
   string name= as_string (u);
-  if (ends (name, "~")) return url_none ();
+  if (ends (name, "~") || ends (name, "#")) return url_none ();
   string r= as_string (call ("tmfs-load", object (name)));
   if (r == "") return url_none ();
   url tmp= url_temp ();
@@ -164,7 +164,7 @@ get_from_ramdisc (url u) {
   if (!is_ramdisc (u)) return url_none ();
   url res= get_cache (u);
   if (!is_none (res)) return (res);
-  url tmp= url_temp ();
+  url tmp= url_temp (string (".") * suffix (u));
   save_string (tmp, u[1][2]->t->label);
   return set_cache (u, tmp);
 }
