@@ -12,6 +12,7 @@
 #include "file.hpp"
 #include "hyphenate.hpp"
 #include "analyze.hpp"
+#include "converter.hpp"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -57,12 +58,14 @@ hyphen_normalize (string s) {
 void
 load_hyphen_tables (string file_name,
                     hashmap<string,string>& patterns,
-                    hashmap<string,string>& hyphenations) {
+                    hashmap<string,string>& hyphenations, bool toCork) {
   string s;
   file_name= string ("hyphen.") * file_name;
   load_string (url ("$TEXMACS_PATH/langs/natural/hyphen", file_name), s, true);
   if (DEBUG_VERBOSE) cout << "TeXmacs] Loading " << file_name << "\n";
 
+  if (toCork) s= utf8_to_cork (s);
+
   hashmap<string,string> H ("?");
   bool pattern_flag=false;
   bool hyphenation_flag=false;
@@ -109,21 +112,53 @@ array<int>
 get_hyphens (string s,
              hashmap<string,string> patterns,
              hashmap<string,string> hyphenations) {
+  return get_hyphens (s, patterns, hyphenations, false);
+}
+
+void
+goto_next_char (string s, int &i, bool utf8) {
+  if (i<N(s) && !utf8) {
+    i++;
+    return;
+  }
+  if (utf8)
+    decode_from_utf8 (s, i);
+  return;
+}
+
+int
+str_length (string s, bool utf8) {
+  if (!utf8) return N(s);
+  int i=0, r=0;
+  while (i<N(s)) {
+    decode_from_utf8 (s, i);
+    r++;
+  }
+  return r;
+}
+
+array<int>
+get_hyphens (string s,
+             hashmap<string,string> patterns,
+             hashmap<string,string> hyphenations, bool utf8) {
   ASSERT (N(s) != 0, "hyphenation of empty string");
 
+  if (utf8) s= cork_to_utf8 (s);
+
   if (hyphenations->contains (s)) {
     string h= hyphenations [s];
-    array<int> penalty (N(s)-1);
+    array<int> penalty (str_length (s, utf8)-1);
     int i=0, j=0;
     while (h[j] == '-') j++;
-    i++; j++;
-    while (i < N(s)) {
+    i++; goto_next_char (h, j, utf8);
+    while (i < N(penalty)+1) {
       penalty[i-1]= HYPH_INVALID;
       while (j < N(h) && h[j] == '-') {
         penalty[i-1]= HYPH_STD;
         j++;
       }
-      i++; j++;
+      i++;
+      goto_next_char (h, j, utf8);
     }
     //cout << s << " --> " << penalty << "\n";
     return penalty;
@@ -131,11 +166,11 @@ get_hyphens (string s,
   else {
     s= "." * lower_case (s) * ".";
     // cout << s << "\n";
-    int i, j, k, m, len;
-    array<int> T (N(s)+1);
-    for (i=0; i<N(s)+1; i++) T[i]=0;
+    int i, j, k, l, m, len;
+    array<int> T (str_length (s, utf8)+1);
+    for (i=0; i<N(T); i++) T[i]=0;
     for (len=1; len < MAX_SEARCH; len++)
-      for (i=0; i<N(s)-len; i++) {
+      for (i=0, l=0; i<N(s) - len; goto_next_char (s, i, utf8), l++) {
         string r= patterns [s (i, i+len)];
         if (!(r == "?")) {
           // cout << "  " << s (i, i+len) << " => " << r << "\n";
@@ -145,13 +180,13 @@ get_hyphens (string s,
               k++;
             }
             else m=0;
-            if (m>T[i+j]) T[i+j]=m;
+            if (m>T[l+j]) T[l+j]=m;
           }
         }
       }
 
-    array<int> penalty (N(s)-3);
-    for (i=2; i<N(s)-1; i++)
+    array<int> penalty (N(T)-4);
+    for (i=2; i < N(T)-4; i++)
       penalty [i-2]= (((T[i]&1)==1)? HYPH_STD: HYPH_INVALID);
     if (N(penalty)>0) penalty[0] = penalty[N(penalty)-1] = HYPH_INVALID;
     if (N(penalty)>1) penalty[1] = penalty[N(penalty)-2] = HYPH_INVALID;
@@ -163,8 +198,27 @@ get_hyphens (string s,
 
 void
 std_hyphenate (string s, int after, string& left, string& right, int penalty) {
-  left = s (0, after+1);
-  right= s (after+1, N(s));
+  std_hyphenate (s, after, left, right, penalty, false);
+}
+void
+std_hyphenate (string s, int after, string& left, string& right, int penalty,
+               bool utf8) {
+  if (!utf8) {
+    left = s (0, after+1);
+    right= s (after+1, N(s));
+  }
+  else {
+    int i= 0, l= 0;
+    while (i < N(s) && l < after+1) {
+      if (s[i] == '<')
+        while (i < N(s) && s[i] != '>') i++;
+      i++;
+      l++;
+    }
+    left = s (0, i);
+    right= s (i, N(s));
+    if (i == N(s)) return;
+  }
   if (penalty >= HYPH_INVALID) left << string ("\\");
   else left << string ("-");
 }
