@@ -96,6 +96,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("alias")= c;
   t ("and")= c;
   t ("assume")= d;
+  t ("autofold")= d;
   t ("begin")= c;
   t ("break")= c;
   t ("case")= c;
@@ -129,6 +130,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("forall")= d;
   t ("foreach")= c;
   t ("foreign")= c;
+  t ("former")= c;
   t ("from")= c;
   t ("fuse")= c;
   t ("generate")= c;
@@ -168,6 +170,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("mutable")= c;
   t ("operator")= c;
   t ("or")= c;
+  t ("outline")= d;
   t ("packed")= c;
   t ("pattern")= c;
   t ("penalty")= c;
@@ -199,6 +202,7 @@ mathemagix_color_setup_keywords (hashmap<string, string> & t)  {
   t ("upgrade")= c;
   t ("use")= c;
   t ("value")= c;
+  t ("virtual")= c;
   t ("while")= c;
   t ("with")= c;
   t ("xor")= c;
@@ -383,17 +387,13 @@ parse_number (string s, int& pos) {
   pos= i;
 }
 
-static void
-parse_no_declare_type (string s, int& pos) {
-  if (pos+1<N(s) && s[pos]==':' && s[pos+1]==':') pos=pos+2;
-}
-
 static void
 parse_declare_type (string s, int& pos) {
   if (pos>=N(s)) return;
   if (s[pos]!=':') return;
   if (pos+1<N(s) && s[pos+1]=='=') return;
   pos++;
+  if (pos+1<N(s) && s[pos]==':') pos++;
   if (!test (s, pos, "<gtr>")) return;
   pos+=5;
 }
@@ -610,16 +610,6 @@ mathemagix_language_rep::get_color (tree t, int start, int end) {
 	possible_future_class= false;
 	break;
       }
-      parse_no_declare_type (s, pos); // :: 
-      if (opos<pos) {
-	type= "no_declare_type";
-	possible_type= false;
-	possible_future_type= false;
-	possible_function= false;
-	possible_future_function= false;
-	possible_future_class= false;
-	break;
-      }  
       parse_backquote (s, pos);
       if (opos<pos) {
 	backquote= true;
@@ -725,8 +715,6 @@ mathemagix_language_rep::get_color (tree t, int start, int end) {
 	if (opos<pos) break;
 	parse_parenthesized (s, pos);
 	if (opos<pos) break;
-	parse_no_declare_type (s, pos);
-	if (opos<pos) break;
 	parse_declare_type (s, pos);
 	if (opos<pos) break;
 	parse_declare_macro(s,pos);
@@ -755,8 +743,6 @@ mathemagix_language_rep::get_color (tree t, int start, int end) {
       if (opos<pos) break;
       parse_parenthesized (s, pos);
       if (opos<pos) break;
-      parse_no_declare_type (s, pos);
-      if (opos<pos) break;
       parse_declare_type (s, pos);
       if (opos<pos) break;
       parse_declare_function (s, pos);
