@@ -23,7 +23,7 @@
 #endif
 
 /******************************************************************************
-* Western text languages
+* Western text languages / 8 bit charset
 ******************************************************************************/
 
 struct text_language_rep: language_rep {
@@ -38,7 +38,7 @@ struct text_language_rep: language_rep {
 
 text_language_rep::text_language_rep (string lan_name, string hyph_name):
   language_rep (lan_name), patterns ("?"), hyphenations ("?") {
-    load_hyphen_tables (hyph_name, patterns, hyphenations); }
+    load_hyphen_tables (hyph_name, patterns, hyphenations, true); }
 
 text_property
 text_language_rep::advance (tree t, int& pos) {
@@ -105,6 +105,93 @@ text_language_rep::hyphenate (
   std_hyphenate (s, after, left, right, penalty[after]);
 }
 
+/******************************************************************************
+* Eastern text languages / using UCS entities
+******************************************************************************/
+
+struct ucs_text_language_rep: language_rep {
+  hashmap<string,string> patterns;
+  hashmap<string,string> hyphenations;
+
+  ucs_text_language_rep (string lan_name, string hyph_name);
+  text_property advance (tree t, int& pos);
+  array<int> get_hyphens (string s);
+  void hyphenate (string s, int after, string& left, string& right);
+  bool unicode;
+};
+
+ucs_text_language_rep::ucs_text_language_rep (string lan_name, string hyph_name):
+  language_rep (lan_name), patterns ("?"), hyphenations ("?")
+  { load_hyphen_tables (hyph_name, patterns, hyphenations, false); }
+
+text_property
+ucs_text_language_rep::advance (tree t, int& pos) {
+  //TODO: replace methods is_punctuation (), is_iso_alpha () and is_numeric (),
+  //      by equivalents taking into account unicode entities.
+  string s= t->label;
+  if (pos == N(s)) return &tp_normal_rep;
+
+  if (s[pos]==' ') {
+    pos++;
+    // while ((pos<N(s)) && (s[pos]==' ')) pos++;
+    if ((pos == N(s)) || (!is_punctuation (s[pos])))
+      return &tp_space_rep;
+    return &tp_blank_rep;
+  }
+  
+  if (is_punctuation (s[pos])) {
+    while ((pos<N(s)) && is_punctuation (s[pos])) pos++;
+    if ((pos==N(s)) || (s[pos]!=' ')) return &tp_normal_rep;
+    switch (s[pos-1]) {
+    case ',': case ':': case ';': case '`': case '\'':
+      return &tp_space_rep;
+    case '.': case '!': case '?':
+      return &tp_period_rep;
+    }
+    return &tp_space_rep;
+  }
+
+  if (s[pos]=='-') {
+    pos++;
+    while ((pos<N(s)) && (s[pos]=='-')) pos++;
+    return &tp_hyph_rep;
+  }
+
+  if (is_iso_alpha (s[pos]) || (s[pos]=='<')) {
+    while ((pos<N(s)) && (is_iso_alpha (s[pos]) || (s[pos]=='<'))) {
+      if (s[pos]=='<') {
+        while ((pos<N(s)) && (s[pos]!='>')) pos++;
+        if (pos<N(s)) pos++;
+      }
+      else
+        pos++;
+    }
+    return &tp_normal_rep;
+  }
+
+  if (is_numeric (s[pos])) { // can not be a '.'
+    while ((pos<N(s)) && is_numeric (s[pos])) pos++;
+    while (s[pos-1]=='.') pos--;
+    return &tp_normal_rep;
+  }
+
+  pos++;
+  return &tp_normal_rep;
+}
+
+array<int>
+ucs_text_language_rep::get_hyphens (string s) {
+  return ::get_hyphens (s, patterns, hyphenations, true);
+}
+
+void
+ucs_text_language_rep::hyphenate (
+  string s, int after, string& left, string& right)
+{
+  array<int> penalty= get_hyphens (s);
+  std_hyphenate (s, after, left, right, penalty[after], true);
+}
+
 /******************************************************************************
 * Oriental languages
 ******************************************************************************/
@@ -261,6 +348,23 @@ language_to_locale (string s) {
   return "en_US";
 }
 
+string
+language_to_local_ISO_charset (string s) {
+  if (s == "bulgarian")  return "ISO-8859-5";
+  if (s == "chinese")    return "";
+  if (s == "czech")      return "ISO-8859-2";
+  if (s == "hungarian")  return "ISO-8859-2";
+  if (s == "japanese")   return "";
+  if (s == "korean")     return "";
+  if (s == "polish")     return "ISO-8859-2";
+  if (s == "romanian")   return "ISO-8859-2";
+  if (s == "russian")    return "ISO-8859-5";
+  if (s == "slovene")    return "ISO-8859-2";
+  if (s == "taiwanese")  return "";
+  if (s == "ukrainian")  return "ISO-8859-5";
+  return "ISO-8859-1";
+}
+
 string
 get_locale_language () {
 #if defined(_WIN32) || defined(__WIN32__)
@@ -353,39 +457,49 @@ get_date (string lan, string fm) {
 
 typedef const char* const_char_ptr;
 
+static language
+make_ucs_text_language (string s, string h) {
+  return tm_new<ucs_text_language_rep> (s, h);
+}
+
 static language
 make_text_language (string s, string h) {
   return tm_new<text_language_rep> (s, h);
 }
 
+static language
+make_oriental_language (string s) {
+  return tm_new<oriental_language_rep> (s);
+}
+
 language
 text_language (string s) {
   if (language::instances -> contains (s)) return language (s);
-  if (s == "american") return make_text_language (s, "us");
-  if (s == "british") return make_text_language (s, "ukenglish");
-  if (s == "bulgarian") return make_text_language (s, "bulgarian");
-  if (s == "chinese") return tm_new<oriental_language_rep> (s);
-  if (s == "czech") return make_text_language (s, "czech");
-  if (s == "danish") return make_text_language (s, "danish");
-  if (s == "dutch") return make_text_language (s, "dutch");
-  if (s == "english") return make_text_language (s, "us");
-  if (s == "finnish") return make_text_language (s, "finnish");
-  if (s == "french") return make_text_language (s, "french");
-  if (s == "german") return make_text_language (s, "german");
-  if (s == "hungarian") return make_text_language (s, "hungarian");
-  if (s == "italian") return make_text_language (s, "italian");
-  if (s == "japanese") return tm_new<oriental_language_rep> (s);
-  if (s == "korean") return tm_new<oriental_language_rep> (s);
-  if (s == "polish") return make_text_language (s, "polish");
+  if (s == "american")   return make_text_language (s, "us");
+  if (s == "british")    return make_text_language (s, "ukenglish");
+  if (s == "bulgarian")  return make_ucs_text_language (s, "bulgarian");
+  if (s == "chinese")    return make_oriental_language (s);
+  if (s == "czech")      return make_text_language (s, "czech");
+  if (s == "danish")     return make_text_language (s, "danish");
+  if (s == "dutch")      return make_text_language (s, "dutch");
+  if (s == "english")    return make_text_language (s, "us");
+  if (s == "finnish")    return make_text_language (s, "finnish");
+  if (s == "french")     return make_text_language (s, "french");
+  if (s == "german")     return make_text_language (s, "german");
+  if (s == "hungarian")  return make_text_language (s, "hungarian");
+  if (s == "italian")    return make_text_language (s, "italian");
+  if (s == "japanese")   return make_oriental_language (s);
+  if (s == "korean")     return make_oriental_language (s);
+  if (s == "polish")     return make_text_language (s, "polish");
   if (s == "portuguese") return make_text_language (s, "portuguese");
-  if (s == "romanian") return make_text_language (s, "romanian");
-  if (s == "russian") return make_text_language (s, "russian");
-  if (s == "slovene") return make_text_language (s, "slovene");
-  if (s == "spanish") return make_text_language (s, "spanish");
-  if (s == "swedish") return make_text_language (s, "swedish");
-  if (s == "taiwanese") return tm_new<oriental_language_rep> (s);
-  if (s == "ukrainian") return make_text_language (s, "ukrainian");
-  if (s == "verbatim") return tm_new<verb_language_rep> ("verbatim");
+  if (s == "romanian")   return make_text_language (s, "romanian");
+  if (s == "russian")    return make_ucs_text_language (s, "russian");
+  if (s == "slovene")    return make_text_language (s, "slovene");
+  if (s == "spanish")    return make_text_language (s, "spanish");
+  if (s == "swedish")    return make_text_language (s, "swedish");
+  if (s == "taiwanese")  return make_oriental_language (s);
+  if (s == "ukrainian")  return make_ucs_text_language (s, "ukrainian");
+  if (s == "verbatim")   return tm_new<verb_language_rep> ("verbatim");
   cerr << "\nThe language was " << s << "\n";
   FAILED ("unknown language");
   return tm_new<verb_language_rep> ("verbatim");
