@@ -11,7 +11,7 @@
 
 #ifndef CONNECT_H
 #define CONNECT_H
-#include "pipe_link.hpp"
+#include "tm_link.hpp"
 
 bool   connection_declared (string name);
 tree   connection_info (string name, string session);
@@ -27,6 +27,5 @@ int    connection_status (string name, string session);
 tree   connection_eval (string name, string session, string s);
 tree   connection_eval (string name, string session, tree t);
 tree   connection_cmd (string name, string session, string s);
-void   listen_to_connections ();
 
 #endif // defined CONNECT_H
