@@ -9,7 +9,12 @@
 * in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
-#include "pipe_link.hpp"
+#include "basic.hpp"
+
+#if !(defined (QTTEXMACS) && (defined (__MINGW__) || defined (__MINGW32__) || defined (QTPIPES)))
+
+#include "tm_link.hpp"
+#include "socket_notifier.hpp"
 #include "sys_utils.hpp"
 #include "hashset.hpp"
 #include "iterator.hpp"
@@ -17,13 +22,9 @@
 #include <stdio.h>
 #include <string.h>
 #ifdef __MINGW32__
-#ifdef OS_WIN32
-#include <sys/pipe.h>
-#else
 //#define PATTERN WIN_PATTERN
 //#include <winsock.h>
 //#undef PATTERN
-#endif
 #else
 #include <unistd.h>
 #include <signal.h>
@@ -34,70 +35,55 @@
 #endif
 
 hashset<pointer> pipe_link_set;
+void pipe_callback (void *obj, void *info);
+extern char **environ;
 
-static void pipe_callback (void *obj, void *info) {
-#ifndef __MINGW32__
-  pipe_link_rep* con= (pipe_link_rep*) obj;  
-#ifdef OS_WIN32
-  bool any_update = false;  
-  if (con->alive  && PIPE_CheckStdout (&con->conn)) {
-    //cout << "pipe_callback OUT" << LF;
-    con->feed (LINK_OUT);
-    any_update = true;
-  }
-  if (con->alive  && PIPE_CheckStderr (&con->conn)) {
-    //cout << "pipe_callback ERR" << LF;
-    con->feed (LINK_ERR);
-    any_update = true;
-  }
-  if (!is_nil (con->feed_cmd) && any_update) {
-    //cout << "pipe_callback APPLY" << LF;
-    if (!is_nil (con->feed_cmd)) con->feed_cmd->apply (); // call the data processor
-  }
-#else
-  fd_set rfds;
-  FD_ZERO (&rfds);
-  int max_fd= max (con->err, con->out)+1;
-  FD_SET (con->out, &rfds);
-  FD_SET (con->err, &rfds);
-  
-  struct timeval tv;
-  tv.tv_sec  = 0;
-  tv.tv_usec = 0;
-  select (max_fd, &rfds, NULL, NULL, &tv);
-
-  bool any_update = false;  
-  if (con->alive && FD_ISSET (con->out, &rfds)) {
-    //cout << "pipe_callback OUT" << LF;
-    con->feed (LINK_OUT);
-    any_update = true;
-  }
-  if (con->alive && FD_ISSET (con->err, &rfds)) {
-    //cout << "pipe_callback ERR" << LF;
-    con->feed (LINK_ERR);
-    any_update = true;
-  }
-  if (!is_nil (con->feed_cmd) && any_update) {
-    //cout << "pipe_callback APPLY" << LF;
-    if (!is_nil (con->feed_cmd)) con->feed_cmd->apply (); // call the data processor
-  }
-#endif
-#endif
-}
+#define STDIN 0
+#define STDOUT 1
+#define STDERR 2
+#define IN 0
+#define OUT 1
+#define TERMCHAR '\1'
 
 /******************************************************************************
-* Constructors and destructors for pipe_links
+* The pipe_link class
 ******************************************************************************/
 
+struct pipe_link_rep: tm_link_rep {
+  string cmd;           // command for launching the pipe
+  int    pid;           // process identifier of the child
+  int    pp_in [2];     // for data going to the child
+  int    pp_out[2];     // for data coming from the child
+  int    pp_err[2];     // for error messages coming from the child
+  int    in;            // file descriptor for data going to the child
+  int    out;           // file descriptor for data coming from the child
+  int    err;           // file descriptor for errors coming from the child
+
+  string outbuf;        // pending output from plugin
+  string errbuf;        // pending errors from plugin
+
+  socket_notifier snout, snerr;
+  
+public:
+  pipe_link_rep (string cmd);
+  ~pipe_link_rep ();
+
+  string  start ();
+  void    write (string s, int channel);
+  string& watch (int channel);
+  string  read (int channel);
+  void    listen (int msecs);
+  void    interrupt ();
+  void    stop ();
+
+  void    feed (int channel);
+};
+
 pipe_link_rep::pipe_link_rep (string cmd2): cmd (cmd2) {
   pipe_link_set->insert ((pointer) this);
-#ifdef OS_WIN32
-  memset(&conn, 0, sizeof(PIPE_CONN));
-#else
   in     = pp_in [0]= pp_in [1]= -1;
   out    = pp_out[0]= pp_out[1]= -1;
   err    = pp_err[0]= pp_err[1]= -1;
-#endif
   outbuf = "";
   errbuf = "";
   alive  = false;
@@ -113,11 +99,36 @@ make_pipe_link (string cmd) {
   return tm_new<pipe_link_rep> (cmd);
 }
 
+void
+close_all_pipes () {
+#ifndef __MINGW32__
+  iterator<pointer> it= iterate (pipe_link_set);
+  while (it->busy()) {
+    pipe_link_rep* con= (pipe_link_rep*) it->next();
+    if (con->alive) {
+      if (-1 != killpg(con->pid,SIGTERM)) {
+	sleep(2);
+	killpg(con->pid,SIGKILL);
+      }
+      con->alive= false;
+    }
+  }
+#endif
+}
+
+void
+process_all_pipes () {
+  iterator<pointer> it= iterate (pipe_link_set);
+  while (it->busy()) {
+    pipe_link_rep* con= (pipe_link_rep*) it->next();
+    if (con->alive) con->apply_command ();
+  }
+}
+
 /******************************************************************************
 * Routines for pipe_links
 ******************************************************************************/
 
-#ifndef OS_WIN32
 #ifndef __MINGW32__
 void
 execute_shell (string s) {
@@ -131,7 +142,6 @@ execute_shell (string s) {
   tm_delete_array (_s);
 }
 #endif
-#endif
 
 string
 pipe_link_rep::start () {
@@ -139,15 +149,6 @@ pipe_link_rep::start () {
   if (alive) return "busy";
   if (DEBUG_AUTO) cout << "TeXmacs] Launching '" << cmd << "'\n";
 
-#ifdef OS_WIN32
-  char *cmdString;
-  bool success;
-  cmdString = as_charp(cmd);
-  success = PIPE_Create(cmdString, &conn);
-  tm_delete_array (cmdString);
-  if (!success) return "Error: Could not create pipe";
-  else {
-#else
   int e1= pipe (pp_in ); (void) e1;
   int e2= pipe (pp_out); (void) e2;
   int e3= pipe (pp_err); (void) e3;
@@ -175,7 +176,6 @@ pipe_link_rep::start () {
     close (pp_out [OUT]);
     err= pp_err [IN ];
     close (pp_err [OUT]);
-#endif
 
     alive= true;
     snout = socket_notifier (out, &pipe_callback, this, NULL);
@@ -187,21 +187,13 @@ pipe_link_rep::start () {
     else {
       int r;
       char outbuf[1024];
-#ifdef OS_WIN32
-      r= PIPE_ReadStdout(&conn, outbuf, 1024);
-#else
       r= ::read (out, outbuf, 1024);
-#endif
       if (r == 1 && outbuf[0] == TERMCHAR) return "ok";
       alive= false;
-#ifdef OS_WIN32
-      PIPE_Close(&conn);
-#else
       if (-1 != killpg(pid,SIGTERM)) {
 	sleep(2);
 	killpg(pid,SIGKILL);
       }
-#endif
       wait (NULL);
       if (r == -1) return "Error: the application does not reply";
       else
@@ -236,12 +228,8 @@ pipe_link_rep::write (string s, int channel) {
   if ((!alive) || (channel != LINK_IN)) return;
   if (DEBUG_IO) cout << "[INPUT]" << debug_io_string (s);
   char* _s= as_charp (s);
-#ifdef OS_WIN32
-  PIPE_WriteStdin(&conn, _s, N(s));
-#else
   int err= ::write (in, _s, N(s));
   (void) err;
-#endif
   tm_delete_array (_s);
 #endif
 }
@@ -252,26 +240,17 @@ pipe_link_rep::feed (int channel) {
   if ((!alive) || ((channel != LINK_OUT) && (channel != LINK_ERR))) return;
   int r;
   char tempout[1024];
-#ifdef OS_WIN32
-  if (channel == LINK_OUT) r = PIPE_ReadStdout(&conn, tempout, 1024);
-  else r = PIPE_ReadStderr(&conn, tempout, 1024);
-#else
   if (channel == LINK_OUT) r = ::read (out, tempout, 1024);
   else r = ::read (err, tempout, 1024);
-#endif
   if (r == -1) {
     cerr << "TeXmacs] read failed for#'" << cmd << "'\n";
     wait (NULL);
   }
   else if (r == 0) {
-#ifdef OS_WIN32
-    PIPE_Close(&conn);
-#else
     if (-1 != killpg(pid,SIGTERM)) {
       sleep(2);
       killpg(pid,SIGKILL);
     }
-#endif
 
     alive= false;
     remove_notifier (snout);      
@@ -313,7 +292,16 @@ pipe_link_rep::listen (int msecs) {
   if (!alive) return;
   time_t wait_until= texmacs_time () + msecs;
   while ((outbuf == "") && (errbuf == "")) {
-    listen_to_pipes (); // FIXME: should listen more specifically
+    fd_set rfds;
+    FD_ZERO (&rfds);
+    FD_SET (out, &rfds);
+    FD_SET (err, &rfds);
+    struct timeval tv;
+    tv.tv_sec  = msecs / 1000;
+    tv.tv_usec = 1000 * (msecs % 1000);
+    int nr= select (max (out, err) + 1, &rfds, NULL, NULL, &tv);
+    if (nr != 0 && FD_ISSET (out, &rfds)) feed (LINK_OUT);
+    if (nr != 0 && FD_ISSET (err, &rfds)) feed (LINK_ERR);
     if (texmacs_time () - wait_until > 0) break;
   }
 }
@@ -322,28 +310,20 @@ void
 pipe_link_rep::interrupt () {
 #ifndef __MINGW32__
   if (!alive) return;
-#ifdef OS_WIN32
-  PIPE_Close(&conn);
-#else
   killpg (pid, SIGINT);
 #endif
-#endif
 }
 
 void
 pipe_link_rep::stop () {
 #ifndef __MINGW32__
   if (!alive) return;
-#ifdef OS_WIN32
-  PIPE_Close(&conn);
-#else
   if (-1 != killpg(pid,SIGTERM)) {
     sleep(2);
     killpg(pid,SIGKILL);
   }
   alive= false;    
   close (in);
-#endif
   alive= false;
   wait (NULL);
 
@@ -353,87 +333,47 @@ pipe_link_rep::stop () {
 }
 
 /******************************************************************************
-* Listen to all active pipes (may be optimized for speed)
+* Call back for new information on pipe
 ******************************************************************************/
 
-void
-listen_to_pipes () {
+void pipe_callback (void *obj, void *info) {
 #ifndef __MINGW32__
-#ifdef OS_WIN32
-  while (true) {
-    int max_fd = 0;
-    iterator<pointer> it = iterate(pipe_link_set);
-    while (it->busy()) {
-      pipe_link_rep* con = (pipe_link_rep*) it->next();
-      if (con->alive) {
-	if (con->conn.isValid && PIPE_CheckStdout (&con->conn)) max_fd++;
-	if (con->conn.isValid && PIPE_CheckStderr (&con->conn)) max_fd++;
-      }
-    }
-    if(max_fd == 0) break;
-	
-    it= iterate (pipe_link_set);
-    while (it->busy()) {
-      pipe_link_rep* con= (pipe_link_rep*) it->next();
-      if (con->alive && PIPE_CheckStdout (&con->conn)) con->feed (LINK_OUT);
-      if (con->alive && PIPE_CheckStderr (&con->conn)) con->feed (LINK_ERR);
-    }
-  }
-#else
-  while (true) {
+  (void) info;
+  pipe_link_rep* con= (pipe_link_rep*) obj;  
+  bool busy= true;
+  bool news= false;
+  while (busy) {
     fd_set rfds;
     FD_ZERO (&rfds);
-    int max_fd= 0;
-    iterator<pointer> it= iterate (pipe_link_set);
-    while (it->busy()) {
-      pipe_link_rep* con= (pipe_link_rep*) it->next();
-      if (con->alive) {
-	FD_SET (con->out, &rfds);
-	FD_SET (con->err, &rfds);
-	if (con->out >= max_fd) max_fd= con->out+1;
-	if (con->err >= max_fd) max_fd= con->err+1;
-      }
-    }
-    if (max_fd == 0) break;
-
+    int max_fd= max (con->err, con->out) + 1;
+    FD_SET (con->out, &rfds);
+    FD_SET (con->err, &rfds);
+  
     struct timeval tv;
     tv.tv_sec  = 0;
     tv.tv_usec = 0;
-    int nr= select (max_fd, &rfds, NULL, NULL, &tv);
-    if (nr==0) break;
+    select (max_fd, &rfds, NULL, NULL, &tv);
 
-    it= iterate (pipe_link_set);
-    while (it->busy()) {
-      pipe_link_rep* con= (pipe_link_rep*) it->next();
-      if (con->alive && FD_ISSET (con->out, &rfds)) con->feed (LINK_OUT);
-      if (con->alive && FD_ISSET (con->err, &rfds)) con->feed (LINK_ERR);
+    busy= false;
+    if (con->alive && FD_ISSET (con->out, &rfds)) {
+      //cout << "pipe_callback OUT" << LF;
+      con->feed (LINK_OUT);
+      busy= news= true;
+    }
+    if (con->alive && FD_ISSET (con->err, &rfds)) {
+      //cout << "pipe_callback ERR" << LF;
+      con->feed (LINK_ERR);
+      busy= news= true;
     }
   }
-#endif
-#endif
-}
-
-/******************************************************************************
-* Emergency exit for all pipes
-******************************************************************************/
-
-void
-close_all_pipes () {
-#ifndef __MINGW32__
-  iterator<pointer> it= iterate (pipe_link_set);
-  while (it->busy()) {
-    pipe_link_rep* con= (pipe_link_rep*) it->next();
-    if (con->alive) {
-#ifdef OS_WIN32
-      PIPE_Close (&con->conn);
-#else
-      if (-1 != killpg(con->pid,SIGTERM)) {
-	sleep(2);
-	killpg(con->pid,SIGKILL);
-      }
-#endif
-      con->alive= false;
-    }
+  /* FIXME: find out the appropriate place to call the callback
+     Currently, the callback is called in tm_server_rep::interpose_handler */
+  if (!is_nil (con->feed_cmd) && news) {
+    //cout << "pipe_callback APPLY" << LF;
+    if (!is_nil (con->feed_cmd))
+      con->feed_cmd->apply (); // call the data processor
   }
 #endif
 }
+
+#endif // !(defined (QTTEXMACS) && (defined (__MINGW__) || defined (__MINGW32__)))
