@@ -9,10 +9,10 @@
 * in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
+#include "tm_link.hpp"
 #include "client_server.hpp"
 #include "socket_server.hpp"
-#include "socket_link.hpp"
-#include "Scheme/object.hpp"
+#include "scheme.hpp"
 
 static socket_server_rep* the_server= NULL;
 
