@@ -14,7 +14,6 @@
 #include "tree.hpp"
 #include "command.hpp"
 
-
 #define CONNECTION_DEAD    0
 #define CONNECTION_DYING   1
 #define WAITING_FOR_INPUT  2
@@ -62,6 +61,7 @@ public:
   void secure_client ();
 
   void set_command (command _cmd) { feed_cmd = _cmd; }
+  void apply_command () { if (!is_nil (feed_cmd)) feed_cmd->apply (); }
   
   friend class tm_link;
 };
@@ -83,4 +83,10 @@ tm_link make_socket_link (string h, int p, int t= SOCKET_DEFAULT, int fd= -1);
 tm_link make_socket_server (int port);
 tm_link find_socket_link (int fd);
 
+void close_all_pipes ();
+void process_all_pipes ();
+void close_all_sockets ();
+void close_all_servers ();
+int  number_of_servers ();
+
 #endif // TM_LINK_H
