@@ -23,13 +23,14 @@ public:
 public:
   hashmap<tree,tree> props;
   int                serial;
-  int                sfactor;       // the shrinking factor
+  double             zoomf;       // the zoom factor
 
 protected:
   hashmap<int,object>    menu_current;
   hashmap<object,widget> menu_cache;
   string*  text_ptr;  // where the interactive string is returned
   command  call_back; // called when typing finished
+  string   cur_title; // current window title
 
 public:
   tm_window_rep (widget wid2, tree geom);
@@ -56,8 +57,8 @@ public:
   bool get_icon_bar_flag (int which);
   bool get_side_tools_flag (int which);
 
-  int  get_shrinking_factor ();
-  void set_shrinking_factor (int sf);
+  double get_window_zoom_factor ();
+  void set_window_zoom_factor (double zoom);
   void get_visible (SI& x1, SI& y1, SI& x2, SI& y2);
   void get_extents (SI& x1, SI& y1, SI& x2, SI& y2);
   void set_extents (SI x1, SI y1, SI x2, SI y2);
@@ -89,8 +90,8 @@ typedef tm_buffer_rep* tm_buffer;
 typedef tm_view_rep*   tm_view;
 typedef tm_window_rep* tm_window;
 
-widget texmacs_output_widget (tree doc);
-widget texmacs_input_widget (tree doc, command cmd, bool continuous);
+widget texmacs_output_widget (tree doc, tree style);
+widget texmacs_input_widget (tree doc, tree style, command cmd, bool continuous);
 
 int window_handle ();
 void window_create (int win, widget wid, string name, bool plain);
@@ -98,6 +99,10 @@ void window_create (int win, widget wid, string name, command quit);
 void window_delete (int win);
 void window_show (int win);
 void window_hide (int win);
+scheme_tree window_get_size (int win);
+void window_set_size (int win, int w, int h);
+scheme_tree window_get_position (int win);
+void window_set_position (int win, int x, int y);
 void windows_delayed_refresh (int ms);
 void windows_refresh ();
 
