@@ -542,15 +542,15 @@ decompose_gif (url u) {
 }
 
 static void
-add_frames (array<box>& a, path ip, url u, int w, int h, int msecs) {
+add_frames (array<box>& v, path ip, url u, int w, int h, int a, int msecs) {
   if (is_none (u)) return;
   else if (is_or (u)) {
-    add_frames (a, ip, u[1], w, h, msecs);
-    add_frames (a, ip, u[2], w, h, msecs);
+    add_frames (v, ip, u[1], w, h, a, msecs);
+    add_frames (v, ip, u[2], w, h, a, msecs);
   }
   else {
-    box imb= image_box (ip, u, w, h);
-    a << anim_constant_box (ip, imb, msecs);
+    box imb= image_box (ip, u, w, h, a);
+    v << anim_constant_box (ip, imb, msecs);
   }
 }
 
@@ -589,12 +589,12 @@ sound_box (path ip, url u, SI h) {
 }
 
 box
-video_box (path ip, url u, SI w, SI h, int msecs, bool repeat_flag) {
+video_box (path ip, url u, SI w, SI h, int alpha, int msecs, bool repeated) {
   url frames= decompose_gif (u);
   if (is_none (frames)) return empty_box (ip, 0, 0, w, h);
   array<box> bs;
-  add_frames (bs, decorate (ip), frames, w, h, msecs);
-  box b= anim_compose_box (repeat_flag? decorate (ip): ip, bs);
-  if (repeat_flag) return anim_repeat_box (ip, b);
+  add_frames (bs, decorate (ip), frames, w, h, alpha, msecs);
+  box b= anim_compose_box (repeated? decorate (ip): ip, bs);
+  if (repeated) return anim_repeat_box (ip, b);
   else return b;
 }
