@@ -4,10 +4,9 @@
 * DESCRIPTION: Concatenations of arrays of boxes
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Boxes/composite.hpp"
@@ -17,7 +16,8 @@
 ******************************************************************************/
 
 struct concat_box_rep: public composite_box_rep {
-  concat_box_rep (path ip, array<box> bs, array<SI> spc);
+  bool indent;
+  concat_box_rep (path ip, array<box> bs, array<SI> spc, bool indent);
   operator tree ();
 
   void      finalize ();
@@ -56,6 +56,7 @@ struct concat_box_rep: public composite_box_rep {
   SI        get_leaf_offset (string search);
 
   box       transform (frame fr);
+  gr_selections graphical_select (SI x, SI y, SI dist);
   gr_selections graphical_select (SI x1, SI y1, SI x2, SI y2);
 };
 
@@ -74,8 +75,7 @@ concat_box_rep::operator tree () {
 void
 concat_box_rep::position (array<SI> spc) {
   int i;
-  if (N(bs)==0)
-    fatal_error ("concat of zero boxes", "concat_box_rep::position");
+  ASSERT (N(bs) != 0, "concat of zero boxes");
   x1 = bs[0]->x1;
   x2 = 0;
   for (i=0; i<N(bs); i++) {
@@ -84,11 +84,28 @@ concat_box_rep::position (array<SI> spc) {
     sy(i)= 0;
     x2 += bs[i]->x2;
   }
-  composite_box_rep::position ();
+
+  bool ok= !indent;
+  x1= y1= x3= y3= MAX_SI;
+  x2= y2= x4= y4= -MAX_SI;
+  for (i=0; i<N(bs); i++)
+    if (!indent || sx2(i) > sx1(i)) {
+      ok= true;
+      x1= min (x1, sx1(i));
+      y1= min (y1, sy1(i));
+      x2= max (x2, sx2(i));
+      y2= max (y2, sy2(i));
+      x3= min (x3, sx3(i));
+      y3= min (y3, sy3(i));
+      x4= max (x4, sx4(i));
+      y4= max (y4, sy4(i));
+    }
+  if (!ok) composite_box_rep::position ();
 }
 
-concat_box_rep::concat_box_rep (path ip, array<box> bs2, array<SI> spc):
-  composite_box_rep (ip)
+concat_box_rep::concat_box_rep
+  (path ip, array<box> bs2, array<SI> spc, bool indent2):
+    composite_box_rep (ip), indent (indent2)
 {
   bs = bs2;
   position (spc);
@@ -462,6 +479,12 @@ concat_box_rep::find_selection (path lbp, path rbp) {
     }
     if (is_nil (rs)) return selection (rectangles (), lp, rp);
     rectangle r= least_upper_bound (rs);
+    if (indent) {
+      r->x1= max (r->x1, x1);
+      r->y1= max (r->y1, y1);
+      r->x2= min (r->x2, x2);
+      r->y2= min (r->y2, y2);
+    }
     return selection (r, lp, rp);
   }
 }
@@ -499,11 +522,20 @@ concat_box_rep::get_leaf_offset (string search) {
   return w();
 }
 
+gr_selections
+concat_box_rep::graphical_select (SI x, SI y, SI dist) {
+  gr_selections res;
+  int i, n= subnr();
+  for (i=n-1; i>=0; i--)
+    res << bs[i]->graphical_select (x- sx(i), y- sy(i), dist);
+  return res;
+}
+
 gr_selections
 concat_box_rep::graphical_select (SI x1, SI y1, SI x2, SI y2) {
   gr_selections res;
   int i, n= subnr();
-  for (i=0; i<n; i++)
+  for (i=n-1; i>=0; i--)
     res << bs[i]->graphical_select (x1- sx(i), y1- sy(i),
                                     x2- sx(i), y2- sy(i));
   return res;
@@ -524,7 +556,7 @@ public:
 };
 
 phrase_box_rep::phrase_box_rep (path ip, array<box> bs, array<SI> spc):
-  concat_box_rep (ip, bs, spc), logs_ptr (NULL) {}
+  concat_box_rep (ip, bs, spc, false), logs_ptr (NULL) {}
 
 phrase_box_rep::~phrase_box_rep () {
   if (logs_ptr != NULL) {
@@ -555,11 +587,11 @@ phrase_box_rep::display (renderer ren) {
 ******************************************************************************/
 
 box
-concat_box (path ip, array<box> bs, array<SI> spc) {
-  return new concat_box_rep (ip, bs, spc);
+concat_box (path ip, array<box> bs, array<SI> spc, bool indent) {
+  return tm_new<concat_box_rep> (ip, bs, spc, indent);
 }
 
 box
 phrase_box (path ip, array<box> bs, array<SI> spc) {
-  return new phrase_box_rep (ip, bs, spc);
+  return tm_new<phrase_box_rep> (ip, bs, spc);
 }
