@@ -4,10 +4,9 @@
 * DESCRIPTION: Script and limit boxes
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "Boxes/composite.hpp"
@@ -207,6 +206,7 @@ dummy_script_box_rep::finalize () {
 
 path
 dummy_script_box_rep::find_box_path (path p, bool& found) {
+  //cout << "Find " << p << " in " << operator tree () << "\n";
   int nr= subnr ();
   if (((nr >= 1) && test_script_border (p, bs[0])) ||
       ((nr == 2) && test_script_border (p, bs[1])))
@@ -385,10 +385,10 @@ void
 side_box_rep::finalize () {
   int i;
   composite_box_rep::finalize ();
-  for (i=1; i<=nr_left; i++)
+  for (i=1; i<=nr_left+nr_right; i++) {
     finalize_left (lip, bs[i]);
-  for (i=1; i<=nr_right; i++)
-    finalize_right (rip, bs[nr_left+ i]);
+    finalize_right (rip, bs[i]);
+  }
 }
 
 int
@@ -510,9 +510,8 @@ side_box_rep::find_tree_path (path bp) {
       if (nr_right == 1) return reverse (descend_script (bs[nr_left+1]->ip,0));
       return reverse (descend_script (bs[nr_left+1]->ip, bs[nr_left+2]->ip,0));
     }
-    fatal_error ("bad leaf", "side_box_rep::find_tree_path");
+    FAILED ("bad leaf");
     return composite_box_rep::find_tree_path (bp);
-    // avoids error message when C++ compiler behaves badly
   }
   else return composite_box_rep::find_tree_path (bp);
 }
@@ -554,25 +553,25 @@ side_box_rep::find_selection (path lbp, path rbp) {
 
 box
 limit_box (path ip, box ref, box lo, box hi, font fn, bool glued) {
-  return new lim_box_rep (ip, ref, lo, hi, fn, glued);
+  return tm_new<lim_box_rep> (ip, ref, lo, hi, fn, glued);
 }
 
 box
 script_box (path ip, box b1, box b2, font fn) {
-  return new dummy_script_box_rep (ip, b1, b2, fn);
+  return tm_new<dummy_script_box_rep> (ip, b1, b2, fn);
 }
 
 box
 left_script_box (path ip, box ref, box b1, box b2, font fn, int level) {
-  return new side_box_rep (ip, ref, b1, b2, box (), box (), fn, level);
+  return tm_new<side_box_rep> (ip, ref, b1, b2, box (), box (), fn, level);
 }
 
 box
 right_script_box (path ip, box ref, box b1, box b2, font fn, int level) {
-  return new side_box_rep (ip, ref, box (), box (), b1, b2, fn, level);
+  return tm_new<side_box_rep> (ip, ref, box (), box (), b1, b2, fn, level);
 }
 
 box
 side_box (path ip, box ref, box l1, box l2, box r1, box r2, font fn, int l) {
-  return new side_box_rep (ip, ref, l1, l2, r1, r2, fn, l);
+  return tm_new<side_box_rep> (ip, ref, l1, l2, r1, r2, fn, l);
 }
