@@ -296,7 +296,7 @@ cell_box_rep::pre_display (renderer& ren) {
   SI l= bl, r= br, b= bb, t= bt;
   SI lx1, rx1, by1, ty1;
   SI lx2, rx2, by2, ty2;
-  if (ren->sfactor > 1) { // correction for screen display only
+  if (ren->is_screen) { // correction for screen display only
     SI  pixel= ren->pixel;
     l= ((l + (pixel - 1)) / pixel) * pixel;
     r= ((r + (pixel - 1)) / pixel) * pixel;
@@ -375,11 +375,11 @@ struct highlight_box_rep: public change_box_rep {
   SI w, xpad, ypad;
   tree bg;
   int alpha;
-  color sun, shad;
+  color sunc, shad;  // Warning: Solaris has "sun" #defined. Don't rename this
   tree old_bg;
   int old_a;
   highlight_box_rep (path ip, box b, SI w, SI xpad, SI ypad,
-		     tree bg, int alpha, color sun, color shad);
+		     tree bg, int alpha, color sunc, color shad);
   operator tree () { return tree (TUPLE, "highlight", (tree) bs[0]); }
   void pre_display (renderer &ren);
   void post_display (renderer &ren);
@@ -388,9 +388,9 @@ struct highlight_box_rep: public change_box_rep {
 
 highlight_box_rep::highlight_box_rep (
   path ip, box b, SI w2, SI xp2, SI yp2,
-  tree bg2, int alpha2, color sun2, color shad2):
+  tree bg2, int alpha2, color sunc2, color shad2):
     change_box_rep (ip, true), w (w2), xpad (xp2), ypad (yp2),
-    bg (bg2), alpha (alpha2), sun (sun2), shad (shad2)
+    bg (bg2), alpha (alpha2), sunc (sunc2), shad (shad2)
 {
   insert (b, w + xpad, 0);
   position ();
@@ -429,7 +429,7 @@ highlight_box_rep::display (renderer ren) {
     SI pixel= ren->pixel;
     W= ((w + pixel - 1) / pixel) * pixel;
   }
-  ren->set_color (sun);
+  ren->set_color (sunc);
   ren->fill (x1  , y2-W, x2  , y2  );
   ren->fill (x1  , y1  , x1+W, y2  );
   ren->set_color (shad);
@@ -611,7 +611,7 @@ text_at_box_rep::graphical_select (SI x, SI y, SI dist) {
   if (norm (p - point (sx(0), sy(0))) <= dist) {
     gr_selection gs;
     gs->type= "text-handle";
-    gs->dist= norm (p - point (sx(0), sy(0)));
+    gs->dist= (SI) norm (p - point (sx(0), sy(0)));
     gs->p= point (sx(0), sy(0));
     gs->cp << reverse (path (0, path (1, ip)));
     gs->pts << gs->p;
@@ -634,7 +634,7 @@ text_at_box_rep::graphical_select (SI x, SI y, SI dist) {
       gr_selection gs;
       gs->type= "text-border-point";
       gs->p= special[i];
-      gs->dist= norm (gs->p - p);
+      gs->dist= (SI) norm (gs->p - p);
       gs->cp << box_rep::find_tree_path (x, y, dist);
       gs->pts << gs->p;
       gs->c= curve ();
@@ -645,7 +645,7 @@ text_at_box_rep::graphical_select (SI x, SI y, SI dist) {
       gr_selection gs;
       gs->type= "text-border";
       gs->p= closest (cs[i], p);
-      gs->dist= norm (gs->p - p);
+      gs->dist= (SI) norm (gs->p - p);
       gs->cp << box_rep::find_tree_path (x, y, dist);
       gs->pts << gs->p;
       gs->c= cs[i];
@@ -712,8 +712,8 @@ remember_box (path ip, box b) {
 
 box
 highlight_box (path ip, box b, SI w, SI xpad, SI ypad,
-	       tree bg, int a, color sun, color shad) {
-  return tm_new<highlight_box_rep> (ip, b, w, xpad, ypad, bg, a, sun, shad);
+	       tree bg, int a, color sunc, color shad) {
+  return tm_new<highlight_box_rep> (ip, b, w, xpad, ypad, bg, a, sunc, shad);
 }
 
 box
