@@ -4,10 +4,9 @@
 * DESCRIPTION: Bridge between logical and physical long macro expansions
 * COPYRIGHT  : (C) 1999  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "bridge.hpp"
@@ -42,7 +41,7 @@ bridge_rewrite_rep::initialize (tree body_t) {
 
 bridge
 bridge_rewrite (typesetter ttt, tree st, path ip) {
-  return new bridge_rewrite_rep (ttt, st, ip);
+  return tm_new<bridge_rewrite_rep> (ttt, st, ip);
 }
 
 /******************************************************************************
