@@ -18,11 +18,13 @@
 
 void
 concater_rep::typeset_blue (tree t, path ip) {
-  tree old_col= env->local_begin (COLOR, "blue");
-  tree old_fam= env->local_begin (FONT_FAMILY, "ss");
+  tree old_mode= env->local_begin (MODE, "src");
+  tree old_col = env->local_begin (COLOR, "blue");
+  tree old_fam = env->local_begin (FONT_FAMILY, "ss");
   typeset (t, ip);
   env->local_end (FONT_FAMILY, old_fam);
   env->local_end (COLOR, old_col);
+  env->local_end (MODE, old_mode);
 }
 
 /******************************************************************************
@@ -164,6 +166,7 @@ concater_rep::typeset_src_args (tree t, path ip) {
 
 void
 concater_rep::typeset_src_tag (tree t, path ip) {
+  if (N(t) == 0) { typeset_error (t, ip); return; }
   int n= N(t);
   marker (descend (ip, 0));
   if ((L(t) == INLINE_TAG) || (env->src_close == CLOSE_REPEAT)) {
