@@ -25,7 +25,7 @@ initialize_default_var_type () {
   hashmap<string,int>& var_type= default_var_type;
 
   var_type (DPI)               = Env_Fixed;
-  var_type (SFACTOR)           = Env_Fixed;
+  var_type (ZOOM_FACTOR)       = Env_Zoom;
   var_type (PREAMBLE)          = Env_Preamble;
   var_type (SAVE_AUX)          = Env_Fixed;
   var_type (MODE)              = Env_Mode;
@@ -274,9 +274,19 @@ edit_env_rep::update_font () {
 int
 decode_alpha (string s) {
   if (N(s) == 0) return 255;
-  else if (s[N(s)-1] == '%')
-    return (int) (2.55 * as_double (s (0, N(s)-1)));
-  else return (int) (255.0 * as_double (s));
+  else if (s[N(s)-1] == '%') {
+      // mg: be careful to avoid rounding problems for the conversion from double to int : (int)(2.55*100.0)=254
+      double p = as_double (s (0, N(s)-1));
+      if (p<0.0) p = 0.0;
+      if (p>100.0) p = 100.0;
+      return ((int) (255.0 * p))/100;
+  }
+  else {
+      double p = as_double (s);
+      if (p<0.0) p = 0.0;
+      if (p>1.0) p = 1.0;
+      return ((int) (255.0 * p))/100;
+  }
 }
 
 void
@@ -540,6 +550,8 @@ edit_env_rep::update_line_arrows () {
 
 void
 edit_env_rep::update () {
+  zoomf          = normal_zoom (get_double (ZOOM_FACTOR));
+  pixel          = (SI) tm_round ((std_shrinkf * PIXEL) / zoomf);
   magn           = get_double (MAGNIFICATION);
   index_level    = get_int (MATH_LEVEL);
   display_style  = get_bool (MATH_DISPLAY);
@@ -580,6 +592,10 @@ edit_env_rep::update (string s) {
     break;
   case Env_Fixed:
     break;
+  case Env_Zoom:
+    zoomf= normal_zoom (get_double (ZOOM_FACTOR));
+    pixel= (SI) tm_round ((std_shrinkf * PIXEL) / zoomf);
+    break;
   case Env_Magnification:
     magn= get_double (MAGNIFICATION);
     update_font ();
