@@ -108,9 +108,15 @@ curvet_closest_points (
       if (stored && decreasing)
         n0= tm_infinity;
       double delta= (n - eps) / 2;
-      t+=c->bound (t, max (eps, delta));
+      t += max (0.00001, c->bound (t, max (eps, delta)));
       nprec= n;
     }
+    if (!stored && decreasing) {
+      curvet ct;
+      ct.dist= norm (pclosest - p);
+      ct.t= closest;
+      res << ct;
+    }
   }
   return res;
 }
@@ -140,6 +146,29 @@ curve_rep::find_closest_point (
     return -1;
 }
 
+point
+closest (curve f, point p) {
+  array<double> abs;
+  array<point> pts;
+  array<path> rcip;
+  f->get_control_points (abs, pts, rcip);
+  if (N(abs) == 0) return f(0);
+  double t1= abs[0];
+  double t2= abs[N(abs)-1];
+  double best= 0;
+  double eps = norm (f(0) - p);
+  for (int i=0; i<10; i++) {
+    bool found= false;
+    double t= f->find_closest_point (t1, t2, p, eps, found);
+    if (found) best= t;
+    else break;
+    double eps2= norm (f(t) - p);
+    if (eps2 >= 0.9 * eps) break;
+    eps= eps2;
+  }
+  return f(best);
+}
+
 point
 grad (curve f, double t) {
   bool error= false;
@@ -205,15 +234,17 @@ struct segment_rep: public curve_rep {
   path cip1, cip2;
   segment_rep (point p1b, point p2b): p1 (p1b), p2 (p2b) {}
   point evaluate (double t) { return (1.0-t)*p1 + t*p2; }
-  void rectify_cumul (array<point>& a, double eps) { a << p2; }
+  void rectify_cumul (array<point>& a, double eps) { (void) eps; a << p2; }
   double bound (double t, double eps) {
     return curve_rep::bound (t, eps);
   }
   point grad (double t, bool& error) {
+    (void) t;
     error= false;
     return p2 - p1;
   }
   double curvature (double t1, double t2) {
+    (void) t1; (void) t2;
     return tm_infinity;
   }
   int get_control_points (
@@ -259,14 +290,15 @@ struct poly_segment_rep: public curve_rep {
     return (i+1 - n*t)*a[i] + (n*t - i)*a[i+1];
   }
   void rectify_cumul (array<point>& cum, double eps) {
-    int i;
-    for (i=0; i<n; i++)
+    (void) eps;
+    for (int i=0; i<n; i++)
       cum << a[i+1];
   }
   double bound (double t, double eps) {
     return curve_rep::bound (t, eps);
   }
   double curvature (double t1, double t2) {
+    (void) t1; (void) t2;
     return tm_infinity;
   }
   point grad (double t, bool& error) {
@@ -745,6 +777,7 @@ arc_rep::grad (double t, bool& error) {
 
 double
 arc_rep::curvature (double t1, double t2) {
+  (void) t1; (void) t2;
   if (r1 >= r2)
     return fnull (r1,1.0e-6) ? tm_infinity : square(r2)/r1;
   else
@@ -869,6 +902,7 @@ struct transformed_curve_rep: public curve_rep {
   }
   point grad (double t, bool& error);
   double curvature (double t1, double t2) {
+    (void) t1; (void) t2;
     FAILED ("not yet implemented");
     return 0.0;
   }
