@@ -4,10 +4,9 @@
 * DESCRIPTION: coordinate frames
 * COPYRIGHT  : (C) 2003  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "frame.hpp"
@@ -29,13 +28,13 @@ struct scaling_rep: public frame_rep {
     (void) p; error= false; return magnify * v; }
   point jacobian_of_inverse (point p, point v, bool &error) {
     (void) p; error= false; return v / magnify; }
-  double direct_bound (point p, double eps) { return eps / magnify; }
-  double inverse_bound (point p, double eps) { return eps * magnify; }
+  double direct_bound (point p, double eps) { (void) p; return eps / magnify; }
+  double inverse_bound (point p, double eps) { (void) p; return eps * magnify; }
 };
 
 frame
 scaling (double magnify, point shift) {
-  return new scaling_rep (magnify, shift);
+  return tm_new<scaling_rep> (magnify, shift);
 }
 
 /******************************************************************************
@@ -54,13 +53,13 @@ struct rotation_2D_rep: public frame_rep {
     (void) p; error= false; return rotate_2D (v, point (0.0, 0.0), angle); }
   point jacobian_of_inverse (point p, point v, bool &error) {
     (void) p; error= false; return rotate_2D (v, point (0.0, 0.0), -angle); }
-  double direct_bound (point p, double eps) { return eps; }
-  double inverse_bound (point p, double eps) { return eps; }
+  double direct_bound (point p, double eps) { (void) p; return eps; }
+  double inverse_bound (point p, double eps) { (void) p; return eps; }
 };
 
 frame
 rotation_2D (point center, double angle) {
-  return new rotation_2D_rep (center, angle);
+  return tm_new<rotation_2D_rep> (center, angle);
 }
 
 /******************************************************************************
@@ -82,22 +81,21 @@ struct affine_2D_rep: public frame_rep {
     q= m * q;
     return point (q[0], q[1]); }
   point inverse_transform (point p) {
-    fatal_error ("Not yet implemented", "affine_2D_rep::inverse_transform");
+    FAILED ("not yet implemented");
     return p; }
   point jacobian (point p, point v, bool &error) {
     (void) p; error= false; return j * v; }
   point jacobian_of_inverse (point p, point v, bool &error) {
     (void) p; (void) v; (void) error;
-    fatal_error ("Not yet implemented",
-		 "affine_2D_rep::jacobian_of_inverse"); 
+    FAILED ("not yet implemented");
     return p;}
-  double direct_bound (point p, double eps) { return eps; }
-  double inverse_bound (point p, double eps) { return eps; }
+  double direct_bound (point p, double eps) { (void) p; return eps; }
+  double inverse_bound (point p, double eps) { (void) p; return eps; }
 };
 
 frame
 affine_2D (matrix<double> m) {
-  return new affine_2D_rep (m);
+  return tm_new<affine_2D_rep> (m);
 }
 
 /******************************************************************************
@@ -120,8 +118,7 @@ struct compound_frame_rep: public frame_rep {
   }
   point jacobian_of_inverse (point p, point v, bool &error) {
     (void) p; (void) v; (void) error;
-    fatal_error ("Not yet implemented",
-		 "compound_frame_rep::jacobian_of_inverse");
+    FAILED ("not yet implemented");
     return p;
   }
   double direct_bound (point p, double eps) {
@@ -132,7 +129,7 @@ struct compound_frame_rep: public frame_rep {
 
 frame
 operator * (frame f1, frame f2) {
-  return new compound_frame_rep (f1, f2);
+  return tm_new<compound_frame_rep> (f1, f2);
 }
 
 /******************************************************************************
@@ -157,5 +154,5 @@ struct inverted_frame_rep: public frame_rep {
 
 frame
 invert (frame f) {
-  return new inverted_frame_rep (f);
+  return tm_new<inverted_frame_rep> (f);
 }
