@@ -4,10 +4,9 @@
 * DESCRIPTION: points
 * COPYRIGHT  : (C) 2003  Joris van der Hoeven
 *******************************************************************************
-* This software falls under the GNU general public license and comes WITHOUT
-* ANY WARRANTY WHATSOEVER. See the file $TEXMACS_PATH/LICENSE for more details.
-* If you don't have this file, write to the Free Software Foundation, Inc.,
-* 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+* This software falls under the GNU general public license version 3 or later.
+* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
+* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
 ******************************************************************************/
 
 #include "point.hpp"
@@ -67,9 +66,14 @@ operator == (point p1, point p2) {
   return true;
 }
 
+bool
+is_point (tree t) {
+  return L(t)==_POINT;
+}
+
 point
 as_point (tree t) {
-  if (!is_tuple (t)) return point ();
+  if (!is_tuple (t) && !is_point (t)) return point ();
   else {
     int i, n= N(t);
     point p(n);
@@ -82,7 +86,7 @@ as_point (tree t) {
 tree
 as_tree (point p) {
   int i, n= N(p);
-  tree t (TUPLE, n);
+  tree t (_POINT, n);
   for (i=0; i<n; i++)
     t[i]= as_string (p[i]);
   return t;
@@ -190,7 +194,7 @@ midperp (point p1, point p2, point p3) {
 }
 
 point
-intersect (axis A, axis B) {
+intersection (axis A, axis B) {
   point i, j;
   if (!orthogonalize (i, j, A.p0, A.p1, B.p0)) {
     if (orthogonalize (i, j, A.p0, A.p1, B.p1))
